@@ -15,6 +15,78 @@
         <source>View source code online</source>
         <translation>عرض الشفرة المصدرية على الويب</translation>
     </message>
+    <message>
+        <source>Report problems</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>AccountDeletionFromClientAndServerConfirmationPage</name>
+    <message>
+        <source>Delete</source>
+        <translation type="obsolete">حذف</translation>
+    </message>
+</context>
+<context>
+    <name>AccountSecurity</name>
+    <message>
+        <source>Account Security</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disable showing the password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disable showing the QR-Code and password</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>AccountTransferPage</name>
+    <message>
+        <source>Transfer account to another device</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scan the QR code or enter the credentials as text on another device to log in on it.
+
+Attention:
+Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Chat address:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Password:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide QR code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show as QR code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show as text</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ChangePassword</name>
@@ -63,11 +135,11 @@
     <name>ChatMessage</name>
     <message>
         <source>Copy Message</source>
-        <translation>نسخ الرسالة</translation>
+        <translation type="vanished">نسخ الرسالة</translation>
     </message>
     <message>
         <source>Edit Message</source>
-        <translation>تعديل الرسالة</translation>
+        <translation type="vanished">تعديل الرسالة</translation>
     </message>
     <message>
         <source>Spoiler</source>
@@ -77,12 +149,23 @@
         <source>Download</source>
         <translation>تنزيل</translation>
     </message>
+</context>
+<context>
+    <name>ChatMessageContextMenu</name>
+    <message>
+        <source>Copy message</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Edit message</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Copy download URL</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Quote</source>
+        <source>Quote message</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -114,7 +197,7 @@
     </message>
     <message>
         <source>Select a file</source>
-        <translation>اختر ملفا</translation>
+        <translation type="vanished">اختر ملفا</translation>
     </message>
     <message>
         <source>Send a spoiler message</source>
@@ -157,6 +240,13 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>ClientWorker</name>
+    <message>
+        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>CommonEncoderSettings</name>
     <message>
@@ -196,6 +286,47 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>ConfirmationPage</name>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">إلغاء</translation>
+    </message>
+</context>
+<context>
+    <name>DisablePasswordDisplay</name>
+    <message>
+        <source>Remove password completely</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your password will not be included in the QR code anymore.
+You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
+Make sure that you backed it up if you want to use your account later.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove password</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>DisablePlainTextPasswordDisplay</name>
+    <message>
+        <source>Do not show password as text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your password will not be shown as text anymore.
+You won&apos;t be able to see your password as text again because this action cannot be undone!
+Make sure that you backed it up if you want to use your account later.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Do not show password</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>DownloadJob</name>
     <message>
@@ -265,25 +396,25 @@
     <name>FileChooser</name>
     <message>
         <source>Select a file</source>
-        <translation>اختر ملفا</translation>
+        <translation type="vanished">اختر ملفا</translation>
     </message>
 </context>
 <context>
     <name>FileChooserMobile</name>
     <message>
         <source>Go to parent folder</source>
-        <translation>الانتقال إلى المجلد الأصلي</translation>
+        <translation type="vanished">الانتقال إلى المجلد الأصلي</translation>
     </message>
     <message>
         <source>Close</source>
-        <translation>أغلق</translation>
+        <translation type="vanished">أغلق</translation>
     </message>
 </context>
 <context>
     <name>GlobalDrawer</name>
     <message>
         <source>Log out</source>
-        <translation>تسجيل الخروج</translation>
+        <translation type="vanished">تسجيل الخروج</translation>
     </message>
     <message>
         <source>About</source>
@@ -313,6 +444,10 @@
         <source>Connecting…</source>
         <translation type="unfinished">جارٍ الاتصال…</translation>
     </message>
+    <message>
+        <source>Switch device</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Kaidan</name>
@@ -323,11 +458,23 @@
 سيتم فتح هذا الرابط عندما تتصل بالإنترنت.</translation>
     </message>
     <message>
-        <source>No password found. Please enter it.</source>
+        <source>No valid login QR code found.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LocalAccountRemoval</name>
+    <message>
+        <source>Remove account from this app</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>No valid login QR code found.</source>
+        <source>Your account will be removed from this app.
+Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -389,10 +536,6 @@
         <source>An unknown error occured; see log for details.</source>
         <translation type="vanished">حدث خطأ مجهول ؛ اطلع على التفاصيل في السجل.</translation>
     </message>
-    <message>
-        <source>Log in using a QR-Code</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>MediaRecorder</name>
@@ -468,15 +611,11 @@
     <name>MessageHandler</name>
     <message>
         <source>Could not send message, as a result of not being connected.</source>
-        <translation>تعذر ارسال الرسالة بسبب عدم توفر الاتصال.</translation>
+        <translation type="vanished">تعذر ارسال الرسالة بسبب عدم توفر الاتصال.</translation>
     </message>
     <message>
         <source>Could not correct message, as a result of not being connected.</source>
-        <translation>تعذر تعديل الرسالة بسبب عدم توفر الاتصال.</translation>
-    </message>
-    <message>
-        <source>Spoiler</source>
-        <translation type="unfinished"></translation>
+        <translation type="vanished">تعذر تعديل الرسالة بسبب عدم توفر الاتصال.</translation>
     </message>
     <message>
         <source>Message could not be sent.</source>
@@ -487,6 +626,25 @@
         <translation type="unfinished">تعديل الرسالة لم يتم بنجاح.</translation>
     </message>
 </context>
+<context>
+    <name>MessageModel</name>
+    <message>
+        <source>Pending</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sent</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delivered</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished">خطأ</translation>
+    </message>
+</context>
 <context>
     <name>MultimediaSettings</name>
     <message>
@@ -558,7 +716,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Initializing...</source>
+        <source>Initializing…</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -566,7 +724,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Recording...</source>
+        <source>Recording…</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -596,7 +754,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Initializing...</source>
+        <source>Initializing…</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -604,7 +762,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Recording... %1</source>
+        <source>Recording… %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -612,6 +770,32 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>PasswordRemovalPage</name>
+    <message>
+        <source>Remove password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Do not show password as text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove completely</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Mark as read</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QmlUtils</name>
     <message>
@@ -642,10 +826,6 @@
         <source>Error</source>
         <translation type="unfinished">خطأ</translation>
     </message>
-    <message>
-        <source>Invisible</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Invalid username or password.</source>
         <translation type="unfinished">اسم المستخدم أو كلمة المرور غير صالحة.</translation>
@@ -668,7 +848,7 @@
     </message>
     <message>
         <source>Could not connect to the server.</source>
-        <translation type="unfinished">تعذر الإتصال بالخادم.</translation>
+        <translation type="obsolete">تعذر الإتصال بالخادم.</translation>
     </message>
     <message>
         <source>Authentification protocol not supported by the server.</source>
@@ -679,7 +859,22 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>An unknown error occured.</source>
+        <source>The server is offline or blocked by a firewall.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The connection could not be refreshed.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>QrCodeGenerator</name>
+    <message>
+        <source>Generating the QR code failed: %1</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -702,6 +897,41 @@ Try to close other applications using the camera.</source>
         <source>The camera format &apos;%1&apos; is not supported.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Scan the QR code from your existing device to transfer your account.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show explanation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scan</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Continue without QR code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connecting…</source>
+        <translation type="unfinished">جارٍ الاتصال…</translation>
+    </message>
+</context>
+<context>
+    <name>RegistrationLoginDecisionPage</name>
+    <message>
+        <source>Set up</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Register a new account</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use an existing account</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RegistrationManager</name>
@@ -714,6 +944,22 @@ Try to close other applications using the camera.</source>
         <translation>تعذر تغيير كلمة المرور: 1%</translation>
     </message>
 </context>
+<context>
+    <name>RemoteAccountDeletion</name>
+    <message>
+        <source>Delete account completely</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your account will be deleted completely, which means from this app and from the server.
+You will not be able to use your account again!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished">حذف</translation>
+    </message>
+</context>
 <context>
     <name>RosterAddContactSheet</name>
     <message>
@@ -855,10 +1101,6 @@ Try to close other applications using the camera.</source>
         <source>Rename contact</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Edit name:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Cancel</source>
         <translation type="unfinished">إلغاء</translation>
@@ -884,18 +1126,32 @@ Try to close other applications using the camera.</source>
     </message>
 </context>
 <context>
-    <name>SettingsPage</name>
+    <name>ServerListModel</name>
     <message>
-        <source>Settings</source>
-        <translation>الإعدادات</translation>
+        <source>Custom server</source>
+        <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>No limitation</source>
+        <extracomment>Unlimited file size for uploading files
+----------
+Deletion of message history saved on server</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 days</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SettingsContent</name>
     <message>
         <source>Change password</source>
-        <translation>تغيير كلمة المرور</translation>
+        <translation type="unfinished">تغيير كلمة المرور</translation>
     </message>
     <message>
         <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
-        <translation>تغيير كلمة مرور حساباتك. يجب عليك إعادة إدخال كلمة المرور إلى جميع الأجهزة الأخرى.</translation>
+        <translation type="unfinished">تغيير كلمة مرور حساباتك. يجب عليك إعادة إدخال كلمة المرور إلى جميع الأجهزة الأخرى.</translation>
     </message>
     <message>
         <source>Multimedia Settings</source>
@@ -905,6 +1161,67 @@ Try to close other applications using the camera.</source>
         <source>Configure photo, video and audio recording settings</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Settings</source>
+        <translation type="unfinished">الإعدادات</translation>
+    </message>
+    <message>
+        <source>Account security</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>configure whether this device can be used to log in on a new device</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove account from Kaidan</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove account from this app</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete account</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete account from the server</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SettingsPage</name>
+    <message>
+        <source>Settings</source>
+        <translation>الإعدادات</translation>
+    </message>
+    <message>
+        <source>Change password</source>
+        <translation type="vanished">تغيير كلمة المرور</translation>
+    </message>
+    <message>
+        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
+        <translation type="vanished">تغيير كلمة مرور حساباتك. يجب عليك إعادة إدخال كلمة المرور إلى جميع الأجهزة الأخرى.</translation>
+    </message>
+</context>
+<context>
+    <name>SettingsSheet</name>
+    <message>
+        <source>Settings</source>
+        <translation type="obsolete">الإعدادات</translation>
+    </message>
+</context>
+<context>
+    <name>StartPage</name>
+    <message>
+        <source>Enjoy free communication on every device!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Let&apos;s start</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SubRequestAcceptSheet</name>
@@ -935,6 +1252,10 @@ Try to close other applications using the camera.</source>
         <source>File</source>
         <translation>ملف</translation>
     </message>
+    <message>
+        <source>Message could not be sent.</source>
+        <translation type="unfinished">تعذر ارسال الرسالة.</translation>
+    </message>
 </context>
 <context>
     <name>UserProfilePage</name>
