@@ -15,6 +15,96 @@
         <source>View source code online</source>
         <translation>Vegeu el codi font en línia</translation>
     </message>
+    <message>
+        <source>Report problems</source>
+        <translation>Informeu de problemes</translation>
+    </message>
+</context>
+<context>
+    <name>AccountDeletionFromClientAndServerConfirmationPage</name>
+    <message>
+        <source>Delete account completely</source>
+        <translation type="vanished">Suprimeix el compte completament</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">Suprimeix</translation>
+    </message>
+</context>
+<context>
+    <name>AccountDeletionPage</name>
+    <message>
+        <source>Delete account</source>
+        <translation type="vanished">Suprimeix el compte</translation>
+    </message>
+    <message>
+        <source>Delete completely</source>
+        <translation type="vanished">Suprimeix completament</translation>
+    </message>
+</context>
+<context>
+    <name>AccountSecurity</name>
+    <message>
+        <source>Account Security</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disable showing the password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disable showing the QR-Code and password</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>AccountTransferPage</name>
+    <message>
+        <source>Transfer account to another device</source>
+        <translation>Transfereix el compte a un altre dispositiu</translation>
+    </message>
+    <message>
+        <source>Scan the QR code or enter the credentials as text on another device to log in on it.
+
+Attention:
+Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
+        <translation>Escanegeu el codi QR o introduïu les credencials com a text en un altre dispositiu per a iniciar-hi una sessió.
+
+Atenció:
+Mai no mostreu aquest codi QR als altres. Fer-ho donaria accés il·limitat al vostre compte!</translation>
+    </message>
+    <message>
+        <source>Chat address:</source>
+        <translation>Adreça del xat:</translation>
+    </message>
+    <message>
+        <source>Password:</source>
+        <translation>Contrasenya:</translation>
+    </message>
+    <message>
+        <source>Hide QR code</source>
+        <translation>Amaga el codi QR</translation>
+    </message>
+    <message>
+        <source>Show as QR code</source>
+        <translation>Mostra com a codi QR</translation>
+    </message>
+    <message>
+        <source>Hide text</source>
+        <translation>Amaga el text</translation>
+    </message>
+    <message>
+        <source>Show as text</source>
+        <translation>Mostra com a text</translation>
+    </message>
 </context>
 <context>
     <name>ChangePassword</name>
@@ -28,15 +118,15 @@
     </message>
     <message>
         <source>New password:</source>
-        <translation>Nova contrasenya:</translation>
+        <translation>Contrasenya nova:</translation>
     </message>
     <message>
         <source>New password (repeat):</source>
-        <translation>Contrasenya nova (repetir):</translation>
+        <translation>Contrasenya nova (de nou):</translation>
     </message>
     <message>
         <source>New passwords do not match.</source>
-        <translation>Les noves contrasenyes no coincideixen.</translation>
+        <translation>Les contrasenyes noves no coincideixen.</translation>
     </message>
     <message>
         <source>Current password is invalid.</source>
@@ -44,7 +134,7 @@
     </message>
     <message>
         <source>You need to be connected to change your password.</source>
-        <translation>Heu d&apos;estar connectat per canviar la vostra contrasenya.</translation>
+        <translation>Heu de connectar-vos per a canviar la contrasenya.</translation>
     </message>
     <message>
         <source>After changing your password, you will need to reenter it on all your other devices.</source>
@@ -63,27 +153,38 @@
     <name>ChatMessage</name>
     <message>
         <source>Copy Message</source>
-        <translation>Copia el missatge</translation>
+        <translation type="vanished">Copia el missatge</translation>
     </message>
     <message>
         <source>Edit Message</source>
-        <translation>Edita el missatge</translation>
+        <translation type="vanished">Edita el missatge</translation>
     </message>
     <message>
         <source>Spoiler</source>
-        <translation>Filtració</translation>
+        <translation>Revelació</translation>
     </message>
     <message>
         <source>Download</source>
-        <translation>Descarrega</translation>
+        <translation>Baixa</translation>
+    </message>
+</context>
+<context>
+    <name>ChatMessageContextMenu</name>
+    <message>
+        <source>Copy message</source>
+        <translation type="unfinished">Copia el missatge</translation>
+    </message>
+    <message>
+        <source>Edit message</source>
+        <translation type="unfinished">Edita el missatge</translation>
     </message>
     <message>
         <source>Copy download URL</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Copia l’URL de la baixada</translation>
     </message>
     <message>
-        <source>Quote</source>
-        <translation type="unfinished"></translation>
+        <source>Quote message</source>
+        <translation type="unfinished">Cita el missatge</translation>
     </message>
 </context>
 <context>
@@ -114,46 +215,69 @@
     </message>
     <message>
         <source>Select a file</source>
-        <translation>Selecciona un fitxer</translation>
+        <translation type="vanished">Selecciona un fitxer</translation>
     </message>
     <message>
         <source>Send a spoiler message</source>
-        <translation>Envia una filtració</translation>
+        <translation>Envia una revelació</translation>
     </message>
     <message>
         <source>Spoiler hint</source>
-        <translation>Indici de la filtració</translation>
+        <translation>Indici de la revelació</translation>
     </message>
     <message>
         <source>Unmute notifications</source>
-        <translation type="unfinished"></translation>
+        <translation>Torna a activar les notificacions</translation>
     </message>
     <message>
         <source>Mute notifications</source>
-        <translation type="unfinished"></translation>
+        <translation>Silencia les notificacions</translation>
     </message>
     <message>
         <source>View profile</source>
-        <translation type="unfinished"></translation>
+        <translation>Mostra el perfil</translation>
     </message>
     <message>
         <source>Search</source>
-        <translation type="unfinished">Cerca</translation>
+        <translation>Cerca</translation>
     </message>
     <message>
         <source>Close</source>
-        <translation type="unfinished">Tanca</translation>
+        <translation>Tanca</translation>
     </message>
     <message>
         <source>Search up</source>
-        <translation type="unfinished"></translation>
+        <translation>Cerca cap enrere</translation>
     </message>
     <message>
         <source>Search down</source>
-        <translation type="unfinished"></translation>
+        <translation>Cerca cap endavant</translation>
     </message>
     <message>
         <source>All files</source>
+        <translation>Tots els fitxers</translation>
+    </message>
+    <message>
+        <source>Copy message</source>
+        <translation type="vanished">Copia el missatge</translation>
+    </message>
+    <message>
+        <source>Edit message</source>
+        <translation type="vanished">Edita el missatge</translation>
+    </message>
+    <message>
+        <source>Copy download URL</source>
+        <translation type="vanished">Copia l’URL de la baixada</translation>
+    </message>
+    <message>
+        <source>Quote message</source>
+        <translation type="vanished">Cita el missatge</translation>
+    </message>
+</context>
+<context>
+    <name>ClientWorker</name>
+    <message>
+        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -181,7 +305,7 @@
     </message>
     <message>
         <source>Constant quality</source>
-        <translation type="unfinished"></translation>
+        <translation>Qualitat constant</translation>
     </message>
     <message>
         <source>Constant bit rate</source>
@@ -196,6 +320,47 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>ConfirmationPage</name>
+    <message>
+        <source>Cancel</source>
+        <translation>Cancel·la</translation>
+    </message>
+</context>
+<context>
+    <name>DisablePasswordDisplay</name>
+    <message>
+        <source>Remove password completely</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your password will not be included in the QR code anymore.
+You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
+Make sure that you backed it up if you want to use your account later.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove password</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>DisablePlainTextPasswordDisplay</name>
+    <message>
+        <source>Do not show password as text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your password will not be shown as text anymore.
+You won&apos;t be able to see your password as text again because this action cannot be undone!
+Make sure that you backed it up if you want to use your account later.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Do not show password</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>DownloadJob</name>
     <message>
@@ -204,7 +369,7 @@
     </message>
     <message>
         <source>Download failed: %1</source>
-        <translation>La descàrrega ha fallat: %1</translation>
+        <translation>Ha fallat la baixada: %1</translation>
     </message>
 </context>
 <context>
@@ -219,7 +384,7 @@
     </message>
     <message>
         <source>Nature</source>
-        <translation>Naturalesa</translation>
+        <translation>Natura</translation>
     </message>
     <message>
         <source>Food</source>
@@ -231,7 +396,7 @@
     </message>
     <message>
         <source>Travel</source>
-        <translation>Viatjar</translation>
+        <translation>Viatges</translation>
     </message>
     <message>
         <source>Objects</source>
@@ -251,39 +416,39 @@
     </message>
     <message>
         <source>Search emoji</source>
-        <translation>Cerca emoji</translation>
+        <translation>Cerca emojis</translation>
     </message>
 </context>
 <context>
     <name>EmptyChatPage</name>
     <message>
         <source>Please select a chat to start messaging</source>
-        <translation>Seleccioneu un xat per començar</translation>
+        <translation>Seleccioneu un xat per a començar</translation>
     </message>
 </context>
 <context>
     <name>FileChooser</name>
     <message>
         <source>Select a file</source>
-        <translation>Seleccioneu un fitxer</translation>
+        <translation type="vanished">Seleccioneu un fitxer</translation>
     </message>
 </context>
 <context>
     <name>FileChooserMobile</name>
     <message>
         <source>Go to parent folder</source>
-        <translation>Vés a la carpeta superior</translation>
+        <translation type="vanished">Vés a la carpeta superior</translation>
     </message>
     <message>
         <source>Close</source>
-        <translation>Tanca</translation>
+        <translation type="vanished">Tanca</translation>
     </message>
 </context>
 <context>
     <name>GlobalDrawer</name>
     <message>
         <source>Log out</source>
-        <translation>Surt</translation>
+        <translation type="vanished">Surt</translation>
     </message>
     <message>
         <source>About</source>
@@ -311,7 +476,19 @@
     </message>
     <message>
         <source>Connecting…</source>
-        <translation type="unfinished">Connectant…</translation>
+        <translation>S’està connectant…</translation>
+    </message>
+    <message>
+        <source>Transfer account</source>
+        <translation type="vanished">Transfereix el compte</translation>
+    </message>
+    <message>
+        <source>Delete account</source>
+        <translation type="vanished">Suprimeix el compte</translation>
+    </message>
+    <message>
+        <source>Switch device</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -322,11 +499,23 @@
         <translation>L&apos;enllaç s&apos;obrirà després de que us hagueu connectat.</translation>
     </message>
     <message>
-        <source>No password found. Please enter it.</source>
+        <source>No valid login QR code found.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LocalAccountRemoval</name>
+    <message>
+        <source>Remove account from this app</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>No valid login QR code found.</source>
+        <source>Your account will be removed from this app.
+Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -354,7 +543,7 @@
     </message>
     <message>
         <source>Connecting…</source>
-        <translation>Connectant…</translation>
+        <translation>S’està connectant…</translation>
     </message>
     <message>
         <source>Connect</source>
@@ -392,75 +581,71 @@
         <source>An unknown error occured; see log for details.</source>
         <translation type="vanished">S&apos;ha produït un error desconegut. Vegeu el registre per més detalls.</translation>
     </message>
-    <message>
-        <source>Log in using a QR-Code</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>MediaRecorder</name>
     <message>
         <source>Default</source>
-        <translation type="unfinished"></translation>
+        <translation>Per defecte</translation>
     </message>
 </context>
 <context>
     <name>MediaUtils</name>
     <message>
         <source>Take picture</source>
-        <translation type="unfinished"></translation>
+        <translation>Fes una foto</translation>
     </message>
     <message>
         <source>Record video</source>
-        <translation type="unfinished"></translation>
+        <translation>Enregistra un vídeo</translation>
     </message>
     <message>
         <source>Record voice</source>
-        <translation type="unfinished"></translation>
+        <translation>Enregistra la veu</translation>
     </message>
     <message>
         <source>Send location</source>
-        <translation type="unfinished"></translation>
+        <translation>Envia la ubicació</translation>
     </message>
     <message>
         <source>Choose file</source>
-        <translation type="unfinished"></translation>
+        <translation>Tria un fitxer</translation>
     </message>
     <message>
         <source>Choose image</source>
-        <translation type="unfinished"></translation>
+        <translation>Tria una imatge</translation>
     </message>
     <message>
         <source>Choose video</source>
-        <translation type="unfinished"></translation>
+        <translation>Tria un vídeo</translation>
     </message>
     <message>
         <source>Choose audio file</source>
-        <translation type="unfinished"></translation>
+        <translation>Tria un fitxer d’àudio</translation>
     </message>
     <message>
         <source>Choose document</source>
-        <translation type="unfinished"></translation>
+        <translation>Tria un document</translation>
     </message>
     <message>
         <source>All files</source>
-        <translation type="unfinished"></translation>
+        <translation>Tots els fitxers</translation>
     </message>
     <message>
         <source>Images</source>
-        <translation type="unfinished"></translation>
+        <translation>Imatges</translation>
     </message>
     <message>
         <source>Videos</source>
-        <translation type="unfinished"></translation>
+        <translation>Vídeos</translation>
     </message>
     <message>
         <source>Audio files</source>
-        <translation type="unfinished"></translation>
+        <translation>Fitxers d’àudio</translation>
     </message>
     <message>
         <source>Documents</source>
-        <translation type="unfinished"></translation>
+        <translation>Documents</translation>
     </message>
     <message>
         <source>%1 (%2)</source>
@@ -471,15 +656,15 @@
     <name>MessageHandler</name>
     <message>
         <source>Could not send message, as a result of not being connected.</source>
-        <translation>No s&apos;ha pogut enviar el missatge perquè no teniu connexió.</translation>
+        <translation type="vanished">No s&apos;ha pogut enviar el missatge perquè no teniu connexió.</translation>
     </message>
     <message>
         <source>Could not correct message, as a result of not being connected.</source>
-        <translation>No s&apos;ha pogut corregir el missatge perquè no teniu connexió.</translation>
+        <translation type="vanished">No s&apos;ha pogut corregir el missatge perquè no teniu connexió.</translation>
     </message>
     <message>
         <source>Spoiler</source>
-        <translation>Filtració</translation>
+        <translation type="vanished">Revelació</translation>
     </message>
     <message>
         <source>Message could not be sent.</source>
@@ -490,91 +675,110 @@
         <translation>La correcció del missatge no ha anat bé.</translation>
     </message>
 </context>
+<context>
+    <name>MessageModel</name>
+    <message>
+        <source>Pending</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sent</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delivered</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished">Error</translation>
+    </message>
+</context>
 <context>
     <name>MultimediaSettings</name>
     <message>
         <source>Multimedia Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Configuració de multimèdia</translation>
     </message>
     <message>
         <source>Configure</source>
-        <translation type="unfinished"></translation>
+        <translation>Configura</translation>
     </message>
     <message>
         <source>Image Capture</source>
-        <translation type="unfinished"></translation>
+        <translation>Captura d’imatges</translation>
     </message>
     <message>
         <source>Audio Recording</source>
-        <translation type="unfinished"></translation>
+        <translation>Enregistrament d’àudio</translation>
     </message>
     <message>
         <source>Video Recording</source>
-        <translation type="unfinished"></translation>
+        <translation>Enregistrament de vídeo</translation>
     </message>
     <message>
         <source>Camera</source>
-        <translation type="unfinished"></translation>
+        <translation>Càmera</translation>
     </message>
     <message>
         <source>Audio input</source>
-        <translation type="unfinished"></translation>
+        <translation>Entrada d’àudio</translation>
     </message>
     <message>
         <source>Container</source>
-        <translation type="unfinished"></translation>
+        <translation>Contenidor</translation>
     </message>
     <message>
         <source>Image</source>
-        <translation type="unfinished">Imatge</translation>
+        <translation>Imatge</translation>
     </message>
     <message>
         <source>Audio</source>
-        <translation type="unfinished">Àudio</translation>
+        <translation>Àudio</translation>
     </message>
     <message>
         <source>Video</source>
-        <translation type="unfinished">Vídeo</translation>
+        <translation>Vídeo</translation>
     </message>
     <message>
         <source>Codec</source>
-        <translation type="unfinished"></translation>
+        <translation>Còdec</translation>
     </message>
     <message>
         <source>Resolution</source>
-        <translation type="unfinished"></translation>
+        <translation>Resolució</translation>
     </message>
     <message>
         <source>Quality</source>
-        <translation type="unfinished"></translation>
+        <translation>Qualitat</translation>
     </message>
     <message>
         <source>Sample Rate</source>
-        <translation type="unfinished"></translation>
+        <translation>Freqüència de mostratge</translation>
     </message>
     <message>
         <source>Frame Rate</source>
-        <translation type="unfinished"></translation>
+        <translation>Freqüència dels fotogrames</translation>
     </message>
     <message>
         <source>Ready</source>
-        <translation type="unfinished"></translation>
+        <translation>Preparat</translation>
     </message>
     <message>
-        <source>Initializing...</source>
-        <translation type="unfinished"></translation>
+        <source>Initializing…</source>
+        <translation>S’està inicialitzant…</translation>
     </message>
     <message>
         <source>Unavailable</source>
-        <translation type="unfinished"></translation>
+        <translation>No disponible</translation>
     </message>
     <message>
-        <source>Recording...</source>
-        <translation type="unfinished"></translation>
+        <source>Recording…</source>
+        <translation>S’està enregistrant…</translation>
     </message>
     <message>
         <source>Paused</source>
-        <translation type="unfinished"></translation>
+        <translation>En pausa</translation>
     </message>
 </context>
 <context>
@@ -596,30 +800,56 @@
     <name>NewMedia</name>
     <message>
         <source>Ready</source>
-        <translation type="unfinished"></translation>
+        <translation>Preparat</translation>
     </message>
     <message>
-        <source>Initializing...</source>
-        <translation type="unfinished"></translation>
+        <source>Initializing…</source>
+        <translation>S’està inicialitzant…</translation>
     </message>
     <message>
         <source>Unavailable</source>
-        <translation type="unfinished"></translation>
+        <translation>No disponible</translation>
     </message>
     <message>
-        <source>Recording... %1</source>
-        <translation type="unfinished"></translation>
+        <source>Recording… %1</source>
+        <translation>S’està enregistrant… %1</translation>
     </message>
     <message>
         <source>Paused %1</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>PasswordRemovalPage</name>
+    <message>
+        <source>Remove password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Do not show password as text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove completely</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Mark as read</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QmlUtils</name>
     <message>
         <source>Available</source>
-        <translation type="unfinished">Disponible</translation>
+        <translation>Disponible</translation>
     </message>
     <message>
         <source>Free for chat</source>
@@ -627,15 +857,15 @@
     </message>
     <message>
         <source>Away</source>
-        <translation type="unfinished">Lluny</translation>
+        <translation>Lluny</translation>
     </message>
     <message>
         <source>Do not disturb</source>
-        <translation type="unfinished">No em molesteu</translation>
+        <translation>No em molesteu</translation>
     </message>
     <message>
         <source>Away for longer</source>
-        <translation type="unfinished">He sortit una estona</translation>
+        <translation>He sortit una estona</translation>
     </message>
     <message>
         <source>Offline</source>
@@ -643,27 +873,23 @@
     </message>
     <message>
         <source>Error</source>
-        <translation type="unfinished">Error</translation>
-    </message>
-    <message>
-        <source>Invisible</source>
-        <translation type="unfinished"></translation>
+        <translation>Error</translation>
     </message>
     <message>
         <source>Invalid username or password.</source>
-        <translation type="unfinished">Usuari o contrasenya invàlids.</translation>
+        <translation>El nom d’usuari o la contrasenya són incorrectes.</translation>
     </message>
     <message>
         <source>Cannot connect to the server. Please check your internet connection.</source>
-        <translation type="unfinished">No s&apos;ha pogut connectar al servidor. Comproveu la vostra connexió a internet.</translation>
+        <translation>No s’ha pogut connectar al servidor. Comproveu la vostra connexió a internet.</translation>
     </message>
     <message>
         <source>The server doesn&apos;t support secure connections.</source>
-        <translation type="unfinished">El servidor no és compatible amb connexions segures.</translation>
+        <translation>El servidor no és compatible amb les connexions segures.</translation>
     </message>
     <message>
         <source>Error while trying to connect securely.</source>
-        <translation type="unfinished">S&apos;ha produït un error provant de connectar de forma segura.</translation>
+        <translation>S’ha produït un error en provar de connectar de forma segura.</translation>
     </message>
     <message>
         <source>Could not resolve the server&apos;s address. Please check your server name.</source>
@@ -671,18 +897,33 @@
     </message>
     <message>
         <source>Could not connect to the server.</source>
-        <translation type="unfinished">No s&apos;ha pogut connectar al servidor.</translation>
+        <translation type="obsolete">No s&apos;ha pogut connectar al servidor.</translation>
     </message>
     <message>
         <source>Authentification protocol not supported by the server.</source>
-        <translation type="unfinished">Protocol d&apos;autenticació no compatible amb el servidor.</translation>
+        <translation>El protocol d’autenticació no és compatible amb el servidor.</translation>
     </message>
     <message>
         <source>This server does not support registration.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>An unknown error occured.</source>
+        <source>The server is offline or blocked by a firewall.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The connection could not be refreshed.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>QrCodeGenerator</name>
+    <message>
+        <source>Generating the QR code failed: %1</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -705,6 +946,41 @@ Try to close other applications using the camera.</source>
         <source>The camera format &apos;%1&apos; is not supported.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Scan the QR code from your existing device to transfer your account.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show explanation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scan</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Continue without QR code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connecting…</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>RegistrationLoginDecisionPage</name>
+    <message>
+        <source>Set up</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Register a new account</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use an existing account</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RegistrationManager</name>
@@ -714,14 +990,30 @@ Try to close other applications using the camera.</source>
     </message>
     <message>
         <source>Failed to change password: %1</source>
-        <translation>No s&apos;ha pogut canviar la contrasenya:% 1</translation>
+        <translation>No s’ha pogut canviar la contrasenya: %1</translation>
+    </message>
+</context>
+<context>
+    <name>RemoteAccountDeletion</name>
+    <message>
+        <source>Delete account completely</source>
+        <translation type="unfinished">Suprimeix el compte completament</translation>
+    </message>
+    <message>
+        <source>Your account will be deleted completely, which means from this app and from the server.
+You will not be able to use your account again!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>RosterAddContactSheet</name>
     <message>
         <source>Add new contact</source>
-        <translation>Afegeix un nou contacte</translation>
+        <translation>Afegeix un contacte nou</translation>
     </message>
     <message>
         <source>This will also send a request to access the presence of the contact.</source>
@@ -858,13 +1150,9 @@ Try to close other applications using the camera.</source>
         <source>Rename contact</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Edit name:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Cancel</source>
-        <translation type="unfinished">Cancel·la</translation>
+        <translation>Cancel·la</translation>
     </message>
     <message>
         <source>Rename</source>
@@ -887,11 +1175,25 @@ Try to close other applications using the camera.</source>
     </message>
 </context>
 <context>
-    <name>SettingsPage</name>
+    <name>ServerListModel</name>
     <message>
-        <source>Settings</source>
-        <translation>Configuració</translation>
+        <source>Custom server</source>
+        <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>No limitation</source>
+        <extracomment>Unlimited file size for uploading files
+----------
+Deletion of message history saved on server</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 days</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SettingsContent</name>
     <message>
         <source>Change password</source>
         <translation>Canvia la contrasenya</translation>
@@ -902,12 +1204,73 @@ Try to close other applications using the camera.</source>
     </message>
     <message>
         <source>Multimedia Settings</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Configuració de multimèdia</translation>
     </message>
     <message>
         <source>Configure photo, video and audio recording settings</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Settings</source>
+        <translation type="unfinished">Configuració</translation>
+    </message>
+    <message>
+        <source>Account security</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>configure whether this device can be used to log in on a new device</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove account from Kaidan</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove account from this app</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete account</source>
+        <translation type="unfinished">Suprimeix el compte</translation>
+    </message>
+    <message>
+        <source>Delete account from the server</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SettingsPage</name>
+    <message>
+        <source>Settings</source>
+        <translation>Configuració</translation>
+    </message>
+    <message>
+        <source>Change password</source>
+        <translation type="vanished">Canvia la contrasenya</translation>
+    </message>
+    <message>
+        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
+        <translation type="vanished">Canvia la contrasenya del vostre compte. Haureu de tornar a introduir-la als altres dispositius.</translation>
+    </message>
+</context>
+<context>
+    <name>SettingsSheet</name>
+    <message>
+        <source>Settings</source>
+        <translation type="vanished">Configuració</translation>
+    </message>
+</context>
+<context>
+    <name>StartPage</name>
+    <message>
+        <source>Enjoy free communication on every device!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Let&apos;s start</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SubRequestAcceptSheet</name>
@@ -938,19 +1301,23 @@ Try to close other applications using the camera.</source>
         <source>File</source>
         <translation>Fitxer</translation>
     </message>
+    <message>
+        <source>Message could not be sent.</source>
+        <translation type="unfinished">No s’ha pogut enviar el missatge.</translation>
+    </message>
 </context>
 <context>
     <name>UserProfilePage</name>
     <message>
         <source>Profile</source>
-        <translation type="unfinished"></translation>
+        <translation>Perfil</translation>
     </message>
 </context>
 <context>
     <name>VCardModel</name>
     <message>
         <source>Name</source>
-        <translation type="unfinished"></translation>
+        <translation>Nom</translation>
     </message>
     <message>
         <source>Nickname</source>
@@ -958,19 +1325,19 @@ Try to close other applications using the camera.</source>
     </message>
     <message>
         <source>About</source>
-        <translation type="unfinished">Quant a</translation>
+        <translation>Quant a</translation>
     </message>
     <message>
         <source>Email</source>
-        <translation type="unfinished"></translation>
+        <translation>Correu-e</translation>
     </message>
     <message>
         <source>Birthday</source>
-        <translation type="unfinished"></translation>
+        <translation>Aniversari</translation>
     </message>
     <message>
         <source>Website</source>
-        <translation type="unfinished"></translation>
+        <translation>Lloc web</translation>
     </message>
 </context>
 </TS>
