@@ -15,6 +15,78 @@
         <source>View source code online</source>
         <translation>Prohlédnout zdrojový kód online</translation>
     </message>
+    <message>
+        <source>Report problems</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>AccountDeletionFromClientAndServerConfirmationPage</name>
+    <message>
+        <source>Delete</source>
+        <translation type="obsolete">Smazat</translation>
+    </message>
+</context>
+<context>
+    <name>AccountSecurity</name>
+    <message>
+        <source>Account Security</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disable showing the password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disable showing the QR-Code and password</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>AccountTransferPage</name>
+    <message>
+        <source>Transfer account to another device</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scan the QR code or enter the credentials as text on another device to log in on it.
+
+Attention:
+Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Chat address:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Password:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide QR code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show as QR code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show as text</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ChangePassword</name>
@@ -63,11 +135,11 @@
     <name>ChatMessage</name>
     <message>
         <source>Copy Message</source>
-        <translation>Zkopírovat zprávu</translation>
+        <translation type="vanished">Zkopírovat zprávu</translation>
     </message>
     <message>
         <source>Edit Message</source>
-        <translation>Editovat zprávu</translation>
+        <translation type="vanished">Editovat zprávu</translation>
     </message>
     <message>
         <source>Spoiler</source>
@@ -79,10 +151,25 @@
     </message>
     <message>
         <source>Copy download URL</source>
-        <translation>Kopírovat stažitelnou URL</translation>
+        <translation type="vanished">Kopírovat stažitelnou URL</translation>
+    </message>
+</context>
+<context>
+    <name>ChatMessageContextMenu</name>
+    <message>
+        <source>Copy message</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Quote</source>
+        <source>Edit message</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy download URL</source>
+        <translation type="unfinished">Kopírovat stažitelnou URL</translation>
+    </message>
+    <message>
+        <source>Quote message</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -114,7 +201,7 @@
     </message>
     <message>
         <source>Select a file</source>
-        <translation>Vybrat soubor</translation>
+        <translation type="vanished">Vybrat soubor</translation>
     </message>
     <message>
         <source>Send a spoiler message</source>
@@ -160,6 +247,17 @@
         <source>All files</source>
         <translation>Všechny soubory</translation>
     </message>
+    <message>
+        <source>Copy download URL</source>
+        <translation type="obsolete">Kopírovat stažitelnou URL</translation>
+    </message>
+</context>
+<context>
+    <name>ClientWorker</name>
+    <message>
+        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CommonEncoderSettings</name>
@@ -200,6 +298,47 @@
         <translation>Dvouproudový</translation>
     </message>
 </context>
+<context>
+    <name>ConfirmationPage</name>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">Zrušit</translation>
+    </message>
+</context>
+<context>
+    <name>DisablePasswordDisplay</name>
+    <message>
+        <source>Remove password completely</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your password will not be included in the QR code anymore.
+You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
+Make sure that you backed it up if you want to use your account later.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove password</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>DisablePlainTextPasswordDisplay</name>
+    <message>
+        <source>Do not show password as text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your password will not be shown as text anymore.
+You won&apos;t be able to see your password as text again because this action cannot be undone!
+Make sure that you backed it up if you want to use your account later.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Do not show password</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>DownloadJob</name>
     <message>
@@ -273,25 +412,25 @@
     <name>FileChooser</name>
     <message>
         <source>Select a file</source>
-        <translation>Vybrat soubor</translation>
+        <translation type="vanished">Vybrat soubor</translation>
     </message>
 </context>
 <context>
     <name>FileChooserMobile</name>
     <message>
         <source>Go to parent folder</source>
-        <translation>Přesun o adresář výše</translation>
+        <translation type="vanished">Přesun o adresář výše</translation>
     </message>
     <message>
         <source>Close</source>
-        <translation>Zavřít</translation>
+        <translation type="vanished">Zavřít</translation>
     </message>
 </context>
 <context>
     <name>GlobalDrawer</name>
     <message>
         <source>Log out</source>
-        <translation>Odhlásit se</translation>
+        <translation type="vanished">Odhlásit se</translation>
     </message>
     <message>
         <source>About</source>
@@ -321,6 +460,10 @@
         <source>Connecting…</source>
         <translation type="unfinished">Připojování…</translation>
     </message>
+    <message>
+        <source>Switch device</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Kaidan</name>
@@ -331,13 +474,29 @@
     </message>
     <message>
         <source>No password found. Please enter it.</source>
-        <translation>Heslo nenalezeno. Prosím zadejte heslo.</translation>
+        <translation type="vanished">Heslo nenalezeno. Prosím zadejte heslo.</translation>
     </message>
     <message>
         <source>No valid login QR code found.</source>
         <translation>Nebyl nalezen žádný platný přihlašovací kód QR.</translation>
     </message>
 </context>
+<context>
+    <name>LocalAccountRemoval</name>
+    <message>
+        <source>Remove account from this app</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your account will be removed from this app.
+Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>LoginPage</name>
     <message>
@@ -411,7 +570,7 @@ Prosím zkontrolujte své připojení k internetu.</translation>
     </message>
     <message>
         <source>Log in using a QR-Code</source>
-        <translation>Přihlaste se pomocí QR kódu</translation>
+        <translation type="vanished">Přihlaste se pomocí QR kódu</translation>
     </message>
 </context>
 <context>
@@ -488,15 +647,15 @@ Prosím zkontrolujte své připojení k internetu.</translation>
     <name>MessageHandler</name>
     <message>
         <source>Could not send message, as a result of not being connected.</source>
-        <translation>Nelze odeslat zprávu, neboť nejste připojeni.</translation>
+        <translation type="vanished">Nelze odeslat zprávu, neboť nejste připojeni.</translation>
     </message>
     <message>
         <source>Could not correct message, as a result of not being connected.</source>
-        <translation>Zprávu nelze editovat, neboť nejste připojeni.</translation>
+        <translation type="vanished">Zprávu nelze editovat, neboť nejste připojeni.</translation>
     </message>
     <message>
         <source>Spoiler</source>
-        <translation>«Spoiler»</translation>
+        <translation type="vanished">«Spoiler»</translation>
     </message>
     <message>
         <source>Message could not be sent.</source>
@@ -507,6 +666,25 @@ Prosím zkontrolujte své připojení k internetu.</translation>
         <translation>Oprava zprávy se nezdařila.</translation>
     </message>
 </context>
+<context>
+    <name>MessageModel</name>
+    <message>
+        <source>Pending</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sent</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delivered</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished">Chyba</translation>
+    </message>
+</context>
 <context>
     <name>MultimediaSettings</name>
     <message>
@@ -578,16 +756,16 @@ Prosím zkontrolujte své připojení k internetu.</translation>
         <translation type="unfinished">Připravený</translation>
     </message>
     <message>
-        <source>Initializing...</source>
-        <translation type="unfinished">Zahajuji...</translation>
+        <source>Initializing…</source>
+        <translation type="unfinished">Zahajuji…</translation>
     </message>
     <message>
         <source>Unavailable</source>
         <translation type="unfinished">Nedostupný</translation>
     </message>
     <message>
-        <source>Recording...</source>
-        <translation type="unfinished">Nahrávám...</translation>
+        <source>Recording…</source>
+        <translation type="unfinished">Nahrávám…</translation>
     </message>
     <message>
         <source>Paused</source>
@@ -665,16 +843,16 @@ Prosím zkontrolujte své připojení k internetu.</translation>
         <translation type="vanished">Připravený</translation>
     </message>
     <message>
-        <source>Initializing...</source>
-        <translation type="vanished">Zahajuji...</translation>
+        <source>Initializing…</source>
+        <translation type="vanished">Zahajuji…</translation>
     </message>
     <message>
         <source>Unavailable</source>
         <translation type="vanished">Nedostupný</translation>
     </message>
     <message>
-        <source>Recording...</source>
-        <translation type="vanished">Nahrávám...</translation>
+        <source>Recording…</source>
+        <translation type="vanished">Nahrávám…</translation>
     </message>
     <message>
         <source>Paused</source>
@@ -688,22 +866,48 @@ Prosím zkontrolujte své připojení k internetu.</translation>
         <translation>Připravený</translation>
     </message>
     <message>
-        <source>Initializing...</source>
-        <translation>Zahajuji...</translation>
+        <source>Initializing…</source>
+        <translation>Zahajuji…</translation>
     </message>
     <message>
         <source>Unavailable</source>
         <translation>Nedostupný</translation>
     </message>
     <message>
-        <source>Recording... %1</source>
-        <translation>Nahrávání... %1</translation>
+        <source>Recording… %1</source>
+        <translation>Nahrávání… %1</translation>
     </message>
     <message>
         <source>Paused %1</source>
         <translation>Pozastaveno %1</translation>
     </message>
 </context>
+<context>
+    <name>PasswordRemovalPage</name>
+    <message>
+        <source>Remove password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Do not show password as text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove completely</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Mark as read</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QmlUtils</name>
     <message>
@@ -736,7 +940,7 @@ Prosím zkontrolujte své připojení k internetu.</translation>
     </message>
     <message>
         <source>Invisible</source>
-        <translation>Neviditelný</translation>
+        <translation type="vanished">Neviditelný</translation>
     </message>
     <message>
         <source>Invalid username or password.</source>
@@ -761,7 +965,7 @@ Prosím zkontrolujte své připojení k internetu.</translation>
     </message>
     <message>
         <source>Could not connect to the server.</source>
-        <translation type="unfinished">Nebylo možné se připojit k serveru.</translation>
+        <translation type="obsolete">Nebylo možné se připojit k serveru.</translation>
     </message>
     <message>
         <source>Authentification protocol not supported by the server.</source>
@@ -772,7 +976,22 @@ Prosím zkontrolujte své připojení k internetu.</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>An unknown error occured.</source>
+        <source>The server is offline or blocked by a firewall.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The connection could not be refreshed.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>QrCodeGenerator</name>
+    <message>
+        <source>Generating the QR code failed: %1</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -796,6 +1015,41 @@ Zkuste zavřít jiné aplikace, které používají fotoaparát.</translation>
         <source>The camera format &apos;%1&apos; is not supported.</source>
         <translation>Formát fotoaparátu &apos;% 1&apos; není podporován.</translation>
     </message>
+    <message>
+        <source>Scan the QR code from your existing device to transfer your account.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show explanation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scan</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Continue without QR code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connecting…</source>
+        <translation type="unfinished">Připojování…</translation>
+    </message>
+</context>
+<context>
+    <name>RegistrationLoginDecisionPage</name>
+    <message>
+        <source>Set up</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Register a new account</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use an existing account</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RegistrationManager</name>
@@ -808,6 +1062,22 @@ Zkuste zavřít jiné aplikace, které používají fotoaparát.</translation>
         <translation>Změna hesla se nezdařila: %1</translation>
     </message>
 </context>
+<context>
+    <name>RemoteAccountDeletion</name>
+    <message>
+        <source>Delete account completely</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your account will be deleted completely, which means from this app and from the server.
+You will not be able to use your account again!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished">Smazat</translation>
+    </message>
+</context>
 <context>
     <name>RosterAddContactSheet</name>
     <message>
@@ -951,7 +1221,7 @@ Zkuste zavřít jiné aplikace, které používají fotoaparát.</translation>
     </message>
     <message>
         <source>Edit name:</source>
-        <translation>Editovat jméno:</translation>
+        <translation type="vanished">Editovat jméno:</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -978,18 +1248,32 @@ Zkuste zavřít jiné aplikace, které používají fotoaparát.</translation>
     </message>
 </context>
 <context>
-    <name>SettingsPage</name>
+    <name>ServerListModel</name>
     <message>
-        <source>Settings</source>
-        <translation>Nastavení</translation>
+        <source>Custom server</source>
+        <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>No limitation</source>
+        <extracomment>Unlimited file size for uploading files
+----------
+Deletion of message history saved on server</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 days</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SettingsContent</name>
     <message>
         <source>Change password</source>
-        <translation>Změna hesla</translation>
+        <translation type="unfinished">Změna hesla</translation>
     </message>
     <message>
         <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
-        <translation>Změní heslo k vašemu účtu. Bude třeba ho zadat na všech vašich zařízeních.</translation>
+        <translation type="unfinished">Změní heslo k vašemu účtu. Bude třeba ho zadat na všech vašich zařízeních.</translation>
     </message>
     <message>
         <source>Multimedia Settings</source>
@@ -999,6 +1283,71 @@ Zkuste zavřít jiné aplikace, které používají fotoaparát.</translation>
         <source>Configure photo, video and audio recording settings</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Settings</source>
+        <translation type="unfinished">Nastavení</translation>
+    </message>
+    <message>
+        <source>Account security</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>configure whether this device can be used to log in on a new device</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove account from Kaidan</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove account from this app</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete account</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete account from the server</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SettingsPage</name>
+    <message>
+        <source>Settings</source>
+        <translation>Nastavení</translation>
+    </message>
+    <message>
+        <source>Change password</source>
+        <translation type="vanished">Změna hesla</translation>
+    </message>
+    <message>
+        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
+        <translation type="vanished">Změní heslo k vašemu účtu. Bude třeba ho zadat na všech vašich zařízeních.</translation>
+    </message>
+    <message>
+        <source>Multimedia Settings</source>
+        <translation type="obsolete">Nastavení multimédií</translation>
+    </message>
+</context>
+<context>
+    <name>SettingsSheet</name>
+    <message>
+        <source>Settings</source>
+        <translation type="obsolete">Nastavení</translation>
+    </message>
+</context>
+<context>
+    <name>StartPage</name>
+    <message>
+        <source>Enjoy free communication on every device!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Let&apos;s start</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SubRequestAcceptSheet</name>
@@ -1029,6 +1378,10 @@ Zkuste zavřít jiné aplikace, které používají fotoaparát.</translation>
         <source>File</source>
         <translation>Soubor</translation>
     </message>
+    <message>
+        <source>Message could not be sent.</source>
+        <translation type="unfinished">Zprávu se nepodařilo odeslat.</translation>
+    </message>
 </context>
 <context>
     <name>UserProfilePage</name>
