@@ -19,6 +19,10 @@
         <source>View source code online</source>
         <translation>Quellcode online einsehen</translation>
     </message>
+    <message>
+        <source>Report problems</source>
+        <translation>Probleme melden</translation>
+    </message>
 </context>
 <context>
     <name>AboutPage</name>
@@ -58,6 +62,126 @@
         <translation type="vanished">Quellcode auf GitHub</translation>
     </message>
 </context>
+<context>
+    <name>AccountDeletionFromClientAndServerConfirmationPage</name>
+    <message>
+        <source>Delete account completely</source>
+        <translation type="vanished">Konto vollständig löschen</translation>
+    </message>
+    <message>
+        <source>Your account will be deleted completely, which means from this app and from the server.
+You will not be able to use your account again!</source>
+        <translation type="vanished">Ihr Konto wird vollständig gelöscht sein, d.h. von dieser Anwendung und vom Server.
+
+Sie werden Ihr Konto nicht mehr benutzen können!</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">Löschen</translation>
+    </message>
+</context>
+<context>
+    <name>AccountDeletionFromClientConfirmationPage</name>
+    <message>
+        <source>Remove account from this app</source>
+        <translation type="vanished">Konto aus dieser App entfernen</translation>
+    </message>
+    <message>
+        <source>Your account will be removed from this app.
+You won&apos;t be able to get your credentials back!
+Make sure that you have backed up those if you want to use your account later.</source>
+        <translation type="vanished">Ihr Konto wird aus dieser App entfernt sein.
+Sie werden nicht in der Lage sein, Ihre Zugangsdaten zurückzubekommen!
+Stellen Sie sicher, dass Sie diese gesichert haben, wenn Sie Ihr Konto später benutzen möchten.</translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation type="vanished">Entfernen</translation>
+    </message>
+</context>
+<context>
+    <name>AccountDeletionPage</name>
+    <message>
+        <source>Delete account</source>
+        <translation type="vanished">Konto löschen</translation>
+    </message>
+    <message>
+        <source>You can remove your account &lt;b&gt;%1&lt;/b&gt; only from this app or delete it completely. If you delete your account completely, you won&apos;t be able to use it with another app because it is also removed from the server.</source>
+        <translation type="vanished">Sie können Ihr Konto &lt;b&gt;%1&lt;/b&gt; nur aus dieser App entfernen oder es komplett löschen. Wenn Sie Ihr Konto vollständig löschen, können Sie es nicht mehr mit einer anderen Anwendung verwenden, da es ebenfalls vom Server entfernt wird.</translation>
+    </message>
+    <message>
+        <source>Remove from this app</source>
+        <translation type="vanished">Aus dieser App entfernen</translation>
+    </message>
+    <message>
+        <source>Delete completely</source>
+        <translation type="vanished">Vollständig löschen</translation>
+    </message>
+</context>
+<context>
+    <name>AccountSecurity</name>
+    <message>
+        <source>Account Security</source>
+        <translation>Konto-Sicherheit</translation>
+    </message>
+    <message>
+        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
+        <translation>Erlaube das Hinzufügen neuer Geräte mit einem QR-Code, aber zeige das Passwort niemals als Text an. Diese Aktion kann nicht rückgängig gemacht werden. Sie sollten also überlegen, das Passwort vor der Verwendung anderweitig zu speichern.</translation>
+    </message>
+    <message>
+        <source>Disable showing the password</source>
+        <translation>Passwort nicht mehr anzeigen</translation>
+    </message>
+    <message>
+        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
+        <translation>Passwort in keiner Form verfügbar machen. Dies kann nicht rückgängig gemacht werden.</translation>
+    </message>
+    <message>
+        <source>Disable showing the QR-Code and password</source>
+        <translation>Passwort und QR-Code nicht mehr anzeigen</translation>
+    </message>
+</context>
+<context>
+    <name>AccountTransferPage</name>
+    <message>
+        <source>Transfer account to another device</source>
+        <translation>Konto auf ein anderes Gerät übertragen</translation>
+    </message>
+    <message>
+        <source>Scan the QR code or enter the credentials as text on another device to log in on it.
+
+Attention:
+Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
+        <translation>Scannen Sie den QR-Code oder geben Sie die Anmeldedaten als Text auf einem anderen Gerät ein, um sich dort anzumelden.
+
+Achtung!
+Zeigen Sie diesen QR-Code niemals anderen Personen. Er würde unbegrenzten Zugang zu Ihrem Konto ermöglichen!</translation>
+    </message>
+    <message>
+        <source>Chat address:</source>
+        <translation>Chat-Adresse:</translation>
+    </message>
+    <message>
+        <source>Password:</source>
+        <translation>Passwort:</translation>
+    </message>
+    <message>
+        <source>Hide QR code</source>
+        <translation>QR-Code ausblenden</translation>
+    </message>
+    <message>
+        <source>Show as QR code</source>
+        <translation>Als QR-Code anzeigen</translation>
+    </message>
+    <message>
+        <source>Hide text</source>
+        <translation>Text ausblenden</translation>
+    </message>
+    <message>
+        <source>Show as text</source>
+        <translation>Als Text anzeigen</translation>
+    </message>
+</context>
 <context>
     <name>BackButton</name>
     <message>
@@ -116,11 +240,11 @@
     </message>
     <message>
         <source>Copy Message</source>
-        <translation>Nachricht kopieren</translation>
+        <translation type="vanished">Nachricht kopieren</translation>
     </message>
     <message>
         <source>Edit Message</source>
-        <translation>Nachricht bearbeiten</translation>
+        <translation type="vanished">Nachricht bearbeiten</translation>
     </message>
     <message>
         <source>Spoiler</source>
@@ -132,11 +256,26 @@
     </message>
     <message>
         <source>Copy download URL</source>
-        <translation>Download-Link kopieren</translation>
+        <translation type="vanished">Download-Link kopieren</translation>
+    </message>
+</context>
+<context>
+    <name>ChatMessageContextMenu</name>
+    <message>
+        <source>Copy message</source>
+        <translation>Nachricht kopieren</translation>
     </message>
     <message>
-        <source>Quote</source>
-        <translation type="unfinished"></translation>
+        <source>Edit message</source>
+        <translation>Nachricht bearbeiten</translation>
+    </message>
+    <message>
+        <source>Copy download URL</source>
+        <translation>URL zum Herunterladen kopieren</translation>
+    </message>
+    <message>
+        <source>Quote message</source>
+        <translation>Nachricht zitieren</translation>
     </message>
 </context>
 <context>
@@ -175,7 +314,7 @@
     </message>
     <message>
         <source>Select a file</source>
-        <translation>Eine Datei auswählen</translation>
+        <translation type="vanished">Eine Datei auswählen</translation>
     </message>
     <message>
         <source>Send a spoiler message</source>
@@ -221,6 +360,29 @@
         <source>All files</source>
         <translation>Alle Dateien</translation>
     </message>
+    <message>
+        <source>Copy message</source>
+        <translation type="vanished">Nachricht kopieren</translation>
+    </message>
+    <message>
+        <source>Edit message</source>
+        <translation type="vanished">Nachricht bearbeiten</translation>
+    </message>
+    <message>
+        <source>Copy download URL</source>
+        <translation type="vanished">Herunterladen-Link kopieren</translation>
+    </message>
+    <message>
+        <source>Quote message</source>
+        <translation type="vanished">Nachricht zitieren</translation>
+    </message>
+</context>
+<context>
+    <name>ClientWorker</name>
+    <message>
+        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
+        <translation>Ihr Konto konnte nicht vom Server gelöscht werden. Daher wurde es auch nicht aus dieser App entfernt: %1</translation>
+    </message>
 </context>
 <context>
     <name>CommonEncoderSettings</name>
@@ -261,6 +423,13 @@
         <translation>Zwei Durchgänge</translation>
     </message>
 </context>
+<context>
+    <name>ConfirmationPage</name>
+    <message>
+        <source>Cancel</source>
+        <translation>Abbrechen</translation>
+    </message>
+</context>
 <context>
     <name>ContextDrawer</name>
     <message>
@@ -268,6 +437,44 @@
         <translation type="vanished">Aktionen</translation>
     </message>
 </context>
+<context>
+    <name>DisablePasswordDisplay</name>
+    <message>
+        <source>Remove password completely</source>
+        <translation>Passwort vollständig ausblenden</translation>
+    </message>
+    <message>
+        <source>Your password will not be included in the QR code anymore.
+You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
+Make sure that you backed it up if you want to use your account later.</source>
+        <translation>Ihr Passwort wird nicht mehr im QR-Code enthalten sein.
+Sie können die Anmeldung über den QR-Code nicht mehr verwenden, ohne Ihr Passwort erneut einzugeben, da diese Aktion nicht rückgängig gemacht werden kann!
+Stellen Sie sicher, dass Sie das Passwort gesichert haben, wenn Sie Ihr Konto später verwenden möchten.</translation>
+    </message>
+    <message>
+        <source>Remove password</source>
+        <translation>Passwort ausblenden</translation>
+    </message>
+</context>
+<context>
+    <name>DisablePlainTextPasswordDisplay</name>
+    <message>
+        <source>Do not show password as text</source>
+        <translation>Passwort nicht als Klartext anzeigen</translation>
+    </message>
+    <message>
+        <source>Your password will not be shown as text anymore.
+You won&apos;t be able to see your password as text again because this action cannot be undone!
+Make sure that you backed it up if you want to use your account later.</source>
+        <translation>Ihr Passwort wird nicht mehr als Text angezeigt werden.
+Sie werden Ihr Passwort nicht mehr als Text sehen können, da diese Aktion nicht rückgängig gemacht werden kann!
+Stellen Sie sicher, dass Sie es gesichert haben, wenn Sie sich später noch auf ihrem Konto anmelden wollen.</translation>
+    </message>
+    <message>
+        <source>Do not show password</source>
+        <translation>Passwort nicht anzeigen</translation>
+    </message>
+</context>
 <context>
     <name>DownloadJob</name>
     <message>
@@ -323,21 +530,21 @@
     </message>
     <message>
         <source>Search emoji</source>
-        <translation>Suche Emoji</translation>
+        <translation>Emoji suchen</translation>
     </message>
 </context>
 <context>
     <name>EmptyChatPage</name>
     <message>
         <source>Please select a chat to start messaging</source>
-        <translation>Bitten wählen Sie einen Chat aus um zu beginnen</translation>
+        <translation>Bitte wählen Sie einen Chat aus, um zu beginnen</translation>
     </message>
 </context>
 <context>
     <name>FileChooser</name>
     <message>
         <source>Select a file</source>
-        <translation>Datei auswählen</translation>
+        <translation type="vanished">Datei auswählen</translation>
     </message>
 </context>
 <context>
@@ -348,11 +555,11 @@
     </message>
     <message>
         <source>Close</source>
-        <translation>Schließen</translation>
+        <translation type="vanished">Schließen</translation>
     </message>
     <message>
         <source>Go to parent folder</source>
-        <translation>In übergeordneten Ordner wechseln</translation>
+        <translation type="vanished">In übergeordneten Ordner wechseln</translation>
     </message>
 </context>
 <context>
@@ -370,7 +577,7 @@
     </message>
     <message>
         <source>Log out</source>
-        <translation>Abmelden</translation>
+        <translation type="vanished">Abmelden</translation>
     </message>
     <message>
         <source>About</source>
@@ -398,15 +605,27 @@
     </message>
     <message>
         <source>Offline</source>
-        <translation type="unfinished">Offline</translation>
+        <translation>Offline</translation>
     </message>
     <message>
         <source>Online</source>
-        <translation type="unfinished"></translation>
+        <translation>Online</translation>
     </message>
     <message>
         <source>Connecting…</source>
-        <translation type="unfinished"></translation>
+        <translation>Verbinde…</translation>
+    </message>
+    <message>
+        <source>Transfer account</source>
+        <translation type="vanished">Konto übertragen</translation>
+    </message>
+    <message>
+        <source>Delete account</source>
+        <translation type="vanished">Konto löschen</translation>
+    </message>
+    <message>
+        <source>Switch device</source>
+        <translation>Gerät wechseln</translation>
     </message>
 </context>
 <context>
@@ -446,13 +665,30 @@
     </message>
     <message>
         <source>No password found. Please enter it.</source>
-        <translation>Kein Password gefunden. Bitte gib es ein.</translation>
+        <translation type="vanished">Kein Password gefunden. Bitte gib es ein.</translation>
     </message>
     <message>
         <source>No valid login QR code found.</source>
         <translation>Kein gültiger QR-Code zum Anmelden gefunden.</translation>
     </message>
 </context>
+<context>
+    <name>LocalAccountRemoval</name>
+    <message>
+        <source>Remove account from this app</source>
+        <translation>Konto aus dieser App entfernen</translation>
+    </message>
+    <message>
+        <source>Your account will be removed from this app.
+Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
+        <translation>Ihr Konto wird aus dieser App entfernt.
+Ihr Passwort wird gelöscht, stellen Sie sicher, dass es in einem Passwort-Manager gespeichert ist oder Sie es kennen!</translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation>Entfernen</translation>
+    </message>
+</context>
 <context>
     <name>LoginPage</name>
     <message>
@@ -533,7 +769,7 @@
     </message>
     <message>
         <source>Log in using a QR-Code</source>
-        <translation>Mit einem QR-Code anmelden</translation>
+        <translation type="vanished">Mit einem QR-Code anmelden</translation>
     </message>
 </context>
 <context>
@@ -555,7 +791,7 @@
     </message>
     <message>
         <source>Record voice</source>
-        <translation>Sprache aufnehmen</translation>
+        <translation>Stimme aufnehmen</translation>
     </message>
     <message>
         <source>Send location</source>
@@ -610,15 +846,15 @@
     <name>MessageHandler</name>
     <message>
         <source>Could not send message, as a result of not being connected.</source>
-        <translation>Konnte Nachricht nicht versenden, da Sie nicht verbunden sind.</translation>
+        <translation type="vanished">Konnte Nachricht nicht versenden, da Sie nicht verbunden sind.</translation>
     </message>
     <message>
         <source>Could not correct message, as a result of not being connected.</source>
-        <translation>Konnte Nachricht nicht korrigieren, da Sie nicht verbunden sind.</translation>
+        <translation type="vanished">Konnte Nachricht nicht korrigieren, da Sie nicht verbunden sind.</translation>
     </message>
     <message>
         <source>Spoiler</source>
-        <translation>Versteckt</translation>
+        <translation type="vanished">Versteckt</translation>
     </message>
     <message>
         <source>Message could not be sent.</source>
@@ -629,91 +865,110 @@
         <translation>Nachrichtenkorrektur war nicht erfolgreich.</translation>
     </message>
 </context>
+<context>
+    <name>MessageModel</name>
+    <message>
+        <source>Pending</source>
+        <translation>Ausstehend</translation>
+    </message>
+    <message>
+        <source>Sent</source>
+        <translation>Gesendet</translation>
+    </message>
+    <message>
+        <source>Delivered</source>
+        <translation>Angekommen</translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation>Fehler</translation>
+    </message>
+</context>
 <context>
     <name>MultimediaSettings</name>
     <message>
         <source>Multimedia Settings</source>
-        <translation type="unfinished">Multimedia-Einstellungen</translation>
+        <translation>Multimedia-Einstellungen</translation>
     </message>
     <message>
         <source>Configure</source>
-        <translation type="unfinished">Konfigurieren</translation>
+        <translation>Konfigurieren</translation>
     </message>
     <message>
         <source>Image Capture</source>
-        <translation type="unfinished">Bild Aufnahme</translation>
+        <translation>Bildaufnahme</translation>
     </message>
     <message>
         <source>Audio Recording</source>
-        <translation type="unfinished">Audio Aufnahme</translation>
+        <translation>Audioaufnahme</translation>
     </message>
     <message>
         <source>Video Recording</source>
-        <translation type="unfinished">Video Aufnahme</translation>
+        <translation>Videoaufnahme</translation>
     </message>
     <message>
         <source>Camera</source>
-        <translation type="unfinished">Kamera</translation>
+        <translation>Kamera</translation>
     </message>
     <message>
         <source>Audio input</source>
-        <translation type="unfinished">Audio Eingabe</translation>
+        <translation>Audioeingabe</translation>
     </message>
     <message>
         <source>Container</source>
-        <translation type="unfinished">Container</translation>
+        <translation>Container</translation>
     </message>
     <message>
         <source>Image</source>
-        <translation type="unfinished">Bild</translation>
+        <translation>Bild</translation>
     </message>
     <message>
         <source>Audio</source>
-        <translation type="unfinished">Ton</translation>
+        <translation>Ton</translation>
     </message>
     <message>
         <source>Video</source>
-        <translation type="unfinished">Video</translation>
+        <translation>Video</translation>
     </message>
     <message>
         <source>Codec</source>
-        <translation type="unfinished">Codec</translation>
+        <translation>Codec</translation>
     </message>
     <message>
         <source>Resolution</source>
-        <translation type="unfinished">Auflösung</translation>
+        <translation>Auflösung</translation>
     </message>
     <message>
         <source>Quality</source>
-        <translation type="unfinished">Qualität</translation>
+        <translation>Qualität</translation>
     </message>
     <message>
         <source>Sample Rate</source>
-        <translation type="unfinished">Abtastrate</translation>
+        <translation>Abtastrate</translation>
     </message>
     <message>
         <source>Frame Rate</source>
-        <translation type="unfinished">Bildrate</translation>
+        <translation>Bildrate</translation>
     </message>
     <message>
         <source>Ready</source>
-        <translation type="unfinished">Bereit</translation>
+        <translation>Bereit</translation>
     </message>
     <message>
-        <source>Initializing...</source>
-        <translation type="unfinished"></translation>
+        <source>Initializing…</source>
+        <translation>Initialisiere…</translation>
     </message>
     <message>
         <source>Unavailable</source>
-        <translation type="unfinished">Nicht verfügbar</translation>
+        <translation>Nicht verfügbar</translation>
     </message>
     <message>
-        <source>Recording...</source>
-        <translation type="unfinished">Aufnahme...</translation>
+        <source>Recording…</source>
+        <translation>Aufnahme…</translation>
     </message>
     <message>
         <source>Paused</source>
-        <translation type="unfinished">Pausiert</translation>
+        <translation>Pausiert</translation>
     </message>
 </context>
 <context>
@@ -787,16 +1042,16 @@
         <translation type="vanished">Bereit</translation>
     </message>
     <message>
-        <source>Initializing...</source>
-        <translation type="vanished">Initialisieren...</translation>
+        <source>Initializing…</source>
+        <translation type="vanished">Initialisieren…</translation>
     </message>
     <message>
         <source>Unavailable</source>
         <translation type="vanished">Nicht verfügbar</translation>
     </message>
     <message>
-        <source>Recording...</source>
-        <translation type="vanished">Aufnahme...</translation>
+        <source>Recording…</source>
+        <translation type="vanished">Aufnahme…</translation>
     </message>
     <message>
         <source>Paused</source>
@@ -810,22 +1065,48 @@
         <translation>Bereit</translation>
     </message>
     <message>
-        <source>Initializing...</source>
-        <translation>Initializieren...</translation>
+        <source>Initializing…</source>
+        <translation>Initializieren…</translation>
     </message>
     <message>
         <source>Unavailable</source>
         <translation>Nicht verfügbar</translation>
     </message>
     <message>
-        <source>Recording... %1</source>
-        <translation>Zeichne auf... %1</translation>
+        <source>Recording… %1</source>
+        <translation>Zeichne auf… %1</translation>
     </message>
     <message>
         <source>Paused %1</source>
         <translation>%1 pausiert</translation>
     </message>
 </context>
+<context>
+    <name>PasswordRemovalPage</name>
+    <message>
+        <source>Remove password</source>
+        <translation>Passwort ausblenden</translation>
+    </message>
+    <message>
+        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
+        <translation>Sie können sich entscheiden, Ihr Passwort für &lt;b&gt;%1&lt;/b&gt; nur nicht mehr als Text anzuzeigen oder es vollständig aus der Kontoübertragung zu entfernen. Wenn Sie Ihr Passwort vollständig entfernen, können Sie die Kontoübertragung per QR-Code-Scan ohne Eingabe Ihres Passworts nicht mehr nutzen, da es auch aus dem QR-Code entfernt wird.</translation>
+    </message>
+    <message>
+        <source>Do not show password as text</source>
+        <translation>Passwort nicht als Klartext anzeigen</translation>
+    </message>
+    <message>
+        <source>Remove completely</source>
+        <translation>Vollständig entfernen</translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Mark as read</source>
+        <translation type="unfinished">Als gelesen markieren</translation>
+    </message>
+</context>
 <context>
     <name>QmlUtils</name>
     <message>
@@ -858,43 +1139,58 @@
     </message>
     <message>
         <source>Invisible</source>
-        <translation>Unsichtbar</translation>
+        <translation type="vanished">Unsichtbar</translation>
     </message>
     <message>
         <source>Invalid username or password.</source>
-        <translation type="unfinished">Falscher Benutzername oder falsches Passwort.</translation>
+        <translation>Falscher Benutzername oder falsches Passwort.</translation>
     </message>
     <message>
         <source>Cannot connect to the server. Please check your internet connection.</source>
-        <translation type="unfinished">Konnte nicht zum Server verbinden. Überprüfen Sie Ihre Internetverbindung.</translation>
+        <translation>Konnte nicht zum Server verbinden. Überprüfen Sie Ihre Internetverbindung.</translation>
     </message>
     <message>
         <source>The server doesn&apos;t support secure connections.</source>
-        <translation type="unfinished">Dieser Server unterstützt keine sicheren Verbindungen.</translation>
+        <translation>Dieser Server unterstützt keine sicheren Verbindungen.</translation>
     </message>
     <message>
         <source>Error while trying to connect securely.</source>
-        <translation type="unfinished">Fehler bei der Herstellung einer sicheren Verbindung.</translation>
+        <translation>Fehler bei der Herstellung einer sicheren Verbindung.</translation>
     </message>
     <message>
         <source>Could not resolve the server&apos;s address. Please check your server name.</source>
-        <translation type="unfinished"></translation>
+        <translation>Konnte die Adresse des Servers nicht finden. Bitte überprüfen Sie Ihren Servernamen.</translation>
     </message>
     <message>
         <source>Could not connect to the server.</source>
-        <translation type="unfinished">Konnte nicht mit dem Server verbinden.</translation>
+        <translation type="obsolete">Konnte nicht mit dem Server verbinden.</translation>
     </message>
     <message>
         <source>Authentification protocol not supported by the server.</source>
-        <translation type="unfinished">Authentifizierungsprotokolle nicht vom Server unterstützt.</translation>
+        <translation>Authentifizierungsprotokolle nicht vom Server unterstützt.</translation>
     </message>
     <message>
         <source>This server does not support registration.</source>
-        <translation type="unfinished"></translation>
+        <translation>Dieser Server unterstützt keine Registrierung.</translation>
     </message>
     <message>
-        <source>An unknown error occured.</source>
-        <translation type="unfinished"></translation>
+        <source>The server is offline or blocked by a firewall.</source>
+        <translation>Der Server ist offline oder durch eine Firewall blockiert.</translation>
+    </message>
+    <message>
+        <source>The connection could not be refreshed.</source>
+        <translation>Die Verbindung konnte nicht aktualisiert werden.</translation>
+    </message>
+    <message>
+        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
+        <translation>Der Internetzugang ist nicht gestattet. Bitte überprüfen Sie die Internetzugangskonfiguration Ihres Systems.</translation>
+    </message>
+</context>
+<context>
+    <name>QrCodeGenerator</name>
+    <message>
+        <source>Generating the QR code failed: %1</source>
+        <translation>Fehler beim Generieren des QR-Codes: %1</translation>
     </message>
 </context>
 <context>
@@ -915,7 +1211,46 @@ Versuche andere Programme, welche die Kamera verwenden, zu schließen.</translat
     </message>
     <message>
         <source>The camera format &apos;%1&apos; is not supported.</source>
-        <translation>Das Kamera-Format &apos;%1&apos; wird nicht unterstüzt.</translation>
+        <translation>Das Kamera-Format „%1“ wird nicht unterstüzt.</translation>
+    </message>
+    <message>
+        <source>Logging in…</source>
+        <translation type="vanished">Anmeldung…</translation>
+    </message>
+    <message>
+        <source>Scan the QR code from your existing device to transfer your account.</source>
+        <translation>Scannen Sie den QR-Code von Ihrem vorhandenen Gerät, um Ihr Konto zu übertragen.</translation>
+    </message>
+    <message>
+        <source>Show explanation</source>
+        <translation>Erklärung anzeigen</translation>
+    </message>
+    <message>
+        <source>Scan</source>
+        <translation>Scannen</translation>
+    </message>
+    <message>
+        <source>Continue without QR code</source>
+        <translation>Ohne QR-Code fortfahren</translation>
+    </message>
+    <message>
+        <source>Connecting…</source>
+        <translation>Verbinden…</translation>
+    </message>
+</context>
+<context>
+    <name>RegistrationLoginDecisionPage</name>
+    <message>
+        <source>Set up</source>
+        <translation>Einrichten</translation>
+    </message>
+    <message>
+        <source>Register a new account</source>
+        <translation>Ein neues Konto registrieren</translation>
+    </message>
+    <message>
+        <source>Use an existing account</source>
+        <translation>Ein vorhandenes Konto verwenden</translation>
     </message>
 </context>
 <context>
@@ -929,6 +1264,23 @@ Versuche andere Programme, welche die Kamera verwenden, zu schließen.</translat
         <translation>Änderung des Passworts ist fehlgeschlagen: %1</translation>
     </message>
 </context>
+<context>
+    <name>RemoteAccountDeletion</name>
+    <message>
+        <source>Delete account completely</source>
+        <translation>Konto vollständig löschen</translation>
+    </message>
+    <message>
+        <source>Your account will be deleted completely, which means from this app and from the server.
+You will not be able to use your account again!</source>
+        <translation>Ihr Konto wird vollständig gelöscht sein, d.h. von dieser Anwendung und vom Server.
+Sie werden Ihr Konto nicht mehr benutzen können!</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Löschen</translation>
+    </message>
+</context>
 <context>
     <name>RosterAddContactSheet</name>
     <message>
@@ -1027,7 +1379,7 @@ Versuche andere Programme, welche die Kamera verwenden, zu schließen.</translat
     </message>
     <message>
         <source>Could not rename contact, as a result of not being connected.</source>
-        <translation>Konnte den Kontakt nicht umbenennen, da du nicht verbunden bist.</translation>
+        <translation>Konnte den Kontakt nicht umbenennen, da keine Verbindung besteht.</translation>
     </message>
 </context>
 <context>
@@ -1084,7 +1436,7 @@ Versuche andere Programme, welche die Kamera verwenden, zu schließen.</translat
     </message>
     <message>
         <source>Edit name:</source>
-        <translation>Namen bearbeiten:</translation>
+        <translation type="vanished">Namen bearbeiten:</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -1110,6 +1462,71 @@ Versuche andere Programme, welche die Kamera verwenden, zu schließen.</translat
         <translation>Beschriftung</translation>
     </message>
 </context>
+<context>
+    <name>ServerListModel</name>
+    <message>
+        <source>Custom server</source>
+        <translation>Benutzerdefinierter Server</translation>
+    </message>
+    <message>
+        <source>No limitation</source>
+        <extracomment>Unlimited file size for uploading files
+----------
+Deletion of message history saved on server</extracomment>
+        <translation>Keine Einschränkungen</translation>
+    </message>
+    <message>
+        <source>%1 days</source>
+        <translation>%1 Tage</translation>
+    </message>
+</context>
+<context>
+    <name>SettingsContent</name>
+    <message>
+        <source>Change password</source>
+        <translation>Passwort ändern</translation>
+    </message>
+    <message>
+        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
+        <translation>Ändert das Passwort Ihres Kontos. Sie werden das neue Passwort auf allen anderen Geräten neu eingeben müssen.</translation>
+    </message>
+    <message>
+        <source>Multimedia Settings</source>
+        <translation>Multimedia-Einstellungen</translation>
+    </message>
+    <message>
+        <source>Configure photo, video and audio recording settings</source>
+        <translation>Konfigurieren Sie die Einstellungen für Foto-, Video- und Audioaufnahmen</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>Einstellungen</translation>
+    </message>
+    <message>
+        <source>Account security</source>
+        <translation>Konto-Sicherheit</translation>
+    </message>
+    <message>
+        <source>configure whether this device can be used to log in on a new device</source>
+        <translation>Einstellen, ob dieses Gerät zum Anmelden an einem neuen Gerät verwendet werden kann</translation>
+    </message>
+    <message>
+        <source>Remove account from Kaidan</source>
+        <translation>Konto aus Kaidan entfernen</translation>
+    </message>
+    <message>
+        <source>Remove account from this app</source>
+        <translation>Konto aus dieser App entfernen</translation>
+    </message>
+    <message>
+        <source>Delete account</source>
+        <translation>Konto löschen</translation>
+    </message>
+    <message>
+        <source>Delete account from the server</source>
+        <translation>Konto auf dem Server löschen</translation>
+    </message>
+</context>
 <context>
     <name>SettingsPage</name>
     <message>
@@ -1118,19 +1535,33 @@ Versuche andere Programme, welche die Kamera verwenden, zu schließen.</translat
     </message>
     <message>
         <source>Change password</source>
-        <translation>Passwort ändern</translation>
+        <translation type="vanished">Passwort ändern</translation>
     </message>
     <message>
         <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
-        <translation>Das Passwort Ihres Kontos ändern. Sie werden das neue Passwort auf allen anderen Geräten neu eingeben müssen.</translation>
+        <translation type="vanished">Das Passwort Ihres Kontos ändern. Sie werden das neue Passwort auf allen anderen Geräten neu eingeben müssen.</translation>
     </message>
     <message>
         <source>Multimedia Settings</source>
-        <translation type="unfinished">Multimedia-Einstellungen</translation>
+        <translation type="obsolete">Multimedia-Einstellungen</translation>
+    </message>
+</context>
+<context>
+    <name>SettingsSheet</name>
+    <message>
+        <source>Settings</source>
+        <translation type="vanished">Einstellungen</translation>
+    </message>
+</context>
+<context>
+    <name>StartPage</name>
+    <message>
+        <source>Enjoy free communication on every device!</source>
+        <translation>Genießen Sie freie Kommunikation auf jedem Gerät!</translation>
     </message>
     <message>
-        <source>Configure photo, video and audio recording settings</source>
-        <translation type="unfinished"></translation>
+        <source>Let&apos;s start</source>
+        <translation>Fangen wir an</translation>
     </message>
 </context>
 <context>
@@ -1176,6 +1607,10 @@ Versuche andere Programme, welche die Kamera verwenden, zu schließen.</translat
         <source>File</source>
         <translation>Datei</translation>
     </message>
+    <message>
+        <source>Message could not be sent.</source>
+        <translation>Nachricht konnte nicht gesendet werden.</translation>
+    </message>
 </context>
 <context>
     <name>UserProfilePage</name>
@@ -1208,7 +1643,7 @@ Versuche andere Programme, welche die Kamera verwenden, zu schließen.</translat
     </message>
     <message>
         <source>Website</source>
-        <translation>Webseite</translation>
+        <translation>Website</translation>
     </message>
 </context>
 <context>
