@@ -19,6 +19,10 @@
         <source>View source code online</source>
         <translation>Vea el código fuente en línea</translation>
     </message>
+    <message>
+        <source>Report problems</source>
+        <translation>Informar de problemas</translation>
+    </message>
 </context>
 <context>
     <name>AboutSheet</name>
@@ -35,6 +39,125 @@
         <translation type="vanished">Código fuente en GitHub</translation>
     </message>
 </context>
+<context>
+    <name>AccountDeletionFromClientAndServerConfirmationPage</name>
+    <message>
+        <source>Delete account completely</source>
+        <translation type="vanished">Eliminar cuenta completamente</translation>
+    </message>
+    <message>
+        <source>Your account will be deleted completely, which means from this app and from the server.
+You will not be able to use your account again!</source>
+        <translation type="vanished">Su cuenta se eliminará por completo, es decir, tanto de esta aplicación como del servidor.
+No podrá utilizarla nuevamente.</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">Eliminar</translation>
+    </message>
+</context>
+<context>
+    <name>AccountDeletionFromClientConfirmationPage</name>
+    <message>
+        <source>Remove account from this app</source>
+        <translation type="vanished">Quitar cuenta de esta aplicación</translation>
+    </message>
+    <message>
+        <source>Your account will be removed from this app.
+You won&apos;t be able to get your credentials back!
+Make sure that you have backed up those if you want to use your account later.</source>
+        <translation type="vanished">Se quitará su cuenta de esta aplicación.
+No podrá recuperar sus datos de acceso.
+Cerciórese de tener una copia de respaldo de estos si quiere utilizar su cuenta después.</translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation type="vanished">Quitar</translation>
+    </message>
+</context>
+<context>
+    <name>AccountDeletionPage</name>
+    <message>
+        <source>Delete account</source>
+        <translation type="vanished">Eliminar cuenta</translation>
+    </message>
+    <message>
+        <source>You can remove your account &lt;b&gt;%1&lt;/b&gt; only from this app or delete it completely. If you delete your account completely, you won&apos;t be able to use it with another app because it is also removed from the server.</source>
+        <translation type="vanished">Puede quitar la cuenta &lt;b&gt;%1&lt;/b&gt; de esta aplicación únicamente o eliminarla por completo. Si la elimina completamente, no podrá utilizarla en otras aplicaciones porque desaparecerá también del servidor.</translation>
+    </message>
+    <message>
+        <source>Remove from this app</source>
+        <translation type="vanished">Quitar de esta aplicación</translation>
+    </message>
+    <message>
+        <source>Delete completely</source>
+        <translation type="vanished">Eliminar completamente</translation>
+    </message>
+</context>
+<context>
+    <name>AccountSecurity</name>
+    <message>
+        <source>Account Security</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disable showing the password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disable showing the QR-Code and password</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>AccountTransferPage</name>
+    <message>
+        <source>Transfer account to another device</source>
+        <translation>Transferir cuenta a otro dispositivo</translation>
+    </message>
+    <message>
+        <source>Scan the QR code or enter the credentials as text on another device to log in on it.
+
+Attention:
+Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
+        <translation>Escanee el código QR o proporcione los datos de acceso como texto en otro dispositivo para acceder a la cuenta.
+
+Atención:
+Jamás muestre este código QR a otras personas, dado que brinda acceso ilimitado a su cuenta.</translation>
+    </message>
+    <message>
+        <source>Chat address:</source>
+        <translation>Dirección de charla:</translation>
+    </message>
+    <message>
+        <source>Password:</source>
+        <translation>Contraseña:</translation>
+    </message>
+    <message>
+        <source>Hide QR code</source>
+        <translation>Ocultar código QR</translation>
+    </message>
+    <message>
+        <source>Show as QR code</source>
+        <translation>Mostrar como código QR</translation>
+    </message>
+    <message>
+        <source>Hide text</source>
+        <translation>Ocultar texto</translation>
+    </message>
+    <message>
+        <source>Show as text</source>
+        <translation>Mostrar como texto</translation>
+    </message>
+</context>
 <context>
     <name>BackButton</name>
     <message>
@@ -93,11 +216,11 @@
     </message>
     <message>
         <source>Copy Message</source>
-        <translation>Copiar mensaje</translation>
+        <translation type="vanished">Copiar mensaje</translation>
     </message>
     <message>
         <source>Edit Message</source>
-        <translation>Editar mensaje</translation>
+        <translation type="vanished">Editar mensaje</translation>
     </message>
     <message>
         <source>Spoiler</source>
@@ -109,11 +232,26 @@
     </message>
     <message>
         <source>Copy download URL</source>
-        <translation>Copiar URL de descarga</translation>
+        <translation type="vanished">Copiar URL de descarga</translation>
+    </message>
+</context>
+<context>
+    <name>ChatMessageContextMenu</name>
+    <message>
+        <source>Copy message</source>
+        <translation type="unfinished">Copiar mensaje</translation>
     </message>
     <message>
-        <source>Quote</source>
-        <translation type="unfinished"></translation>
+        <source>Edit message</source>
+        <translation type="unfinished">Editar mensaje</translation>
+    </message>
+    <message>
+        <source>Copy download URL</source>
+        <translation type="unfinished">Copiar URL de descarga</translation>
+    </message>
+    <message>
+        <source>Quote message</source>
+        <translation type="unfinished">Citar mensaje</translation>
     </message>
 </context>
 <context>
@@ -152,7 +290,7 @@
     </message>
     <message>
         <source>Select a file</source>
-        <translation>Elegir un archivo</translation>
+        <translation type="vanished">Elegir un archivo</translation>
     </message>
     <message>
         <source>Send a spoiler message</source>
@@ -198,6 +336,29 @@
         <source>All files</source>
         <translation>Todos los archivos</translation>
     </message>
+    <message>
+        <source>Copy message</source>
+        <translation type="vanished">Copiar mensaje</translation>
+    </message>
+    <message>
+        <source>Edit message</source>
+        <translation type="vanished">Editar mensaje</translation>
+    </message>
+    <message>
+        <source>Copy download URL</source>
+        <translation type="vanished">Copiar URL de descarga</translation>
+    </message>
+    <message>
+        <source>Quote message</source>
+        <translation type="vanished">Citar mensaje</translation>
+    </message>
+</context>
+<context>
+    <name>ClientWorker</name>
+    <message>
+        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
+        <translation>No se pudo eliminar la cuenta del servidor. Por ello, tampoco se ha quitado de esta aplicación: %1</translation>
+    </message>
 </context>
 <context>
     <name>CommonEncoderSettings</name>
@@ -238,6 +399,13 @@
         <translation>Dos pasadas</translation>
     </message>
 </context>
+<context>
+    <name>ConfirmationPage</name>
+    <message>
+        <source>Cancel</source>
+        <translation>Cancelar</translation>
+    </message>
+</context>
 <context>
     <name>ContextDrawer</name>
     <message>
@@ -245,6 +413,40 @@
         <translation type="vanished">Acciones</translation>
     </message>
 </context>
+<context>
+    <name>DisablePasswordDisplay</name>
+    <message>
+        <source>Remove password completely</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your password will not be included in the QR code anymore.
+You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
+Make sure that you backed it up if you want to use your account later.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove password</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>DisablePlainTextPasswordDisplay</name>
+    <message>
+        <source>Do not show password as text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your password will not be shown as text anymore.
+You won&apos;t be able to see your password as text again because this action cannot be undone!
+Make sure that you backed it up if you want to use your account later.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Do not show password</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>DownloadJob</name>
     <message>
@@ -314,7 +516,7 @@
     <name>FileChooser</name>
     <message>
         <source>Select a file</source>
-        <translation>Elegir un archivo</translation>
+        <translation type="vanished">Elegir un archivo</translation>
     </message>
 </context>
 <context>
@@ -325,11 +527,11 @@
     </message>
     <message>
         <source>Close</source>
-        <translation>Cerrar</translation>
+        <translation type="vanished">Cerrar</translation>
     </message>
     <message>
         <source>Go to parent folder</source>
-        <translation>Ir a la carpeta superior</translation>
+        <translation type="vanished">Ir a la carpeta superior</translation>
     </message>
 </context>
 <context>
@@ -347,7 +549,7 @@
     </message>
     <message>
         <source>Log out</source>
-        <translation>Salir</translation>
+        <translation type="vanished">Salir</translation>
     </message>
     <message>
         <source>About</source>
@@ -367,15 +569,27 @@
     </message>
     <message>
         <source>Offline</source>
-        <translation type="unfinished">Desconectado</translation>
+        <translation>Desconectado</translation>
     </message>
     <message>
         <source>Online</source>
-        <translation type="unfinished"></translation>
+        <translation>En línea</translation>
     </message>
     <message>
         <source>Connecting…</source>
-        <translation type="unfinished">Conectando…</translation>
+        <translation>Conectando…</translation>
+    </message>
+    <message>
+        <source>Transfer account</source>
+        <translation type="vanished">Transferir cuenta</translation>
+    </message>
+    <message>
+        <source>Delete account</source>
+        <translation type="vanished">Eliminar cuenta</translation>
+    </message>
+    <message>
+        <source>Switch device</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -415,13 +629,29 @@
     </message>
     <message>
         <source>No password found. Please enter it.</source>
-        <translation>No se encontró ninguna contraseña. Escríbala.</translation>
+        <translation type="vanished">No se encontró ninguna contraseña. Escríbala.</translation>
     </message>
     <message>
         <source>No valid login QR code found.</source>
         <translation>No se encontró ningún código QR de inicio de sesión válido.</translation>
     </message>
 </context>
+<context>
+    <name>LocalAccountRemoval</name>
+    <message>
+        <source>Remove account from this app</source>
+        <translation type="unfinished">Quitar cuenta de esta aplicación</translation>
+    </message>
+    <message>
+        <source>Your account will be removed from this app.
+Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation type="unfinished">Quitar</translation>
+    </message>
+</context>
 <context>
     <name>LoginPage</name>
     <message>
@@ -498,7 +728,7 @@
     </message>
     <message>
         <source>Log in using a QR-Code</source>
-        <translation>Acceder mediante código QR</translation>
+        <translation type="vanished">Acceder mediante código QR</translation>
     </message>
 </context>
 <context>
@@ -575,15 +805,15 @@
     <name>MessageHandler</name>
     <message>
         <source>Could not send message, as a result of not being connected.</source>
-        <translation>No se pudo enviar el mensaje porque no está conectado.</translation>
+        <translation type="vanished">No se pudo enviar el mensaje porque no está conectado.</translation>
     </message>
     <message>
         <source>Could not correct message, as a result of not being connected.</source>
-        <translation>No se pudo corregir el mensaje porque no está conectado.</translation>
+        <translation type="vanished">No se pudo corregir el mensaje porque no está conectado.</translation>
     </message>
     <message>
         <source>Spoiler</source>
-        <translation>«Spoiler»</translation>
+        <translation type="vanished">«Spoiler»</translation>
     </message>
     <message>
         <source>Message could not be sent.</source>
@@ -594,91 +824,110 @@
         <translation>Falló la corrección del mensaje.</translation>
     </message>
 </context>
+<context>
+    <name>MessageModel</name>
+    <message>
+        <source>Pending</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sent</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delivered</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished">Error</translation>
+    </message>
+</context>
 <context>
     <name>MultimediaSettings</name>
     <message>
         <source>Multimedia Settings</source>
-        <translation type="unfinished">Configuración de multimedia</translation>
+        <translation>Configuración de multimedia</translation>
     </message>
     <message>
         <source>Configure</source>
-        <translation type="unfinished">Configurar</translation>
+        <translation>Configurar</translation>
     </message>
     <message>
         <source>Image Capture</source>
-        <translation type="unfinished">Captura de imagen</translation>
+        <translation>Captura de imagen</translation>
     </message>
     <message>
         <source>Audio Recording</source>
-        <translation type="unfinished">Grabación de audio</translation>
+        <translation>Grabación de audio</translation>
     </message>
     <message>
         <source>Video Recording</source>
-        <translation type="unfinished">Grabación de vídeo</translation>
+        <translation>Grabación de vídeo</translation>
     </message>
     <message>
         <source>Camera</source>
-        <translation type="unfinished">Cámara</translation>
+        <translation>Cámara</translation>
     </message>
     <message>
         <source>Audio input</source>
-        <translation type="unfinished">Entrada de audio</translation>
+        <translation>Entrada de audio</translation>
     </message>
     <message>
         <source>Container</source>
-        <translation type="unfinished">Contenedor</translation>
+        <translation>Contenedor</translation>
     </message>
     <message>
         <source>Image</source>
-        <translation type="unfinished">Imagen</translation>
+        <translation>Imagen</translation>
     </message>
     <message>
         <source>Audio</source>
-        <translation type="unfinished">Audio</translation>
+        <translation>Audio</translation>
     </message>
     <message>
         <source>Video</source>
-        <translation type="unfinished">Vídeo</translation>
+        <translation>Vídeo</translation>
     </message>
     <message>
         <source>Codec</source>
-        <translation type="unfinished">Códec</translation>
+        <translation>Códec</translation>
     </message>
     <message>
         <source>Resolution</source>
-        <translation type="unfinished">Resolución</translation>
+        <translation>Resolución</translation>
     </message>
     <message>
         <source>Quality</source>
-        <translation type="unfinished">Calidad</translation>
+        <translation>Calidad</translation>
     </message>
     <message>
         <source>Sample Rate</source>
-        <translation type="unfinished">Tasa de muestreo</translation>
+        <translation>Tasa de muestreo</translation>
     </message>
     <message>
         <source>Frame Rate</source>
-        <translation type="unfinished">Tasa de fotogramas</translation>
+        <translation>Tasa de fotogramas</translation>
     </message>
     <message>
         <source>Ready</source>
-        <translation type="unfinished">Preparado</translation>
+        <translation>Preparado</translation>
     </message>
     <message>
-        <source>Initializing...</source>
-        <translation type="unfinished">Iniciando…</translation>
+        <source>Initializing…</source>
+        <translation>Iniciando…</translation>
     </message>
     <message>
         <source>Unavailable</source>
-        <translation type="unfinished">No disponible</translation>
+        <translation>No disponible</translation>
     </message>
     <message>
-        <source>Recording...</source>
-        <translation type="unfinished">Grabando…</translation>
+        <source>Recording…</source>
+        <translation>Grabando…</translation>
     </message>
     <message>
         <source>Paused</source>
-        <translation type="unfinished">En pausa</translation>
+        <translation>En pausa</translation>
     </message>
 </context>
 <context>
@@ -752,7 +1001,7 @@
         <translation type="vanished">Preparado</translation>
     </message>
     <message>
-        <source>Initializing...</source>
+        <source>Initializing…</source>
         <translation type="vanished">Iniciando…</translation>
     </message>
     <message>
@@ -760,7 +1009,7 @@
         <translation type="vanished">No disponible</translation>
     </message>
     <message>
-        <source>Recording...</source>
+        <source>Recording…</source>
         <translation type="vanished">Grabando…</translation>
     </message>
     <message>
@@ -775,7 +1024,7 @@
         <translation>Preparado</translation>
     </message>
     <message>
-        <source>Initializing...</source>
+        <source>Initializing…</source>
         <translation>Iniciando…</translation>
     </message>
     <message>
@@ -783,7 +1032,7 @@
         <translation>No disponible</translation>
     </message>
     <message>
-        <source>Recording... %1</source>
+        <source>Recording… %1</source>
         <translation>Grabando… %1</translation>
     </message>
     <message>
@@ -791,6 +1040,32 @@
         <translation>%1 en pausa</translation>
     </message>
 </context>
+<context>
+    <name>PasswordRemovalPage</name>
+    <message>
+        <source>Remove password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Do not show password as text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove completely</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Mark as read</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QmlUtils</name>
     <message>
@@ -823,43 +1098,58 @@
     </message>
     <message>
         <source>Invisible</source>
-        <translation>Invisible</translation>
+        <translation type="vanished">Invisible</translation>
     </message>
     <message>
         <source>Invalid username or password.</source>
-        <translation type="unfinished">Usuario o contraseña no válido.</translation>
+        <translation>Usuario o contraseña no válido.</translation>
     </message>
     <message>
         <source>Cannot connect to the server. Please check your internet connection.</source>
-        <translation type="unfinished">No se puede conectar al servidor. Compruebe su conexión a internet.</translation>
+        <translation>No se puede conectar con el servidor. Compruebe su conexión a internet.</translation>
     </message>
     <message>
         <source>The server doesn&apos;t support secure connections.</source>
-        <translation type="unfinished">El servidor no admite conexiones seguras.</translation>
+        <translation>El servidor no admite conexiones seguras.</translation>
     </message>
     <message>
         <source>Error while trying to connect securely.</source>
-        <translation type="unfinished">Error al intentar conectar de forma segura.</translation>
+        <translation>Error al intentar conectar de forma segura.</translation>
     </message>
     <message>
         <source>Could not resolve the server&apos;s address. Please check your server name.</source>
-        <translation type="unfinished"></translation>
+        <translation>No se pudo resolver la dirección del servidor. Compruebe el nombre del servidor.</translation>
     </message>
     <message>
         <source>Could not connect to the server.</source>
-        <translation type="unfinished">No se pudo conectar al servidor.</translation>
+        <translation type="obsolete">No se pudo conectar al servidor.</translation>
     </message>
     <message>
         <source>Authentification protocol not supported by the server.</source>
-        <translation type="unfinished">El protocolo de autenticación no es compatible con el servidor.</translation>
+        <translation>El servidor no admite el protocolo de autenticación.</translation>
     </message>
     <message>
         <source>This server does not support registration.</source>
-        <translation type="unfinished"></translation>
+        <translation>Este servidor no admite registros.</translation>
     </message>
     <message>
-        <source>An unknown error occured.</source>
-        <translation type="unfinished"></translation>
+        <source>The server is offline or blocked by a firewall.</source>
+        <translation>El servidor está desconectado o bloqueado por un cortafuegos.</translation>
+    </message>
+    <message>
+        <source>The connection could not be refreshed.</source>
+        <translation>No se pudo actualizar la conexión.</translation>
+    </message>
+    <message>
+        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
+        <translation>No se permite el acceso a internet. Compruebe la configuración de acceso a internet del sistema.</translation>
+    </message>
+</context>
+<context>
+    <name>QrCodeGenerator</name>
+    <message>
+        <source>Generating the QR code failed: %1</source>
+        <translation>Falló la generación del código QR: %1</translation>
     </message>
 </context>
 <context>
@@ -882,6 +1172,45 @@ Pruebe a cerrar otras aplicaciones que utilicen la cámara.</translation>
         <source>The camera format &apos;%1&apos; is not supported.</source>
         <translation>No se admite el formato «%1» de la cámara.</translation>
     </message>
+    <message>
+        <source>Logging in…</source>
+        <translation type="vanished">Accediendo…</translation>
+    </message>
+    <message>
+        <source>Scan the QR code from your existing device to transfer your account.</source>
+        <translation>Escanee el código QR desde su dispositivo existente para transferir su cuenta.</translation>
+    </message>
+    <message>
+        <source>Show explanation</source>
+        <translation>Mostrar explicación</translation>
+    </message>
+    <message>
+        <source>Scan</source>
+        <translation>Escanear</translation>
+    </message>
+    <message>
+        <source>Continue without QR code</source>
+        <translation>Continuar sin código QR</translation>
+    </message>
+    <message>
+        <source>Connecting…</source>
+        <translation type="unfinished">Conectando…</translation>
+    </message>
+</context>
+<context>
+    <name>RegistrationLoginDecisionPage</name>
+    <message>
+        <source>Set up</source>
+        <translation>Configurar</translation>
+    </message>
+    <message>
+        <source>Register a new account</source>
+        <translation>Registrar cuenta nueva</translation>
+    </message>
+    <message>
+        <source>Use an existing account</source>
+        <translation>Utilizar cuenta existente</translation>
+    </message>
 </context>
 <context>
     <name>RegistrationManager</name>
@@ -894,19 +1223,36 @@ Pruebe a cerrar otras aplicaciones que utilicen la cámara.</translation>
         <translation>Error al cambiar la contraseña: %1</translation>
     </message>
 </context>
+<context>
+    <name>RemoteAccountDeletion</name>
+    <message>
+        <source>Delete account completely</source>
+        <translation type="unfinished">Eliminar cuenta completamente</translation>
+    </message>
+    <message>
+        <source>Your account will be deleted completely, which means from this app and from the server.
+You will not be able to use your account again!</source>
+        <translation type="unfinished">Su cuenta se eliminará por completo, es decir, tanto de esta aplicación como del servidor.
+No podrá utilizarla nuevamente.</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RosterAddContactSheet</name>
     <message>
         <source>Add new contact</source>
-        <translation>Añadir nuevo contacto</translation>
+        <translation>Añadir contacto nuevo</translation>
     </message>
     <message>
         <source>Nickname:</source>
-        <translation>Alias:</translation>
+        <translation>Apodo:</translation>
     </message>
     <message>
         <source>Jabber-ID:</source>
-        <translation>Jabber-ID:</translation>
+        <translation>Id. de Jabber:</translation>
     </message>
     <message>
         <source>user@example.org</source>
@@ -1049,7 +1395,7 @@ Pruebe a cerrar otras aplicaciones que utilicen la cámara.</translation>
     </message>
     <message>
         <source>Edit name:</source>
-        <translation>Editar nombre:</translation>
+        <translation type="vanished">Editar nombre:</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -1076,11 +1422,25 @@ Pruebe a cerrar otras aplicaciones que utilicen la cámara.</translation>
     </message>
 </context>
 <context>
-    <name>SettingsPage</name>
+    <name>ServerListModel</name>
     <message>
-        <source>Settings</source>
-        <translation>Configuración</translation>
+        <source>Custom server</source>
+        <translation>Servidor personalizado</translation>
     </message>
+    <message>
+        <source>No limitation</source>
+        <extracomment>Unlimited file size for uploading files
+----------
+Deletion of message history saved on server</extracomment>
+        <translation>Sin límites</translation>
+    </message>
+    <message>
+        <source>%1 days</source>
+        <translation>%1 días</translation>
+    </message>
+</context>
+<context>
+    <name>SettingsContent</name>
     <message>
         <source>Change password</source>
         <translation>Cambiar contraseña</translation>
@@ -1091,12 +1451,77 @@ Pruebe a cerrar otras aplicaciones que utilicen la cámara.</translation>
     </message>
     <message>
         <source>Multimedia Settings</source>
-        <translation type="unfinished">Configuración de multimedia</translation>
+        <translation>Configuración de multimedia</translation>
     </message>
     <message>
         <source>Configure photo, video and audio recording settings</source>
+        <translation>Defina las opciones de grabación de imágenes, vídeo y audio</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation type="unfinished">Configuración</translation>
+    </message>
+    <message>
+        <source>Account security</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>configure whether this device can be used to log in on a new device</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove account from Kaidan</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove account from this app</source>
+        <translation type="unfinished">Quitar cuenta de esta aplicación</translation>
+    </message>
+    <message>
+        <source>Delete account</source>
+        <translation type="unfinished">Eliminar cuenta</translation>
+    </message>
+    <message>
+        <source>Delete account from the server</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SettingsPage</name>
+    <message>
+        <source>Settings</source>
+        <translation>Configuración</translation>
+    </message>
+    <message>
+        <source>Change password</source>
+        <translation type="vanished">Cambiar contraseña</translation>
+    </message>
+    <message>
+        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
+        <translation type="vanished">Cambia la contraseña de su cuenta. Necesitará introducirla en todos sus dispositivos.</translation>
+    </message>
+    <message>
+        <source>Multimedia Settings</source>
+        <translation type="obsolete">Configuración de multimedia</translation>
+    </message>
+</context>
+<context>
+    <name>SettingsSheet</name>
+    <message>
+        <source>Settings</source>
+        <translation type="vanished">Configuración</translation>
+    </message>
+</context>
+<context>
+    <name>StartPage</name>
+    <message>
+        <source>Enjoy free communication on every device!</source>
+        <translation>Disfrute de comunicación libre y gratuita en cualquier dispositivo.</translation>
+    </message>
+    <message>
+        <source>Let&apos;s start</source>
+        <translation>Empezar</translation>
+    </message>
 </context>
 <context>
     <name>SubRequestAcceptSheet</name>
@@ -1141,6 +1566,10 @@ Pruebe a cerrar otras aplicaciones que utilicen la cámara.</translation>
         <source>File</source>
         <translation>Archivo</translation>
     </message>
+    <message>
+        <source>Message could not be sent.</source>
+        <translation type="unfinished">No se pudo enviar el mensaje.</translation>
+    </message>
 </context>
 <context>
     <name>UserProfilePage</name>
