@@ -15,6 +15,78 @@
         <source>View source code online</source>
         <translation>Ikusi iturburu kodea linean</translation>
     </message>
+    <message>
+        <source>Report problems</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>AccountDeletionFromClientAndServerConfirmationPage</name>
+    <message>
+        <source>Delete</source>
+        <translation type="obsolete">Ezabatu</translation>
+    </message>
+</context>
+<context>
+    <name>AccountSecurity</name>
+    <message>
+        <source>Account Security</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disable showing the password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disable showing the QR-Code and password</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>AccountTransferPage</name>
+    <message>
+        <source>Transfer account to another device</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scan the QR code or enter the credentials as text on another device to log in on it.
+
+Attention:
+Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Chat address:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Password:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide QR code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show as QR code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show as text</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>BackButton</name>
@@ -74,11 +146,11 @@
     </message>
     <message>
         <source>Copy Message</source>
-        <translation>Mezua kopiatu</translation>
+        <translation type="vanished">Mezua kopiatu</translation>
     </message>
     <message>
         <source>Edit Message</source>
-        <translation>Mezua editatu</translation>
+        <translation type="vanished">Mezua editatu</translation>
     </message>
     <message>
         <source>Spoiler</source>
@@ -88,12 +160,23 @@
         <source>Download</source>
         <translation>Deskargatu</translation>
     </message>
+</context>
+<context>
+    <name>ChatMessageContextMenu</name>
+    <message>
+        <source>Copy message</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Edit message</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Copy download URL</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Quote</source>
+        <source>Quote message</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -125,7 +208,7 @@
     </message>
     <message>
         <source>Select a file</source>
-        <translation>Artxibo bat aukeratu</translation>
+        <translation type="vanished">Artxibo bat aukeratu</translation>
     </message>
     <message>
         <source>Send a spoiler message</source>
@@ -168,6 +251,13 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>ClientWorker</name>
+    <message>
+        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>CommonEncoderSettings</name>
     <message>
@@ -207,6 +297,13 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>ConfirmationPage</name>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">Utzi</translation>
+    </message>
+</context>
 <context>
     <name>ContextDrawer</name>
     <message>
@@ -214,6 +311,40 @@
         <translation type="vanished">Jarduerak</translation>
     </message>
 </context>
+<context>
+    <name>DisablePasswordDisplay</name>
+    <message>
+        <source>Remove password completely</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your password will not be included in the QR code anymore.
+You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
+Make sure that you backed it up if you want to use your account later.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove password</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>DisablePlainTextPasswordDisplay</name>
+    <message>
+        <source>Do not show password as text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your password will not be shown as text anymore.
+You won&apos;t be able to see your password as text again because this action cannot be undone!
+Make sure that you backed it up if you want to use your account later.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Do not show password</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>DownloadJob</name>
     <message>
@@ -283,7 +414,7 @@
     <name>FileChooser</name>
     <message>
         <source>Select a file</source>
-        <translation>Artxibo bat aukeratu</translation>
+        <translation type="vanished">Artxibo bat aukeratu</translation>
     </message>
 </context>
 <context>
@@ -294,11 +425,11 @@
     </message>
     <message>
         <source>Close</source>
-        <translation>Itxi</translation>
+        <translation type="vanished">Itxi</translation>
     </message>
     <message>
         <source>Go to parent folder</source>
-        <translation>Karpeta nagusira joan</translation>
+        <translation type="vanished">Karpeta nagusira joan</translation>
     </message>
 </context>
 <context>
@@ -316,7 +447,7 @@
     </message>
     <message>
         <source>Log out</source>
-        <translation>Saioa itxi</translation>
+        <translation type="vanished">Saioa itxi</translation>
     </message>
     <message>
         <source>About</source>
@@ -346,6 +477,10 @@
         <source>Connecting…</source>
         <translation type="unfinished">Konektatzen…</translation>
     </message>
+    <message>
+        <source>Switch device</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Kaidan</name>
@@ -371,11 +506,23 @@
         <translation type="vanished">Ezin izan da artxiboa bidali, konektaturik ez zaudelako.</translation>
     </message>
     <message>
-        <source>No password found. Please enter it.</source>
+        <source>No valid login QR code found.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LocalAccountRemoval</name>
+    <message>
+        <source>Remove account from this app</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>No valid login QR code found.</source>
+        <source>Your account will be removed from this app.
+Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -449,10 +596,6 @@
         <source>An unknown error occured; see log for details.</source>
         <translation type="vanished">Akats ezezagun bat gertatu da; ikusi xehetasunak log edo erregistroetan.</translation>
     </message>
-    <message>
-        <source>Log in using a QR-Code</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>MediaRecorder</name>
@@ -528,15 +671,15 @@
     <name>MessageHandler</name>
     <message>
         <source>Could not send message, as a result of not being connected.</source>
-        <translation>Ezin izan da mezua bidali, konektaturik ez  dagoelako.</translation>
+        <translation type="vanished">Ezin izan da mezua bidali, konektaturik ez  dagoelako.</translation>
     </message>
     <message>
         <source>Could not correct message, as a result of not being connected.</source>
-        <translation>Ezin izan da mezua zuzendu konektaturik ez zaudelako.</translation>
+        <translation type="vanished">Ezin izan da mezua zuzendu konektaturik ez zaudelako.</translation>
     </message>
     <message>
         <source>Spoiler</source>
-        <translation>«Spoiler»</translation>
+        <translation type="vanished">«Spoiler»</translation>
     </message>
     <message>
         <source>Message could not be sent.</source>
@@ -547,6 +690,25 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>MessageModel</name>
+    <message>
+        <source>Pending</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sent</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delivered</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished">Errorea</translation>
+    </message>
+</context>
 <context>
     <name>MultimediaSettings</name>
     <message>
@@ -618,7 +780,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Initializing...</source>
+        <source>Initializing…</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -626,7 +788,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Recording...</source>
+        <source>Recording…</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -656,7 +818,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Initializing...</source>
+        <source>Initializing…</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -664,7 +826,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Recording... %1</source>
+        <source>Recording… %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -672,6 +834,32 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>PasswordRemovalPage</name>
+    <message>
+        <source>Remove password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Do not show password as text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove completely</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Mark as read</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QmlUtils</name>
     <message>
@@ -702,10 +890,6 @@
         <source>Error</source>
         <translation type="unfinished">Errorea</translation>
     </message>
-    <message>
-        <source>Invisible</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Invalid username or password.</source>
         <translation type="unfinished">Erabiltzaile edo pasahitz okerra.</translation>
@@ -728,7 +912,7 @@
     </message>
     <message>
         <source>Could not connect to the server.</source>
-        <translation type="unfinished">Ezin izan da zerbitzarira konektatu.</translation>
+        <translation type="obsolete">Ezin izan da zerbitzarira konektatu.</translation>
     </message>
     <message>
         <source>Authentification protocol not supported by the server.</source>
@@ -739,7 +923,22 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>An unknown error occured.</source>
+        <source>The server is offline or blocked by a firewall.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The connection could not be refreshed.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>QrCodeGenerator</name>
+    <message>
+        <source>Generating the QR code failed: %1</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -762,6 +961,41 @@ Try to close other applications using the camera.</source>
         <source>The camera format &apos;%1&apos; is not supported.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Scan the QR code from your existing device to transfer your account.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show explanation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scan</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Continue without QR code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connecting…</source>
+        <translation type="unfinished">Konektatzen…</translation>
+    </message>
+</context>
+<context>
+    <name>RegistrationLoginDecisionPage</name>
+    <message>
+        <source>Set up</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Register a new account</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use an existing account</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RegistrationManager</name>
@@ -774,6 +1008,22 @@ Try to close other applications using the camera.</source>
         <translation>Akatsa pasahitza aldatzean: %1</translation>
     </message>
 </context>
+<context>
+    <name>RemoteAccountDeletion</name>
+    <message>
+        <source>Delete account completely</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your account will be deleted completely, which means from this app and from the server.
+You will not be able to use your account again!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished">Ezabatu</translation>
+    </message>
+</context>
 <context>
     <name>RosterAddContactSheet</name>
     <message>
@@ -919,10 +1169,6 @@ Try to close other applications using the camera.</source>
         <source>Rename contact</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Edit name:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Cancel</source>
         <translation type="unfinished">Utzi</translation>
@@ -948,18 +1194,32 @@ Try to close other applications using the camera.</source>
     </message>
 </context>
 <context>
-    <name>SettingsPage</name>
+    <name>ServerListModel</name>
     <message>
-        <source>Settings</source>
-        <translation>Ezarpenak</translation>
+        <source>Custom server</source>
+        <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>No limitation</source>
+        <extracomment>Unlimited file size for uploading files
+----------
+Deletion of message history saved on server</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 days</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SettingsContent</name>
     <message>
         <source>Change password</source>
-        <translation>Pasahitza aldatu</translation>
+        <translation type="unfinished">Pasahitza aldatu</translation>
     </message>
     <message>
         <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
-        <translation>Zure kontuaren pasahitza aldatzen du. Zure gainontzeko gailuetan berriro sartu beharko duzu.</translation>
+        <translation type="unfinished">Zure kontuaren pasahitza aldatzen du. Zure gainontzeko gailuetan berriro sartu beharko duzu.</translation>
     </message>
     <message>
         <source>Multimedia Settings</source>
@@ -969,6 +1229,67 @@ Try to close other applications using the camera.</source>
         <source>Configure photo, video and audio recording settings</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Settings</source>
+        <translation type="unfinished">Ezarpenak</translation>
+    </message>
+    <message>
+        <source>Account security</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>configure whether this device can be used to log in on a new device</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove account from Kaidan</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove account from this app</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete account</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete account from the server</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SettingsPage</name>
+    <message>
+        <source>Settings</source>
+        <translation>Ezarpenak</translation>
+    </message>
+    <message>
+        <source>Change password</source>
+        <translation type="vanished">Pasahitza aldatu</translation>
+    </message>
+    <message>
+        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
+        <translation type="vanished">Zure kontuaren pasahitza aldatzen du. Zure gainontzeko gailuetan berriro sartu beharko duzu.</translation>
+    </message>
+</context>
+<context>
+    <name>SettingsSheet</name>
+    <message>
+        <source>Settings</source>
+        <translation type="obsolete">Ezarpenak</translation>
+    </message>
+</context>
+<context>
+    <name>StartPage</name>
+    <message>
+        <source>Enjoy free communication on every device!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Let&apos;s start</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SubRequestAcceptSheet</name>
@@ -999,6 +1320,10 @@ Try to close other applications using the camera.</source>
         <source>File</source>
         <translation>Artxiboa</translation>
     </message>
+    <message>
+        <source>Message could not be sent.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UserProfilePage</name>
