@@ -19,6 +19,10 @@
         <source>View source code online</source>
         <translation>Voir le code source en ligne</translation>
     </message>
+    <message>
+        <source>Report problems</source>
+        <translation>Signaler un problème</translation>
+    </message>
 </context>
 <context>
     <name>AboutPage</name>
@@ -54,6 +58,125 @@
         <translation type="vanished">Code source sur GitHub</translation>
     </message>
 </context>
+<context>
+    <name>AccountDeletionFromClientAndServerConfirmationPage</name>
+    <message>
+        <source>Delete account completely</source>
+        <translation type="vanished">Supprimer le compte définitivement</translation>
+    </message>
+    <message>
+        <source>Your account will be deleted completely, which means from this app and from the server.
+You will not be able to use your account again!</source>
+        <translation type="vanished">Votre compte va être définitivement supprimé. C&apos;est à dire sur l&apos;application locale et sur le serveur.
+Vous ne serez plus en capacité d&apos;utiliser ce compte à nouveau !</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">Supprimer</translation>
+    </message>
+</context>
+<context>
+    <name>AccountDeletionFromClientConfirmationPage</name>
+    <message>
+        <source>Remove account from this app</source>
+        <translation type="vanished">Supprimer ce compte de l&apos;application</translation>
+    </message>
+    <message>
+        <source>Your account will be removed from this app.
+You won&apos;t be able to get your credentials back!
+Make sure that you have backed up those if you want to use your account later.</source>
+        <translation type="vanished">Votre compte va être supprimé de l&apos;application.
+Vous n&apos;aurez plus accès à vos identifiants !
+Assurez vous d&apos;en avoir fais une copie si vous comptez réutiliser ce compte plus tard.</translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation type="vanished">Supprimer</translation>
+    </message>
+</context>
+<context>
+    <name>AccountDeletionPage</name>
+    <message>
+        <source>Delete account</source>
+        <translation type="vanished">Supprimer le compte</translation>
+    </message>
+    <message>
+        <source>You can remove your account &lt;b&gt;%1&lt;/b&gt; only from this app or delete it completely. If you delete your account completely, you won&apos;t be able to use it with another app because it is also removed from the server.</source>
+        <translation type="vanished">Vous pouver supprimer votre compte &lt;b&gt;%1&lt;/b&gt; seulement de l&apos;application ou complètement. Si vous supprimez complètement votre compte, vous ne pourrez plus l&apos;utiliser avec une autre application parce qu&apos;il sera aussi supprimé du server.</translation>
+    </message>
+    <message>
+        <source>Remove from this app</source>
+        <translation type="vanished">Supprimer de l&apos;application</translation>
+    </message>
+    <message>
+        <source>Delete completely</source>
+        <translation type="vanished">Supprimer définitivement</translation>
+    </message>
+</context>
+<context>
+    <name>AccountSecurity</name>
+    <message>
+        <source>Account Security</source>
+        <translation>Sécurité du compte</translation>
+    </message>
+    <message>
+        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
+        <translation>Autoriser l&apos;ajout de nouveaux appareils en utilisant un code QR, mais ne jamais afficher le mot de passe sous forme de texte. Cette action ne peut pas être annulée, veuillez donc envisager de stocker le mot de passe d&apos;une autre manière avant de l&apos;utiliser.</translation>
+    </message>
+    <message>
+        <source>Disable showing the password</source>
+        <translation>Désactiver l&apos;affichage du mot de passe</translation>
+    </message>
+    <message>
+        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
+        <translation>N&apos;expose pas le mot de passe sous quelque forme que ce soit. Cette action ne peut pas être annulée.</translation>
+    </message>
+    <message>
+        <source>Disable showing the QR-Code and password</source>
+        <translation>Désactiver l&apos;affichage du code QR et d mot de passe</translation>
+    </message>
+</context>
+<context>
+    <name>AccountTransferPage</name>
+    <message>
+        <source>Transfer account to another device</source>
+        <translation>Transférer le compte vers un autre appareil</translation>
+    </message>
+    <message>
+        <source>Scan the QR code or enter the credentials as text on another device to log in on it.
+
+Attention:
+Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
+        <translation>Scannez le QR code ou entrez les identifiants sur un autre appareil pour vous y connecter.
+
+Attention :
+Ne montrez ce QR code à personne d&apos;autre. Il permet un accès complet à votre compte !</translation>
+    </message>
+    <message>
+        <source>Chat address:</source>
+        <translation>Adresse de clavardage :</translation>
+    </message>
+    <message>
+        <source>Password:</source>
+        <translation>Mot de passe :</translation>
+    </message>
+    <message>
+        <source>Hide QR code</source>
+        <translation>Cacher le QR code</translation>
+    </message>
+    <message>
+        <source>Show as QR code</source>
+        <translation>Afficher comme QR code</translation>
+    </message>
+    <message>
+        <source>Hide text</source>
+        <translation>Cacher le texte</translation>
+    </message>
+    <message>
+        <source>Show as text</source>
+        <translation>Afficher comme texte</translation>
+    </message>
+</context>
 <context>
     <name>BackButton</name>
     <message>
@@ -101,7 +224,7 @@
     </message>
     <message>
         <source>Change</source>
-        <translation>Modifier</translation>
+        <translation>Changer</translation>
     </message>
 </context>
 <context>
@@ -112,11 +235,11 @@
     </message>
     <message>
         <source>Copy Message</source>
-        <translation>Copier le message</translation>
+        <translation type="vanished">Copier le message</translation>
     </message>
     <message>
         <source>Edit Message</source>
-        <translation>Modifier le message</translation>
+        <translation type="vanished">Modifier le message</translation>
     </message>
     <message>
         <source>Spoiler</source>
@@ -126,13 +249,28 @@
         <source>Download</source>
         <translation>Télécharger</translation>
     </message>
+    <message>
+        <source>Copy download URL</source>
+        <translation type="vanished">Copier le lien de téléchargement</translation>
+    </message>
+</context>
+<context>
+    <name>ChatMessageContextMenu</name>
+    <message>
+        <source>Copy message</source>
+        <translation>Copier le message</translation>
+    </message>
+    <message>
+        <source>Edit message</source>
+        <translation>Modifier le message</translation>
+    </message>
     <message>
         <source>Copy download URL</source>
         <translation>Copier le lien de téléchargement</translation>
     </message>
     <message>
-        <source>Quote</source>
-        <translation type="unfinished"></translation>
+        <source>Quote message</source>
+        <translation>Citer le message</translation>
     </message>
 </context>
 <context>
@@ -167,7 +305,7 @@
     </message>
     <message>
         <source>Select a file</source>
-        <translation>Sélectionner un fichier</translation>
+        <translation type="vanished">Sélectionner un fichier</translation>
     </message>
     <message>
         <source>Send a spoiler message</source>
@@ -213,6 +351,29 @@
         <source>All files</source>
         <translation>Tous les fichiers</translation>
     </message>
+    <message>
+        <source>Copy message</source>
+        <translation type="vanished">Copier le message</translation>
+    </message>
+    <message>
+        <source>Edit message</source>
+        <translation type="vanished">Modifier le message</translation>
+    </message>
+    <message>
+        <source>Copy download URL</source>
+        <translation type="vanished">Copier le lien de téléchargement</translation>
+    </message>
+    <message>
+        <source>Quote message</source>
+        <translation type="vanished">Citer le message</translation>
+    </message>
+</context>
+<context>
+    <name>ClientWorker</name>
+    <message>
+        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
+        <translation>Votre compte ne peut pas être supprimé du serveur. Il m&apos;a pas été non plus supprimé de l&apos;application : %1</translation>
+    </message>
 </context>
 <context>
     <name>CommonEncoderSettings</name>
@@ -253,6 +414,13 @@
         <translation>Deux passes</translation>
     </message>
 </context>
+<context>
+    <name>ConfirmationPage</name>
+    <message>
+        <source>Cancel</source>
+        <translation>Annuler</translation>
+    </message>
+</context>
 <context>
     <name>ContextDrawer</name>
     <message>
@@ -260,6 +428,44 @@
         <translation type="vanished">Actions</translation>
     </message>
 </context>
+<context>
+    <name>DisablePasswordDisplay</name>
+    <message>
+        <source>Remove password completely</source>
+        <translation>Supprimer complètement le mot de passe</translation>
+    </message>
+    <message>
+        <source>Your password will not be included in the QR code anymore.
+You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
+Make sure that you backed it up if you want to use your account later.</source>
+        <translation>Votre mot de passe ne sera plus inclus dans le code QR.
+Vous ne pourrez plus utiliser la connexion par code QR sans saisir de nouveau votre mot de passe car cette action ne peut pas être annulée !
+Assurez-vous que vous l&apos;avez sauvegardé si vous voulez utiliser votre compte plus tard.</translation>
+    </message>
+    <message>
+        <source>Remove password</source>
+        <translation>Supprimer le mot de passe</translation>
+    </message>
+</context>
+<context>
+    <name>DisablePlainTextPasswordDisplay</name>
+    <message>
+        <source>Do not show password as text</source>
+        <translation>Ne pas afficher le mot de passe sous forme de texte</translation>
+    </message>
+    <message>
+        <source>Your password will not be shown as text anymore.
+You won&apos;t be able to see your password as text again because this action cannot be undone!
+Make sure that you backed it up if you want to use your account later.</source>
+        <translation>Votre mot de passe ne sera plus affiché sous forme de texte.
+Vous ne pourrez plus voir votre mot de passe sous forme de texte car cette action ne peut pas être annulée !
+Assurez-vous que vous l&apos;avez sauvegardé si vous voulez utiliser votre compte plus tard.</translation>
+    </message>
+    <message>
+        <source>Do not show password</source>
+        <translation>Ne pas afficher le mot de passe</translation>
+    </message>
+</context>
 <context>
     <name>DownloadJob</name>
     <message>
@@ -287,7 +493,7 @@
     </message>
     <message>
         <source>Food</source>
-        <translation>Aliments</translation>
+        <translation>Nourriture</translation>
     </message>
     <message>
         <source>Activity</source>
@@ -329,7 +535,7 @@
     <name>FileChooser</name>
     <message>
         <source>Select a file</source>
-        <translation>Sélectionnez un fichier</translation>
+        <translation type="vanished">Sélectionnez un fichier</translation>
     </message>
 </context>
 <context>
@@ -340,11 +546,11 @@
     </message>
     <message>
         <source>Close</source>
-        <translation>Fermer</translation>
+        <translation type="vanished">Fermer</translation>
     </message>
     <message>
         <source>Go to parent folder</source>
-        <translation>Aller au dossier parent</translation>
+        <translation type="vanished">Aller au dossier parent</translation>
     </message>
 </context>
 <context>
@@ -358,7 +564,7 @@
     <name>GlobalDrawer</name>
     <message>
         <source>Log out</source>
-        <translation>Se déconnecter</translation>
+        <translation type="vanished">Se déconnecter</translation>
     </message>
     <message>
         <source>About</source>
@@ -386,15 +592,27 @@
     </message>
     <message>
         <source>Offline</source>
-        <translation type="unfinished">Hors ligne</translation>
+        <translation>Hors ligne</translation>
     </message>
     <message>
         <source>Online</source>
-        <translation type="unfinished"></translation>
+        <translation>En ligne</translation>
     </message>
     <message>
         <source>Connecting…</source>
-        <translation type="unfinished">Connexion en cours…</translation>
+        <translation>Connexion en cours…</translation>
+    </message>
+    <message>
+        <source>Transfer account</source>
+        <translation type="vanished">Transférer le compte</translation>
+    </message>
+    <message>
+        <source>Delete account</source>
+        <translation type="vanished">Supprimer le compte</translation>
+    </message>
+    <message>
+        <source>Switch device</source>
+        <translation>Permuter d&apos;appareil</translation>
     </message>
 </context>
 <context>
@@ -422,13 +640,30 @@
     </message>
     <message>
         <source>No password found. Please enter it.</source>
-        <translation>Aucun mot de passe trouvé. Veuillez le saisir.</translation>
+        <translation type="vanished">Aucun mot de passe trouvé. Veuillez le saisir.</translation>
     </message>
     <message>
         <source>No valid login QR code found.</source>
         <translation>Aucun code QR de connexion valide trouvé.</translation>
     </message>
 </context>
+<context>
+    <name>LocalAccountRemoval</name>
+    <message>
+        <source>Remove account from this app</source>
+        <translation>Supprimer ce compte de l&apos;application</translation>
+    </message>
+    <message>
+        <source>Your account will be removed from this app.
+Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
+        <translation>Votre compte sera supprimé de l&apos;application.
+Votre mot de passe sera supprimé, assurez-vous qu&apos;il est enregistré dans un gestionnaire de mots de passe ou que vous le connaissez !</translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation>Supprimer</translation>
+    </message>
+</context>
 <context>
     <name>LoginPage</name>
     <message>
@@ -505,7 +740,7 @@
     </message>
     <message>
         <source>Log in using a QR-Code</source>
-        <translation>Connexion à l&apos;aide d&apos;un code QR</translation>
+        <translation type="vanished">Connexion à l&apos;aide d&apos;un code QR</translation>
     </message>
 </context>
 <context>
@@ -582,15 +817,15 @@
     <name>MessageHandler</name>
     <message>
         <source>Could not send message, as a result of not being connected.</source>
-        <translation>Impossible d&apos;envoyer le message car vous n&apos;êtes pas connecté(e).</translation>
+        <translation type="vanished">Impossible d&apos;envoyer le message car vous n&apos;êtes pas connecté(e).</translation>
     </message>
     <message>
         <source>Could not correct message, as a result of not being connected.</source>
-        <translation>Impossible de corriger le message car vous n&apos;êtes pas connecté(e).</translation>
+        <translation type="vanished">Impossible de corriger le message car vous n&apos;êtes pas connecté(e).</translation>
     </message>
     <message>
         <source>Spoiler</source>
-        <translation>Révélation</translation>
+        <translation type="vanished">Révélation</translation>
     </message>
     <message>
         <source>Message could not be sent.</source>
@@ -601,91 +836,110 @@
         <translation>La correction du message a échoué.</translation>
     </message>
 </context>
+<context>
+    <name>MessageModel</name>
+    <message>
+        <source>Pending</source>
+        <translation>En attente</translation>
+    </message>
+    <message>
+        <source>Sent</source>
+        <translation>Envoyé</translation>
+    </message>
+    <message>
+        <source>Delivered</source>
+        <translation>Délivré</translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation>Erreur</translation>
+    </message>
+</context>
 <context>
     <name>MultimediaSettings</name>
     <message>
         <source>Multimedia Settings</source>
-        <translation type="unfinished">Paramètres multimédia</translation>
+        <translation>Paramètres multimédia</translation>
     </message>
     <message>
         <source>Configure</source>
-        <translation type="unfinished">Configurer</translation>
+        <translation>Configurer</translation>
     </message>
     <message>
         <source>Image Capture</source>
-        <translation type="unfinished">Capturer une image</translation>
+        <translation>Capturer une image</translation>
     </message>
     <message>
         <source>Audio Recording</source>
-        <translation type="unfinished">Enregistrement audio</translation>
+        <translation>Enregistrement audio</translation>
     </message>
     <message>
         <source>Video Recording</source>
-        <translation type="unfinished">Enregistrement vidéo</translation>
+        <translation>Enregistrement vidéo</translation>
     </message>
     <message>
         <source>Camera</source>
-        <translation type="unfinished">Caméra</translation>
+        <translation>Caméra</translation>
     </message>
     <message>
         <source>Audio input</source>
-        <translation type="unfinished">Entrée audio</translation>
+        <translation>Entrée audio</translation>
     </message>
     <message>
         <source>Container</source>
-        <translation type="unfinished">Conteneur</translation>
+        <translation>Conteneur</translation>
     </message>
     <message>
         <source>Image</source>
-        <translation type="unfinished">Image</translation>
+        <translation>Image</translation>
     </message>
     <message>
         <source>Audio</source>
-        <translation type="unfinished">Audio</translation>
+        <translation>Audio</translation>
     </message>
     <message>
         <source>Video</source>
-        <translation type="unfinished">Vidéo</translation>
+        <translation>Vidéo</translation>
     </message>
     <message>
         <source>Codec</source>
-        <translation type="unfinished">Codec</translation>
+        <translation>Codec</translation>
     </message>
     <message>
         <source>Resolution</source>
-        <translation type="unfinished">Résolution</translation>
+        <translation>Résolution</translation>
     </message>
     <message>
         <source>Quality</source>
-        <translation type="unfinished">Qualité</translation>
+        <translation>Qualité</translation>
     </message>
     <message>
         <source>Sample Rate</source>
-        <translation type="unfinished">Taux d&apos;échantillonnage</translation>
+        <translation>Taux d&apos;échantillonnage</translation>
     </message>
     <message>
         <source>Frame Rate</source>
-        <translation type="unfinished">Images par seconde</translation>
+        <translation>Images par seconde</translation>
     </message>
     <message>
         <source>Ready</source>
-        <translation type="unfinished">Prêt</translation>
+        <translation>Prêt</translation>
     </message>
     <message>
-        <source>Initializing...</source>
-        <translation type="unfinished">Initialisation...</translation>
+        <source>Initializing…</source>
+        <translation>Initialisation…</translation>
     </message>
     <message>
         <source>Unavailable</source>
-        <translation type="unfinished">Indisponible</translation>
+        <translation>Indisponible</translation>
     </message>
     <message>
-        <source>Recording...</source>
-        <translation type="unfinished">Enregistrement...</translation>
+        <source>Recording…</source>
+        <translation>Enregistrement…</translation>
     </message>
     <message>
         <source>Paused</source>
-        <translation type="unfinished">En pause</translation>
+        <translation>En pause</translation>
     </message>
 </context>
 <context>
@@ -759,16 +1013,16 @@
         <translation type="vanished">Prêt</translation>
     </message>
     <message>
-        <source>Initializing...</source>
-        <translation type="vanished">Initialisation...</translation>
+        <source>Initializing…</source>
+        <translation type="vanished">Initialisation…</translation>
     </message>
     <message>
         <source>Unavailable</source>
         <translation type="vanished">Indisponible</translation>
     </message>
     <message>
-        <source>Recording...</source>
-        <translation type="vanished">Enregistrement...</translation>
+        <source>Recording…</source>
+        <translation type="vanished">Enregistrement…</translation>
     </message>
     <message>
         <source>Paused</source>
@@ -782,22 +1036,48 @@
         <translation>Prêt</translation>
     </message>
     <message>
-        <source>Initializing...</source>
-        <translation>Initialisation...</translation>
+        <source>Initializing…</source>
+        <translation>Initialisation…</translation>
     </message>
     <message>
         <source>Unavailable</source>
         <translation>Indisponible</translation>
     </message>
     <message>
-        <source>Recording... %1</source>
-        <translation>Enregistrement... %1</translation>
+        <source>Recording… %1</source>
+        <translation>Enregistrement… %1</translation>
     </message>
     <message>
         <source>Paused %1</source>
         <translation>En pause %1</translation>
     </message>
 </context>
+<context>
+    <name>PasswordRemovalPage</name>
+    <message>
+        <source>Remove password</source>
+        <translation>Supprimer le mot de passe</translation>
+    </message>
+    <message>
+        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
+        <translation>Vous pouvez décider non seulement de ne pas afficher votre mot de passe pour &lt;b&gt;%1&lt;/b&gt; sous forme de texte ou de le supprimer complètement lors du transfert de compte. Si vous supprimez complètement votre mot de passe, vous ne pourrez plus utiliser le transfert de compte par lecture optique sans saisir votre mot de passe, car il est également supprimé du code QR.</translation>
+    </message>
+    <message>
+        <source>Do not show password as text</source>
+        <translation>Ne pas afficher le mot de passe sous forme de texte</translation>
+    </message>
+    <message>
+        <source>Remove completely</source>
+        <translation>Supprimer complètement</translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Mark as read</source>
+        <translation>Noter comme lu</translation>
+    </message>
+</context>
 <context>
     <name>QmlUtils</name>
     <message>
@@ -830,43 +1110,58 @@
     </message>
     <message>
         <source>Invisible</source>
-        <translation>Invisible</translation>
+        <translation type="vanished">Invisible</translation>
     </message>
     <message>
         <source>Invalid username or password.</source>
-        <translation type="unfinished">Identifiant ou mot de passe invalide.</translation>
+        <translation>Identifiant ou mot de passe invalide.</translation>
     </message>
     <message>
         <source>Cannot connect to the server. Please check your internet connection.</source>
-        <translation type="unfinished">Impossible de se connecter au serveur. Veuillez tester votre connexion à internet.</translation>
+        <translation>Impossible de se connecter au serveur. Veuillez tester votre connexion à internet.</translation>
     </message>
     <message>
         <source>The server doesn&apos;t support secure connections.</source>
-        <translation type="unfinished">Le serveur ne permet pas les connexions sécurisées.</translation>
+        <translation>Le serveur ne permet pas les connexions sécurisées.</translation>
     </message>
     <message>
         <source>Error while trying to connect securely.</source>
-        <translation type="unfinished">Une erreur est survenue lors de la connexion sécurisée.</translation>
+        <translation>Une erreur est survenue lors de la connexion sécurisée.</translation>
     </message>
     <message>
         <source>Could not resolve the server&apos;s address. Please check your server name.</source>
-        <translation type="unfinished"></translation>
+        <translation>Impossible de trouver l&apos;adresse du serveur. Merci de vérifier le nom du serveur.</translation>
     </message>
     <message>
         <source>Could not connect to the server.</source>
-        <translation type="unfinished">Impossible de se connecter au serveur.</translation>
+        <translation type="obsolete">Impossible de se connecter au serveur.</translation>
     </message>
     <message>
         <source>Authentification protocol not supported by the server.</source>
-        <translation type="unfinished">Protocole d&apos;authentification non supporté par le serveur.</translation>
+        <translation>Protocole d&apos;authentification non pris en charge par le serveur.</translation>
     </message>
     <message>
         <source>This server does not support registration.</source>
-        <translation type="unfinished"></translation>
+        <translation>Ce serveur ne gère pas l&apos;inscription.</translation>
     </message>
     <message>
-        <source>An unknown error occured.</source>
-        <translation type="unfinished"></translation>
+        <source>The server is offline or blocked by a firewall.</source>
+        <translation>Le server est hors ligne ou bloqué par un pare-feu.</translation>
+    </message>
+    <message>
+        <source>The connection could not be refreshed.</source>
+        <translation>La connection ne peut pas être actualisée.</translation>
+    </message>
+    <message>
+        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
+        <translation>L&apos;accès à internet n&apos;est pas autorisé. Merci de vérifier les permissions système.</translation>
+    </message>
+</context>
+<context>
+    <name>QrCodeGenerator</name>
+    <message>
+        <source>Generating the QR code failed: %1</source>
+        <translation>Échec de la génération du QR code : %1</translation>
     </message>
 </context>
 <context>
@@ -889,6 +1184,45 @@ Essayez de fermer d&apos;autres applications utilisant la caméra.</translation>
         <source>The camera format &apos;%1&apos; is not supported.</source>
         <translation>Le format « %1 » de la caméra n&apos;est pas pris en charge.</translation>
     </message>
+    <message>
+        <source>Logging in…</source>
+        <translation type="vanished">Connexion…</translation>
+    </message>
+    <message>
+        <source>Scan the QR code from your existing device to transfer your account.</source>
+        <translation>Scanner le QR code de votre appareil pour transférer votre compte.</translation>
+    </message>
+    <message>
+        <source>Show explanation</source>
+        <translation>Afficher des explications</translation>
+    </message>
+    <message>
+        <source>Scan</source>
+        <translation>Scanner</translation>
+    </message>
+    <message>
+        <source>Continue without QR code</source>
+        <translation>Continuer sans QR Code</translation>
+    </message>
+    <message>
+        <source>Connecting…</source>
+        <translation>Connexion…</translation>
+    </message>
+</context>
+<context>
+    <name>RegistrationLoginDecisionPage</name>
+    <message>
+        <source>Set up</source>
+        <translation>Configurer</translation>
+    </message>
+    <message>
+        <source>Register a new account</source>
+        <translation>Créer un nouveau compte</translation>
+    </message>
+    <message>
+        <source>Use an existing account</source>
+        <translation>Utiliser un compte existant</translation>
+    </message>
 </context>
 <context>
     <name>RegistrationManager</name>
@@ -901,6 +1235,23 @@ Essayez de fermer d&apos;autres applications utilisant la caméra.</translation>
         <translation>Échec lors de la modification du mot de passe : %1</translation>
     </message>
 </context>
+<context>
+    <name>RemoteAccountDeletion</name>
+    <message>
+        <source>Delete account completely</source>
+        <translation>Supprimer complètement le compte</translation>
+    </message>
+    <message>
+        <source>Your account will be deleted completely, which means from this app and from the server.
+You will not be able to use your account again!</source>
+        <translation>Votre compte va être complètement supprimé. C&apos;est-à-dire localement dans l&apos;application et sur le serveur.
+Vous ne pourrez plus utiliser ce compte à nouveau !</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Supprimer</translation>
+    </message>
+</context>
 <context>
     <name>RosterAddContactSheet</name>
     <message>
@@ -1064,7 +1415,7 @@ Essayez de fermer d&apos;autres applications utilisant la caméra.</translation>
     </message>
     <message>
         <source>Edit name:</source>
-        <translation>Modifier le nom :</translation>
+        <translation type="vanished">Modifier le nom :</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -1103,11 +1454,25 @@ Essayez de fermer d&apos;autres applications utilisant la caméra.</translation>
     </message>
 </context>
 <context>
-    <name>SettingsPage</name>
+    <name>ServerListModel</name>
     <message>
-        <source>Settings</source>
-        <translation>Paramètres</translation>
+        <source>Custom server</source>
+        <translation>Autre serveur</translation>
     </message>
+    <message>
+        <source>No limitation</source>
+        <extracomment>Unlimited file size for uploading files
+----------
+Deletion of message history saved on server</extracomment>
+        <translation>Pas de limites</translation>
+    </message>
+    <message>
+        <source>%1 days</source>
+        <translation>%1 jours</translation>
+    </message>
+</context>
+<context>
+    <name>SettingsContent</name>
     <message>
         <source>Change password</source>
         <translation>Modifier le mot de passe</translation>
@@ -1118,11 +1483,76 @@ Essayez de fermer d&apos;autres applications utilisant la caméra.</translation>
     </message>
     <message>
         <source>Multimedia Settings</source>
-        <translation type="unfinished">Paramètres multimédia</translation>
+        <translation>Paramètres multimédia</translation>
     </message>
     <message>
         <source>Configure photo, video and audio recording settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Configurer les paramètres d&apos;enregistrement des photos, video et audio</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>Paramètres</translation>
+    </message>
+    <message>
+        <source>Account security</source>
+        <translation>Sécurité du compte</translation>
+    </message>
+    <message>
+        <source>configure whether this device can be used to log in on a new device</source>
+        <translation>Configurer si cet appareil peut être utilisé pour se connecter à un nouvel appareil</translation>
+    </message>
+    <message>
+        <source>Remove account from Kaidan</source>
+        <translation>Supprimer ce compte de Kaidan</translation>
+    </message>
+    <message>
+        <source>Remove account from this app</source>
+        <translation>Supprimer ce compte de l&apos;application</translation>
+    </message>
+    <message>
+        <source>Delete account</source>
+        <translation>Supprimer ce compte</translation>
+    </message>
+    <message>
+        <source>Delete account from the server</source>
+        <translation>Supprimer ce compte du serveur</translation>
+    </message>
+</context>
+<context>
+    <name>SettingsPage</name>
+    <message>
+        <source>Settings</source>
+        <translation>Paramètres</translation>
+    </message>
+    <message>
+        <source>Change password</source>
+        <translation type="vanished">Modifier le mot de passe</translation>
+    </message>
+    <message>
+        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
+        <translation type="vanished">Modifie le mot de passe du compte. Vous devrez le ressaisir sur tous vos autres appareils.</translation>
+    </message>
+    <message>
+        <source>Multimedia Settings</source>
+        <translation type="obsolete">Paramètres multimédia</translation>
+    </message>
+</context>
+<context>
+    <name>SettingsSheet</name>
+    <message>
+        <source>Settings</source>
+        <translation type="vanished">Paramètres</translation>
+    </message>
+</context>
+<context>
+    <name>StartPage</name>
+    <message>
+        <source>Enjoy free communication on every device!</source>
+        <translation>Profitez d&apos;une communication libre sur tous vos appareils !</translation>
+    </message>
+    <message>
+        <source>Let&apos;s start</source>
+        <translation>C&apos;est parti</translation>
     </message>
 </context>
 <context>
@@ -1162,6 +1592,10 @@ Essayez de fermer d&apos;autres applications utilisant la caméra.</translation>
         <source>More Actions</source>
         <translation type="vanished">Plus d&apos;actions</translation>
     </message>
+    <message>
+        <source>Message could not be sent.</source>
+        <translation>Le message n&apos;a pas pu être envoyé.</translation>
+    </message>
 </context>
 <context>
     <name>UserProfilePage</name>
@@ -1178,7 +1612,7 @@ Essayez de fermer d&apos;autres applications utilisant la caméra.</translation>
     </message>
     <message>
         <source>Nickname</source>
-        <translation>Surnom</translation>
+        <translation>Pseudo</translation>
     </message>
     <message>
         <source>About</source>
@@ -1194,7 +1628,7 @@ Essayez de fermer d&apos;autres applications utilisant la caméra.</translation>
     </message>
     <message>
         <source>Website</source>
-        <translation>Site internet</translation>
+        <translation>Site web</translation>
     </message>
 </context>
 </TS>
