@@ -15,6 +15,74 @@
         <source>View source code online</source>
         <translation>Ver código fonte en liña</translation>
     </message>
+    <message>
+        <source>Report problems</source>
+        <translation>Informar de problemas</translation>
+    </message>
+</context>
+<context>
+    <name>AccountSecurity</name>
+    <message>
+        <source>Account Security</source>
+        <translation>Seguridade da conta</translation>
+    </message>
+    <message>
+        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
+        <translation>Permitir engadir novos dispositivos usando un código QR, pero non mostrar o contrasinal como texto. Esta acción non ten volta, así que recomendamos gardar o contrasinal antes de utilizalo.</translation>
+    </message>
+    <message>
+        <source>Disable showing the password</source>
+        <translation>Desactivar mostrar o contrasinal</translation>
+    </message>
+    <message>
+        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
+        <translation>Non mostrar o contrasinal de ningún xeito. Esta acción non ten volta atrás.</translation>
+    </message>
+    <message>
+        <source>Disable showing the QR-Code and password</source>
+        <translation>Desactivar mostrar o código QR e o contrasinal</translation>
+    </message>
+</context>
+<context>
+    <name>AccountTransferPage</name>
+    <message>
+        <source>Transfer account to another device</source>
+        <translation>Transferir conta a outro dispositivo</translation>
+    </message>
+    <message>
+        <source>Scan the QR code or enter the credentials as text on another device to log in on it.
+
+Attention:
+Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
+        <translation>Escanear código QR ou escribir as credenciais como texto noutro dispositivo para conectar nel.
+
+Atención:
+Nunca lle mostres este código QR a ninguén. Permitiríalle acceso sen límite á túa conta!</translation>
+    </message>
+    <message>
+        <source>Chat address:</source>
+        <translation>Enderezo da conversa:</translation>
+    </message>
+    <message>
+        <source>Password:</source>
+        <translation>Contrasinal:</translation>
+    </message>
+    <message>
+        <source>Hide QR code</source>
+        <translation>Agochar código QR</translation>
+    </message>
+    <message>
+        <source>Show as QR code</source>
+        <translation>Mostrar como código QR</translation>
+    </message>
+    <message>
+        <source>Hide text</source>
+        <translation>Agochar texto</translation>
+    </message>
+    <message>
+        <source>Show as text</source>
+        <translation>Mostrar como texto</translation>
+    </message>
 </context>
 <context>
     <name>ChangePassword</name>
@@ -63,11 +131,11 @@
     <name>ChatMessage</name>
     <message>
         <source>Copy Message</source>
-        <translation>Copiar Mensaxe</translation>
+        <translation type="vanished">Copiar Mensaxe</translation>
     </message>
     <message>
         <source>Edit Message</source>
-        <translation>Editar Mensaxe</translation>
+        <translation type="vanished">Editar Mensaxe</translation>
     </message>
     <message>
         <source>Spoiler</source>
@@ -79,11 +147,30 @@
     </message>
     <message>
         <source>Copy download URL</source>
-        <translation>Copiar URL de descarga</translation>
+        <translation type="vanished">Copiar URL de descarga</translation>
     </message>
     <message>
         <source>Quote</source>
-        <translation type="unfinished"></translation>
+        <translation type="vanished">Citar</translation>
+    </message>
+</context>
+<context>
+    <name>ChatMessageContextMenu</name>
+    <message>
+        <source>Copy message</source>
+        <translation>Copiar mensaxe</translation>
+    </message>
+    <message>
+        <source>Edit message</source>
+        <translation>Editar mensaxe</translation>
+    </message>
+    <message>
+        <source>Copy download URL</source>
+        <translation>Copiar URL de descarga</translation>
+    </message>
+    <message>
+        <source>Quote message</source>
+        <translation>Citar mensaxe</translation>
     </message>
 </context>
 <context>
@@ -114,7 +201,7 @@
     </message>
     <message>
         <source>Select a file</source>
-        <translation>Escoller ficheiro</translation>
+        <translation type="vanished">Escoller ficheiro</translation>
     </message>
     <message>
         <source>Send a spoiler message</source>
@@ -161,6 +248,13 @@
         <translation>Todos os ficheiros</translation>
     </message>
 </context>
+<context>
+    <name>ClientWorker</name>
+    <message>
+        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
+        <translation>A túa conta non se pode eliminar do servidor. Así, tampouco foi eliminada desta app: %1</translation>
+    </message>
+</context>
 <context>
     <name>CommonEncoderSettings</name>
     <message>
@@ -200,6 +294,51 @@
         <translation>Dúas pasadas</translation>
     </message>
 </context>
+<context>
+    <name>ConfirmationPage</name>
+    <message>
+        <source>Cancel</source>
+        <translation>Cancelar</translation>
+    </message>
+</context>
+<context>
+    <name>DisablePasswordDisplay</name>
+    <message>
+        <source>Remove password completely</source>
+        <translation>Eliminar contrasinal completamente</translation>
+    </message>
+    <message>
+        <source>Your password will not be included in the QR code anymore.
+You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
+Make sure that you backed it up if you want to use your account later.</source>
+        <translation>O teu contrasinal xa non se vai incluír no código QR.
+Non poderás conectar a través do código QR sen escribir o contrasinal porque esta acción non ten volta atrás!
+Asegúrate de que tes unha copia de apoio se queres usar a conta posteriormente.</translation>
+    </message>
+    <message>
+        <source>Remove password</source>
+        <translation>Eliminar contrasinal</translation>
+    </message>
+</context>
+<context>
+    <name>DisablePlainTextPasswordDisplay</name>
+    <message>
+        <source>Do not show password as text</source>
+        <translation>Non mostrar o contrasinal como texto</translation>
+    </message>
+    <message>
+        <source>Your password will not be shown as text anymore.
+You won&apos;t be able to see your password as text again because this action cannot be undone!
+Make sure that you backed it up if you want to use your account later.</source>
+        <translation>O teu contrasinal non se mostrará como texto nunca máis.
+Non poderás ver o teu contrasinal como texto porque esta acción non ten volta atrás!
+Asegúrate de ter unha copia de apoio se queres usar a túa conta máis adiante.</translation>
+    </message>
+    <message>
+        <source>Do not show password</source>
+        <translation>Non mostrar contrasinal</translation>
+    </message>
+</context>
 <context>
     <name>DownloadJob</name>
     <message>
@@ -269,25 +408,25 @@
     <name>FileChooser</name>
     <message>
         <source>Select a file</source>
-        <translation>Escoller ficheiro</translation>
+        <translation type="vanished">Escoller ficheiro</translation>
     </message>
 </context>
 <context>
     <name>FileChooserMobile</name>
     <message>
         <source>Go to parent folder</source>
-        <translation>Ir ao cartafol superior</translation>
+        <translation type="vanished">Ir ao cartafol superior</translation>
     </message>
     <message>
         <source>Close</source>
-        <translation>Pechar</translation>
+        <translation type="vanished">Pechar</translation>
     </message>
 </context>
 <context>
     <name>GlobalDrawer</name>
     <message>
         <source>Log out</source>
-        <translation>Desconectar</translation>
+        <translation type="vanished">Desconectar</translation>
     </message>
     <message>
         <source>About</source>
@@ -307,15 +446,19 @@
     </message>
     <message>
         <source>Offline</source>
-        <translation type="unfinished">Desconectada</translation>
+        <translation>Desconectada</translation>
     </message>
     <message>
         <source>Online</source>
-        <translation type="unfinished"></translation>
+        <translation>Conectada</translation>
     </message>
     <message>
         <source>Connecting…</source>
-        <translation type="unfinished">Conectando…</translation>
+        <translation>Conectando…</translation>
+    </message>
+    <message>
+        <source>Switch device</source>
+        <translation>Cambiar de dispositivo</translation>
     </message>
 </context>
 <context>
@@ -327,13 +470,30 @@
     </message>
     <message>
         <source>No password found. Please enter it.</source>
-        <translation>Non hai contrasinal. Por favor escríbea.</translation>
+        <translation type="vanished">Non hai contrasinal. Por favor escríbea.</translation>
     </message>
     <message>
         <source>No valid login QR code found.</source>
         <translation>Non te atopou código QR de conexión válido.</translation>
     </message>
 </context>
+<context>
+    <name>LocalAccountRemoval</name>
+    <message>
+        <source>Remove account from this app</source>
+        <translation>Eliminar conta desde esta app</translation>
+    </message>
+    <message>
+        <source>Your account will be removed from this app.
+Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
+        <translation>A conta vai ser eliminada desta app.
+O contrasinal será borrado, asegúrate de que o tes gardado ou de que te lembras del!</translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation>Eliminar</translation>
+    </message>
+</context>
 <context>
     <name>LoginPage</name>
     <message>
@@ -398,7 +558,7 @@
     </message>
     <message>
         <source>Log in using a QR-Code</source>
-        <translation>Conectar usando código QR</translation>
+        <translation type="vanished">Conectar usando código QR</translation>
     </message>
 </context>
 <context>
@@ -475,15 +635,15 @@
     <name>MessageHandler</name>
     <message>
         <source>Could not send message, as a result of not being connected.</source>
-        <translation>Non se enviou a mensaxe, xa que non está conectada.</translation>
+        <translation type="vanished">Non se enviou a mensaxe, xa que non está conectada.</translation>
     </message>
     <message>
         <source>Could not correct message, as a result of not being connected.</source>
-        <translation>Non se correxiu a mensaxe, xa que non está conectada.</translation>
+        <translation type="vanished">Non se correxiu a mensaxe, xa que non está conectada.</translation>
     </message>
     <message>
         <source>Spoiler</source>
-        <translation>Spoiler</translation>
+        <translation type="vanished">Spoiler</translation>
     </message>
     <message>
         <source>Message could not be sent.</source>
@@ -494,91 +654,110 @@
         <translation>Non se puido correxir a mensaxe.</translation>
     </message>
 </context>
+<context>
+    <name>MessageModel</name>
+    <message>
+        <source>Pending</source>
+        <translation>Pendente</translation>
+    </message>
+    <message>
+        <source>Sent</source>
+        <translation>Enviar</translation>
+    </message>
+    <message>
+        <source>Delivered</source>
+        <translation>Entregado</translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation>Fallo</translation>
+    </message>
+</context>
 <context>
     <name>MultimediaSettings</name>
     <message>
         <source>Multimedia Settings</source>
-        <translation type="unfinished">Axustes Multimedia</translation>
+        <translation>Axustes Multimedia</translation>
     </message>
     <message>
         <source>Configure</source>
-        <translation type="unfinished">Configurar</translation>
+        <translation>Configurar</translation>
     </message>
     <message>
         <source>Image Capture</source>
-        <translation type="unfinished">Capturar imaxe</translation>
+        <translation>Capturar imaxe</translation>
     </message>
     <message>
         <source>Audio Recording</source>
-        <translation type="unfinished">Gravando audio</translation>
+        <translation>Gravar audio</translation>
     </message>
     <message>
         <source>Video Recording</source>
-        <translation type="unfinished">Gravando vídeo</translation>
+        <translation>Gravar vídeo</translation>
     </message>
     <message>
         <source>Camera</source>
-        <translation type="unfinished">Cámara</translation>
+        <translation>Cámara</translation>
     </message>
     <message>
         <source>Audio input</source>
-        <translation type="unfinished">Entrada de audio</translation>
+        <translation>Entrada de audio</translation>
     </message>
     <message>
         <source>Container</source>
-        <translation type="unfinished">Contedor</translation>
+        <translation>Contedor</translation>
     </message>
     <message>
         <source>Image</source>
-        <translation type="unfinished">Imaxe</translation>
+        <translation>Imaxe</translation>
     </message>
     <message>
         <source>Audio</source>
-        <translation type="unfinished"></translation>
+        <translation>Audio</translation>
     </message>
     <message>
         <source>Video</source>
-        <translation type="unfinished">Vídeo</translation>
+        <translation>Vídeo</translation>
     </message>
     <message>
         <source>Codec</source>
-        <translation type="unfinished">Códec</translation>
+        <translation>Códec</translation>
     </message>
     <message>
         <source>Resolution</source>
-        <translation type="unfinished">Resolución</translation>
+        <translation>Resolución</translation>
     </message>
     <message>
         <source>Quality</source>
-        <translation type="unfinished">Calidade</translation>
+        <translation>Calidade</translation>
     </message>
     <message>
         <source>Sample Rate</source>
-        <translation type="unfinished">Taxa de mostreo</translation>
+        <translation>Taxa de mostreo</translation>
     </message>
     <message>
         <source>Frame Rate</source>
-        <translation type="unfinished">Taxa de marcos</translation>
+        <translation>Taxa de marcos</translation>
     </message>
     <message>
         <source>Ready</source>
-        <translation type="unfinished"></translation>
+        <translation>Listo</translation>
     </message>
     <message>
-        <source>Initializing...</source>
-        <translation type="unfinished">Inicializando...</translation>
+        <source>Initializing…</source>
+        <translation>Inicializando…</translation>
     </message>
     <message>
         <source>Unavailable</source>
-        <translation type="unfinished">Non dispoñible</translation>
+        <translation>Non dispoñible</translation>
     </message>
     <message>
-        <source>Recording...</source>
-        <translation type="unfinished">Gravando...</translation>
+        <source>Recording…</source>
+        <translation>Gravando…</translation>
     </message>
     <message>
         <source>Paused</source>
-        <translation type="unfinished">En pausa</translation>
+        <translation>En pausa</translation>
     </message>
 </context>
 <context>
@@ -652,16 +831,16 @@
         <translation type="vanished">Listo</translation>
     </message>
     <message>
-        <source>Initializing...</source>
-        <translation type="vanished">Inicializando...</translation>
+        <source>Initializing…</source>
+        <translation type="vanished">Inicializando…</translation>
     </message>
     <message>
         <source>Unavailable</source>
         <translation type="vanished">Non dispoñible</translation>
     </message>
     <message>
-        <source>Recording...</source>
-        <translation type="vanished">Gravando...</translation>
+        <source>Recording…</source>
+        <translation type="vanished">Gravando…</translation>
     </message>
     <message>
         <source>Paused</source>
@@ -675,22 +854,48 @@
         <translation>Preparado</translation>
     </message>
     <message>
-        <source>Initializing...</source>
-        <translation>Inicializando...</translation>
+        <source>Initializing…</source>
+        <translation>Inicializando…</translation>
     </message>
     <message>
         <source>Unavailable</source>
         <translation>Non dispoñible</translation>
     </message>
     <message>
-        <source>Recording... %1</source>
-        <translation>Gravando... %1</translation>
+        <source>Recording… %1</source>
+        <translation>Gravando… %1</translation>
     </message>
     <message>
         <source>Paused %1</source>
         <translation>En pausa %1</translation>
     </message>
 </context>
+<context>
+    <name>PasswordRemovalPage</name>
+    <message>
+        <source>Remove password</source>
+        <translation>Eliminar contrasinal</translation>
+    </message>
+    <message>
+        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
+        <translation>Podes decidir que non se mostre o contrasinal para &lt;b&gt;%1&lt;/b&gt; como texto nunca máis ou eliminala completamente desde a transferencia da conta. Se eliminas o contrasinal completamente non poderás voltar a utilizar a transferencia da conta vía escaneo sen escribir o contrasinal xa que tamén se eliminará do código QR.</translation>
+    </message>
+    <message>
+        <source>Do not show password as text</source>
+        <translation>Non mostrar o contrasinal como texto</translation>
+    </message>
+    <message>
+        <source>Remove completely</source>
+        <translation>Eliminar completamente</translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Mark as read</source>
+        <translation>Marcar como lido</translation>
+    </message>
+</context>
 <context>
     <name>QmlUtils</name>
     <message>
@@ -723,43 +928,62 @@
     </message>
     <message>
         <source>Invisible</source>
-        <translation>Non visible</translation>
+        <translation type="vanished">Non visible</translation>
     </message>
     <message>
         <source>Invalid username or password.</source>
-        <translation type="unfinished">Usuario ou contrasinal non válidos.</translation>
+        <translation>Usuario ou contrasinal non válidos.</translation>
     </message>
     <message>
         <source>Cannot connect to the server. Please check your internet connection.</source>
-        <translation type="unfinished">Non puido conectar co servidor. Por favor, comprobe a conexión a internet.</translation>
+        <translation>Non hai conexión co servidor. Por favor, comproba a conexión a internet.</translation>
     </message>
     <message>
         <source>The server doesn&apos;t support secure connections.</source>
-        <translation type="unfinished">O servidor non soporta conexións seguras.</translation>
+        <translation>O servidor non soporta conexións seguras.</translation>
     </message>
     <message>
         <source>Error while trying to connect securely.</source>
-        <translation type="unfinished">Fallo ao intentar conectar de xeito seguro.</translation>
+        <translation>Fallo ao intentar conectar de xeito seguro.</translation>
     </message>
     <message>
         <source>Could not resolve the server&apos;s address. Please check your server name.</source>
-        <translation type="unfinished"></translation>
+        <translation>Non se puido resolver o enderezo do servidor. Comproba o nome do servidor.</translation>
     </message>
     <message>
         <source>Could not connect to the server.</source>
-        <translation type="unfinished">Non puido conectar co servidor.</translation>
+        <translation type="vanished">Non hai conexión co servidor.</translation>
     </message>
     <message>
         <source>Authentification protocol not supported by the server.</source>
-        <translation type="unfinished">Protocolo de autenticación non soportado polo servidor.</translation>
+        <translation>Protocolo de autenticación non soportado polo servidor.</translation>
     </message>
     <message>
         <source>This server does not support registration.</source>
-        <translation type="unfinished"></translation>
+        <translation>O servidor non permite o rexistro.</translation>
     </message>
     <message>
         <source>An unknown error occured.</source>
-        <translation type="unfinished"></translation>
+        <translation type="vanished">Houbo un fallo descoñecido.</translation>
+    </message>
+    <message>
+        <source>The server is offline or blocked by a firewall.</source>
+        <translation>O servidor está desconectado ou bloqueado por cortalumes.</translation>
+    </message>
+    <message>
+        <source>The connection could not be refreshed.</source>
+        <translation>A conexión non se pode actualizar.</translation>
+    </message>
+    <message>
+        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
+        <translation>Non se permite o acceso a internet. Comproba a configuración de acceso a internet do sistema.</translation>
+    </message>
+</context>
+<context>
+    <name>QrCodeGenerator</name>
+    <message>
+        <source>Generating the QR code failed: %1</source>
+        <translation>Fallou a creación do código QR: %1</translation>
     </message>
 </context>
 <context>
@@ -782,6 +1006,41 @@ Pecha outras aplicacións que a estén utilizando.</translation>
         <source>The camera format &apos;%1&apos; is not supported.</source>
         <translation>O formato de cámara &apos;%1&apos; non está soportado.</translation>
     </message>
+    <message>
+        <source>Connecting…</source>
+        <translation>Conectando…</translation>
+    </message>
+    <message>
+        <source>Scan the QR code from your existing device to transfer your account.</source>
+        <translation>Escanea o código QR desde o outro dispositivo para transferir a conta.</translation>
+    </message>
+    <message>
+        <source>Show explanation</source>
+        <translation>Mostrar explicación</translation>
+    </message>
+    <message>
+        <source>Scan</source>
+        <translation>Escanear</translation>
+    </message>
+    <message>
+        <source>Continue without QR code</source>
+        <translation>Continuar sen código QR</translation>
+    </message>
+</context>
+<context>
+    <name>RegistrationLoginDecisionPage</name>
+    <message>
+        <source>Set up</source>
+        <translation>Axustar</translation>
+    </message>
+    <message>
+        <source>Register a new account</source>
+        <translation>Rexistrar unha nova conta</translation>
+    </message>
+    <message>
+        <source>Use an existing account</source>
+        <translation>Usar unha conta existente</translation>
+    </message>
 </context>
 <context>
     <name>RegistrationManager</name>
@@ -794,6 +1053,23 @@ Pecha outras aplicacións que a estén utilizando.</translation>
         <translation>Fallo no cambio de contrasinal: %1</translation>
     </message>
 </context>
+<context>
+    <name>RemoteAccountDeletion</name>
+    <message>
+        <source>Delete account completely</source>
+        <translation>Eliminar completamente a conta</translation>
+    </message>
+    <message>
+        <source>Your account will be deleted completely, which means from this app and from the server.
+You will not be able to use your account again!</source>
+        <translation>A conta vaise eliminar completamente, tanto nesta app como no servidor.
+Non poderás utilizar nunca máis a conta!</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Eliminar</translation>
+    </message>
+</context>
 <context>
     <name>RosterAddContactSheet</name>
     <message>
@@ -802,7 +1078,7 @@ Pecha outras aplicacións que a estén utilizando.</translation>
     </message>
     <message>
         <source>This will also send a request to access the presence of the contact.</source>
-        <translation>Esto tamén enviará unha solicitude  para acceder a presenza do contacto.</translation>
+        <translation>Esto tamén enviará unha solicitude para acceder á presenza do contacto.</translation>
     </message>
     <message>
         <source>Jabber-ID:</source>
@@ -937,7 +1213,7 @@ Pecha outras aplicacións que a estén utilizando.</translation>
     </message>
     <message>
         <source>Edit name:</source>
-        <translation>Editar nome:</translation>
+        <translation type="vanished">Editar nome:</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -964,7 +1240,25 @@ Pecha outras aplicacións que a estén utilizando.</translation>
     </message>
 </context>
 <context>
-    <name>SettingsPage</name>
+    <name>ServerListModel</name>
+    <message>
+        <source>Custom server</source>
+        <translation>Servidor personalizado</translation>
+    </message>
+    <message>
+        <source>No limitation</source>
+        <extracomment>Unlimited file size for uploading files
+----------
+Deletion of message history saved on server</extracomment>
+        <translation>Sen límite</translation>
+    </message>
+    <message>
+        <source>%1 days</source>
+        <translation>%1 días</translation>
+    </message>
+</context>
+<context>
+    <name>SettingsContent</name>
     <message>
         <source>Settings</source>
         <translation>Axustes</translation>
@@ -975,15 +1269,73 @@ Pecha outras aplicacións que a estén utilizando.</translation>
     </message>
     <message>
         <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
-        <translation>Cambio no contrasinal da conta. Deberá voltar a introducilo nos outros dispositivos.</translation>
+        <translation>Cambio no contrasinal da conta. Deberás voltar a introducilo nos outros dispositivos.</translation>
     </message>
     <message>
         <source>Multimedia Settings</source>
-        <translation type="unfinished">Axustes Multimedia</translation>
+        <translation>Axustes Multimedia</translation>
     </message>
     <message>
         <source>Configure photo, video and audio recording settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Configurar os axustes para fotos e gravación de audio e vídeo</translation>
+    </message>
+    <message>
+        <source>Account security</source>
+        <translation>Seguridade da conta</translation>
+    </message>
+    <message>
+        <source>configure whether this device can be used to log in on a new device</source>
+        <translation>configura se queres poder usar este dispositivo para conectar noutro dispositivo</translation>
+    </message>
+    <message>
+        <source>Remove account from Kaidan</source>
+        <translation>Eliminar a conta de Kaidan</translation>
+    </message>
+    <message>
+        <source>Remove account from this app</source>
+        <translation>Eliminar a conta desta app</translation>
+    </message>
+    <message>
+        <source>Delete account</source>
+        <translation>Eliminar conta</translation>
+    </message>
+    <message>
+        <source>Delete account from the server</source>
+        <translation>Eliminar a conta do servidor</translation>
+    </message>
+</context>
+<context>
+    <name>SettingsPage</name>
+    <message>
+        <source>Settings</source>
+        <translation>Axustes</translation>
+    </message>
+    <message>
+        <source>Change password</source>
+        <translation type="vanished">Cambiar contrasinal</translation>
+    </message>
+    <message>
+        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
+        <translation type="vanished">Cambio no contrasinal da conta. Deberá voltar a introducilo nos outros dispositivos.</translation>
+    </message>
+    <message>
+        <source>Multimedia Settings</source>
+        <translation type="vanished">Axustes Multimedia</translation>
+    </message>
+    <message>
+        <source>Configure photo, video and audio recording settings</source>
+        <translation type="vanished">Configurar os axustes para fotos e gravación de audio e vídeo</translation>
+    </message>
+</context>
+<context>
+    <name>StartPage</name>
+    <message>
+        <source>Enjoy free communication on every device!</source>
+        <translation>Desfruta da comunicación libre en todos os dispositivos!</translation>
+    </message>
+    <message>
+        <source>Let&apos;s start</source>
+        <translation>Comecemos</translation>
     </message>
 </context>
 <context>
@@ -1015,6 +1367,10 @@ Pecha outras aplicacións que a estén utilizando.</translation>
         <source>File</source>
         <translation>Ficheiro</translation>
     </message>
+    <message>
+        <source>Message could not be sent.</source>
+        <translation>Non se puido enviar a mensaxe.</translation>
+    </message>
 </context>
 <context>
     <name>UserProfilePage</name>
