@@ -15,12 +15,77 @@
         <source>View source code online</source>
         <translation>Visualizza il codice sorgente online</translation>
     </message>
+    <message>
+        <source>Report problems</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>AccountSecurity</name>
+    <message>
+        <source>Account Security</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disable showing the password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disable showing the QR-Code and password</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>AccountTransferPage</name>
+    <message>
+        <source>Transfer account to another device</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scan the QR code or enter the credentials as text on another device to log in on it.
+
+Attention:
+Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Chat address:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Password:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide QR code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show as QR code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show as text</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ChangePassword</name>
     <message>
         <source>Change password</source>
-        <translation>Cambia password</translation>
+        <translation>Cambia la password</translation>
     </message>
     <message>
         <source>Current password:</source>
@@ -63,11 +128,11 @@
     <name>ChatMessage</name>
     <message>
         <source>Copy Message</source>
-        <translation>Copia Messaggio</translation>
+        <translation type="vanished">Copia il messaggio</translation>
     </message>
     <message>
         <source>Edit Message</source>
-        <translation>Modifica Messaggio</translation>
+        <translation type="vanished">Modifica il messaggio</translation>
     </message>
     <message>
         <source>Spoiler</source>
@@ -79,10 +144,29 @@
     </message>
     <message>
         <source>Copy download URL</source>
-        <translation>Copia URL di download</translation>
+        <translation type="vanished">Copia URL di download</translation>
     </message>
     <message>
         <source>Quote</source>
+        <translation type="vanished">Cita</translation>
+    </message>
+</context>
+<context>
+    <name>ChatMessageContextMenu</name>
+    <message>
+        <source>Copy message</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Edit message</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy download URL</source>
+        <translation type="unfinished">Copia URL di download</translation>
+    </message>
+    <message>
+        <source>Quote message</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -114,7 +198,7 @@
     </message>
     <message>
         <source>Select a file</source>
-        <translation>Seleziona un file</translation>
+        <translation type="vanished">Seleziona un file</translation>
     </message>
     <message>
         <source>Send a spoiler message</source>
@@ -138,7 +222,7 @@
     </message>
     <message>
         <source>Multimedia settings</source>
-        <translation>Impostazioni multimediali</translation>
+        <translation type="vanished">Impostazioni multimediali</translation>
     </message>
     <message>
         <source>Search</source>
@@ -161,6 +245,13 @@
         <translation>Tutti i file</translation>
     </message>
 </context>
+<context>
+    <name>ClientWorker</name>
+    <message>
+        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>CommonEncoderSettings</name>
     <message>
@@ -189,17 +280,58 @@
     </message>
     <message>
         <source>Constant bit rate</source>
-        <translation>Velocità in bit costante</translation>
+        <translation>Bit rate costante</translation>
     </message>
     <message>
         <source>Average bit rate</source>
-        <translation>Velocità in bit media</translation>
+        <translation>Bit rate medio</translation>
     </message>
     <message>
         <source>Two pass</source>
         <translation>Due passaggi</translation>
     </message>
 </context>
+<context>
+    <name>ConfirmationPage</name>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">Annulla</translation>
+    </message>
+</context>
+<context>
+    <name>DisablePasswordDisplay</name>
+    <message>
+        <source>Remove password completely</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your password will not be included in the QR code anymore.
+You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
+Make sure that you backed it up if you want to use your account later.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove password</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>DisablePlainTextPasswordDisplay</name>
+    <message>
+        <source>Do not show password as text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your password will not be shown as text anymore.
+You won&apos;t be able to see your password as text again because this action cannot be undone!
+Make sure that you backed it up if you want to use your account later.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Do not show password</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>DownloadJob</name>
     <message>
@@ -208,7 +340,7 @@
     </message>
     <message>
         <source>Download failed: %1</source>
-        <translation>Scaricamento non riuscito: %1</translation>
+        <translation>Scaricamento fallito: %1</translation>
     </message>
 </context>
 <context>
@@ -269,29 +401,29 @@
     <name>FileChooser</name>
     <message>
         <source>Select a file</source>
-        <translation>Seleziona un file</translation>
+        <translation type="vanished">Seleziona un file</translation>
     </message>
 </context>
 <context>
     <name>FileChooserMobile</name>
     <message>
         <source>Go to parent folder</source>
-        <translation>Vai al livello superiore</translation>
+        <translation type="vanished">Vai al livello superiore</translation>
     </message>
     <message>
         <source>Close</source>
-        <translation>Chiudi</translation>
+        <translation type="vanished">Chiudi</translation>
     </message>
 </context>
 <context>
     <name>GlobalDrawer</name>
     <message>
         <source>Log out</source>
-        <translation>Esci</translation>
+        <translation type="vanished">Esci</translation>
     </message>
     <message>
         <source>About</source>
-        <translation>Più Informazioni</translation>
+        <translation>Informazioni</translation>
     </message>
     <message>
         <source>Invite friends</source>
@@ -307,15 +439,19 @@
     </message>
     <message>
         <source>Offline</source>
-        <translation type="unfinished">Non in linea</translation>
+        <translation>Fuori linea</translation>
     </message>
     <message>
         <source>Online</source>
-        <translation type="unfinished"></translation>
+        <translation>In linea</translation>
     </message>
     <message>
         <source>Connecting…</source>
-        <translation type="unfinished">Connessione…</translation>
+        <translation>Connessione…</translation>
+    </message>
+    <message>
+        <source>Switch device</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -327,13 +463,29 @@
     </message>
     <message>
         <source>No password found. Please enter it.</source>
-        <translation>Nessuna password trovata. Per favore inseriscila.</translation>
+        <translation type="vanished">Nessuna password trovata. Per favore inseriscila.</translation>
     </message>
     <message>
         <source>No valid login QR code found.</source>
         <translation>Nessun codice QR di accesso valido trovato.</translation>
     </message>
 </context>
+<context>
+    <name>LocalAccountRemoval</name>
+    <message>
+        <source>Remove account from this app</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your account will be removed from this app.
+Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>LoginPage</name>
     <message>
@@ -402,7 +554,7 @@
     </message>
     <message>
         <source>Log in using a QR-Code</source>
-        <translation>Accedi utilizzando un QR-Code</translation>
+        <translation type="vanished">Accedi utilizzando un QR-Code</translation>
     </message>
 </context>
 <context>
@@ -432,23 +584,23 @@
     </message>
     <message>
         <source>Choose file</source>
-        <translation>Scegli file</translation>
+        <translation>Scegli un file</translation>
     </message>
     <message>
         <source>Choose image</source>
-        <translation>Scegli immagine</translation>
+        <translation>Scegli un&apos;immagine</translation>
     </message>
     <message>
         <source>Choose video</source>
-        <translation>Scegli video</translation>
+        <translation>Scegli un video</translation>
     </message>
     <message>
         <source>Choose audio file</source>
-        <translation>Scegli file audio</translation>
+        <translation>Scegli un file audio</translation>
     </message>
     <message>
         <source>Choose document</source>
-        <translation>Scegli documento</translation>
+        <translation>Scegli un documento</translation>
     </message>
     <message>
         <source>All files</source>
@@ -479,15 +631,15 @@
     <name>MessageHandler</name>
     <message>
         <source>Could not send message, as a result of not being connected.</source>
-        <translation>Impossibile inviare messaggi, perchè non sei connesso.</translation>
+        <translation type="vanished">Impossibile inviare messaggi, perchè non sei connesso.</translation>
     </message>
     <message>
         <source>Could not correct message, as a result of not being connected.</source>
-        <translation>Impossibile correggere messaggi, perchè non sei connesso.</translation>
+        <translation type="vanished">Impossibile correggere il messaggio, perchè non sei connesso.</translation>
     </message>
     <message>
         <source>Spoiler</source>
-        <translation>Spoiler</translation>
+        <translation type="vanished">Spoiler</translation>
     </message>
     <message>
         <source>Message could not be sent.</source>
@@ -498,11 +650,30 @@
         <translation>La correzione del messaggio non è riuscita.</translation>
     </message>
 </context>
+<context>
+    <name>MessageModel</name>
+    <message>
+        <source>Pending</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sent</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delivered</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished">Errore</translation>
+    </message>
+</context>
 <context>
     <name>MultimediaSettings</name>
     <message>
         <source>Multimedia Settings</source>
-        <translation>Impostazioni Multimediali</translation>
+        <translation>Impostazioni multimediali</translation>
     </message>
     <message>
         <source>Configure</source>
@@ -510,15 +681,15 @@
     </message>
     <message>
         <source>Image Capture</source>
-        <translation>Cattura Immagine</translation>
+        <translation>Cattura immagine</translation>
     </message>
     <message>
         <source>Audio Recording</source>
-        <translation>Registrazione Audio</translation>
+        <translation>Registrazione audio</translation>
     </message>
     <message>
         <source>Video Recording</source>
-        <translation>Registrazione Video</translation>
+        <translation>Registrazione video</translation>
     </message>
     <message>
         <source>Camera</source>
@@ -534,15 +705,15 @@
     </message>
     <message>
         <source>Image</source>
-        <translation type="unfinished">Immagine</translation>
+        <translation>Immagine</translation>
     </message>
     <message>
         <source>Audio</source>
-        <translation type="unfinished">Audio</translation>
+        <translation>Audio</translation>
     </message>
     <message>
         <source>Video</source>
-        <translation type="unfinished">Video</translation>
+        <translation>Video</translation>
     </message>
     <message>
         <source>Codec</source>
@@ -558,27 +729,27 @@
     </message>
     <message>
         <source>Sample Rate</source>
-        <translation>Frequenza di Campionamento</translation>
+        <translation>Frequenza di campionamento</translation>
     </message>
     <message>
         <source>Frame Rate</source>
-        <translation>Frequenza Fotogrammi</translation>
+        <translation>Frequenza fotogrammi</translation>
     </message>
     <message>
         <source>Ready</source>
         <translation>Pronto</translation>
     </message>
     <message>
-        <source>Initializing...</source>
-        <translation>Inizializzazione...</translation>
+        <source>Initializing…</source>
+        <translation>Inizializzazione…</translation>
     </message>
     <message>
         <source>Unavailable</source>
         <translation>Non disponibile</translation>
     </message>
     <message>
-        <source>Recording...</source>
-        <translation>Registrazione...</translation>
+        <source>Recording…</source>
+        <translation>Registrazione…</translation>
     </message>
     <message>
         <source>Paused</source>
@@ -607,22 +778,48 @@
         <translation>Pronto</translation>
     </message>
     <message>
-        <source>Initializing...</source>
-        <translation>Inizializzazione...</translation>
+        <source>Initializing…</source>
+        <translation>Inizializzazione…</translation>
     </message>
     <message>
         <source>Unavailable</source>
         <translation>Non disponibile</translation>
     </message>
     <message>
-        <source>Recording... %1</source>
-        <translation>Registrazione... %1</translation>
+        <source>Recording… %1</source>
+        <translation>Registrazione… %1</translation>
     </message>
     <message>
         <source>Paused %1</source>
         <translation>In pausa %1</translation>
     </message>
 </context>
+<context>
+    <name>PasswordRemovalPage</name>
+    <message>
+        <source>Remove password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Do not show password as text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove completely</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Mark as read</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QmlUtils</name>
     <message>
@@ -635,7 +832,7 @@
     </message>
     <message>
         <source>Away</source>
-        <translation>Lontano dal dispositivo</translation>
+        <translation>Assente</translation>
     </message>
     <message>
         <source>Do not disturb</source>
@@ -643,7 +840,7 @@
     </message>
     <message>
         <source>Away for longer</source>
-        <translation>Lontano per tanto tempo</translation>
+        <translation>Lontano per molto tempo</translation>
     </message>
     <message>
         <source>Offline</source>
@@ -655,42 +852,61 @@
     </message>
     <message>
         <source>Invisible</source>
-        <translation>Invisibile</translation>
+        <translation type="vanished">Invisibile</translation>
     </message>
     <message>
         <source>Invalid username or password.</source>
-        <translation type="unfinished">Nome utente o password non validi.</translation>
+        <translation>Nome utente o password non validi.</translation>
     </message>
     <message>
         <source>Cannot connect to the server. Please check your internet connection.</source>
-        <translation type="unfinished">Impossibile connettersi al server. Per favore controlla la tua connessione a internet.</translation>
+        <translation>Impossibile connettersi al server. Per favore controlla la tua connessione a internet.</translation>
     </message>
     <message>
         <source>The server doesn&apos;t support secure connections.</source>
-        <translation type="unfinished">Il server non supporta connessioni sicure.</translation>
+        <translation>Il server non supporta connessioni sicure.</translation>
     </message>
     <message>
         <source>Error while trying to connect securely.</source>
-        <translation type="unfinished">Errore durante il tentativo di connessione sicura.</translation>
+        <translation>Errore durante il tentativo di connessione sicura.</translation>
     </message>
     <message>
         <source>Could not resolve the server&apos;s address. Please check your server name.</source>
-        <translation type="unfinished"></translation>
+        <translation>Non è stato possibile trovare l&apos;indirizzo del server. Si prega di controllare il nome del server.</translation>
     </message>
     <message>
         <source>Could not connect to the server.</source>
-        <translation type="unfinished">Non posso connettermi al server.</translation>
+        <translation type="vanished">Impossibile connettersi al server.</translation>
     </message>
     <message>
         <source>Authentification protocol not supported by the server.</source>
-        <translation type="unfinished">Protocollo di autenticazione non supportato dal server.</translation>
+        <translation>Protocollo di autenticazione non supportato dal server.</translation>
     </message>
     <message>
         <source>This server does not support registration.</source>
-        <translation type="unfinished"></translation>
+        <translation>Questo server non supporta la registrazione.</translation>
     </message>
     <message>
         <source>An unknown error occured.</source>
+        <translation type="vanished">Si è verificato un errore sconosciuto.</translation>
+    </message>
+    <message>
+        <source>The server is offline or blocked by a firewall.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The connection could not be refreshed.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>QrCodeGenerator</name>
+    <message>
+        <source>Generating the QR code failed: %1</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -698,7 +914,7 @@
     <name>QrCodeScannerPage</name>
     <message>
         <source>Scan QR code</source>
-        <translation>Scansiona QR code</translation>
+        <translation>Scansiona il codice QR</translation>
     </message>
     <message>
         <source>There is no camera available.</source>
@@ -712,7 +928,42 @@ Provare a chiudere altre applicazioni che stanno utilizzando la fotocamera.</tra
     </message>
     <message>
         <source>The camera format &apos;%1&apos; is not supported.</source>
-        <translation>Il formato della fotocamera &apos;%1&apos; non è supportato.</translation>
+        <translation>Il formato della fotocamera «%1» non è supportato.</translation>
+    </message>
+    <message>
+        <source>Connecting…</source>
+        <translation type="unfinished">Connessione…</translation>
+    </message>
+    <message>
+        <source>Scan the QR code from your existing device to transfer your account.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show explanation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scan</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Continue without QR code</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>RegistrationLoginDecisionPage</name>
+    <message>
+        <source>Set up</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Register a new account</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use an existing account</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -726,6 +977,22 @@ Provare a chiudere altre applicazioni che stanno utilizzando la fotocamera.</tra
         <translation>Cambio password non riuscito: %1</translation>
     </message>
 </context>
+<context>
+    <name>RemoteAccountDeletion</name>
+    <message>
+        <source>Delete account completely</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your account will be deleted completely, which means from this app and from the server.
+You will not be able to use your account again!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished">Elimina</translation>
+    </message>
+</context>
 <context>
     <name>RosterAddContactSheet</name>
     <message>
@@ -804,11 +1071,11 @@ Provare a chiudere altre applicazioni che stanno utilizzando la fotocamera.</tra
     <name>RosterManager</name>
     <message>
         <source>Could not add contact, as a result of not being connected.</source>
-        <translation>Non è possibile aggiungere il contatto, perchè non sei connesso.</translation>
+        <translation>Impossibile aggiungere il contatto, perché non sei connesso.</translation>
     </message>
     <message>
         <source>Could not remove contact, as a result of not being connected.</source>
-        <translation>Impossibile rimuovere il contatto, perchè non sei connesso.</translation>
+        <translation>Impossibile rimuovere il contatto, perché non sei connesso.</translation>
     </message>
     <message>
         <source>Spoiler</source>
@@ -835,7 +1102,7 @@ Provare a chiudere altre applicazioni che stanno utilizzando la fotocamera.</tra
     </message>
     <message>
         <source>Offline</source>
-        <translation>Non in linea</translation>
+        <translation>Fuori linea</translation>
     </message>
     <message>
         <source>Search contacts</source>
@@ -850,7 +1117,7 @@ Provare a chiudere altre applicazioni che stanno utilizzando la fotocamera.</tra
     </message>
     <message>
         <source>Delete contact</source>
-        <translation>Elimina contatto</translation>
+        <translation>Elimina il contatto</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -865,11 +1132,11 @@ Provare a chiudere altre applicazioni che stanno utilizzando la fotocamera.</tra
     <name>RosterRenameContactSheet</name>
     <message>
         <source>Rename contact</source>
-        <translation>Rinomina contatto</translation>
+        <translation>Rinomina il contatto</translation>
     </message>
     <message>
         <source>Edit name:</source>
-        <translation>Modifica nome:</translation>
+        <translation type="vanished">Modifica il nome:</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -895,6 +1162,71 @@ Provare a chiudere altre applicazioni che stanno utilizzando la fotocamera.</tra
         <translation>Invia</translation>
     </message>
 </context>
+<context>
+    <name>ServerListModel</name>
+    <message>
+        <source>Custom server</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No limitation</source>
+        <extracomment>Unlimited file size for uploading files
+----------
+Deletion of message history saved on server</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 days</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SettingsContent</name>
+    <message>
+        <source>Settings</source>
+        <translation type="unfinished">Impostazioni</translation>
+    </message>
+    <message>
+        <source>Change password</source>
+        <translation type="unfinished">Cambia la password</translation>
+    </message>
+    <message>
+        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
+        <translation type="unfinished">Cambia la password del tuo account. Dovrai reinserirla negli altri tuoi dispositivi.</translation>
+    </message>
+    <message>
+        <source>Multimedia Settings</source>
+        <translation type="unfinished">Impostazioni multimediali</translation>
+    </message>
+    <message>
+        <source>Configure photo, video and audio recording settings</source>
+        <translation type="unfinished">Configura le impostazioni di registrazione di foto, video e audio</translation>
+    </message>
+    <message>
+        <source>Account security</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>configure whether this device can be used to log in on a new device</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove account from Kaidan</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove account from this app</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete account</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete account from the server</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>SettingsPage</name>
     <message>
@@ -903,18 +1235,29 @@ Provare a chiudere altre applicazioni che stanno utilizzando la fotocamera.</tra
     </message>
     <message>
         <source>Change password</source>
-        <translation>Cambia password</translation>
+        <translation type="vanished">Cambia la password</translation>
     </message>
     <message>
         <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
-        <translation>Cambia la password del tuo account. Dovrai reinserirla negli altri tuoi dispositivi.</translation>
+        <translation type="vanished">Cambia la password del tuo account. Dovrai reinserirla negli altri tuoi dispositivi.</translation>
     </message>
     <message>
         <source>Multimedia Settings</source>
-        <translation type="unfinished"></translation>
+        <translation type="vanished">Impostazioni multimediali</translation>
     </message>
     <message>
         <source>Configure photo, video and audio recording settings</source>
+        <translation type="vanished">Configura le impostazioni di registrazione di foto, video e audio</translation>
+    </message>
+</context>
+<context>
+    <name>StartPage</name>
+    <message>
+        <source>Enjoy free communication on every device!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Let&apos;s start</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -922,7 +1265,7 @@ Provare a chiudere altre applicazioni che stanno utilizzando la fotocamera.</tra
     <name>SubRequestAcceptSheet</name>
     <message>
         <source>Subscription Request</source>
-        <translation>Richiesta di Sottoscrizione</translation>
+        <translation>Richiesta di sottoscrizione</translation>
     </message>
     <message>
         <source>You received a subscription request by &lt;b&gt;%1&lt;/b&gt;. If you accept it, the account will have access to your presence status.</source>
@@ -947,6 +1290,10 @@ Provare a chiudere altre applicazioni che stanno utilizzando la fotocamera.</tra
         <source>File</source>
         <translation>File</translation>
     </message>
+    <message>
+        <source>Message could not be sent.</source>
+        <translation type="unfinished">Il messaggio non può essere inviato.</translation>
+    </message>
 </context>
 <context>
     <name>UserProfilePage</name>
@@ -967,11 +1314,11 @@ Provare a chiudere altre applicazioni che stanno utilizzando la fotocamera.</tra
     </message>
     <message>
         <source>About</source>
-        <translation>Più Informazioni</translation>
+        <translation>Informazioni</translation>
     </message>
     <message>
         <source>Email</source>
-        <translation>Email</translation>
+        <translation>E-mail</translation>
     </message>
     <message>
         <source>Birthday</source>
