@@ -15,6 +15,10 @@
         <source>View source code online</source>
         <translation>Lihat kod sumber dalam talian</translation>
     </message>
+    <message>
+        <source>Report problems</source>
+        <translation>Laporkan masalah</translation>
+    </message>
 </context>
 <context>
     <name>AboutPage</name>
@@ -50,6 +54,125 @@
         <translation type="obsolete">Lesen:</translation>
     </message>
 </context>
+<context>
+    <name>AccountDeletionFromClientAndServerConfirmationPage</name>
+    <message>
+        <source>Delete account completely</source>
+        <translation type="vanished">Padam keseluruhan akaun</translation>
+    </message>
+    <message>
+        <source>Your account will be deleted completely, which means from this app and from the server.
+You will not be able to use your account again!</source>
+        <translation type="vanished">Akaun anda akan dipadam keseluruhannya, iaitu dipadam daripada aplikasi ini dan juga daripada pelayan.
+Anda tidak akan mampu menggunakan akaun anda lagi!</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">Padam</translation>
+    </message>
+</context>
+<context>
+    <name>AccountDeletionFromClientConfirmationPage</name>
+    <message>
+        <source>Remove account from this app</source>
+        <translation type="vanished">Buang akaun daripada aplikasi ini</translation>
+    </message>
+    <message>
+        <source>Your account will be removed from this app.
+You won&apos;t be able to get your credentials back!
+Make sure that you have backed up those if you want to use your account later.</source>
+        <translation type="vanished">Akaun anda akan dibuang daripada aplikasi ini.
+Anda tidak akan mampu mendapatkan kelayakan anda semula!
+Sila pastikan anda telah menyandarkan kelayakan sekiranya anda ingin menggunakan akaun anda pada waktu akan datang.</translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation type="vanished">Buang</translation>
+    </message>
+</context>
+<context>
+    <name>AccountDeletionPage</name>
+    <message>
+        <source>Delete account</source>
+        <translation type="vanished">Padam akaun</translation>
+    </message>
+    <message>
+        <source>You can remove your account &lt;b&gt;%1&lt;/b&gt; only from this app or delete it completely. If you delete your account completely, you won&apos;t be able to use it with another app because it is also removed from the server.</source>
+        <translation type="vanished">Anda boleh membuang akaun anda &lt;b&gt;%1&lt;/b&gt; hanya daripada aplikasi ini atau memadamnya secara keseluruhannya. Jika anda memadam akaun anda keseluruhannya, anda tidak akan mampu menggunakan akaun tersebut di aplikasi lain kerana ia turut dibuang daripada pelayan.</translation>
+    </message>
+    <message>
+        <source>Remove from this app</source>
+        <translation type="vanished">Buang daripada aplikasi ini</translation>
+    </message>
+    <message>
+        <source>Delete completely</source>
+        <translation type="vanished">Padam keseluruhannya</translation>
+    </message>
+</context>
+<context>
+    <name>AccountSecurity</name>
+    <message>
+        <source>Account Security</source>
+        <translation>Keselamatan Akaun</translation>
+    </message>
+    <message>
+        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
+        <translation>Membolehkan penambahan peranti baharu menggunakan Kod QR, tetapi tidak menunjukkan kata laluan sebagai teks. Perbuatan ini tidak boleh diundur, jadi anda disyorkan untuk menyimpan kata laluan dalam cara yang lain sebelum menggunakannya.</translation>
+    </message>
+    <message>
+        <source>Disable showing the password</source>
+        <translation>Lumpuhkan penampakan kata laluan</translation>
+    </message>
+    <message>
+        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
+        <translation>Jangan dedah kata laluan dengan sebarang cara. Perbuatan ini tidak boleh diundur.</translation>
+    </message>
+    <message>
+        <source>Disable showing the QR-Code and password</source>
+        <translation>Lumpuhkan penampakan Kod QR dan kata laluan</translation>
+    </message>
+</context>
+<context>
+    <name>AccountTransferPage</name>
+    <message>
+        <source>Transfer account to another device</source>
+        <translation>Pindahkan akaun ke peranti lain</translation>
+    </message>
+    <message>
+        <source>Scan the QR code or enter the credentials as text on another device to log in on it.
+
+Attention:
+Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
+        <translation>Imbas kod QR atau masukkan kelayakan sebagai teks di peranti lain untuk log masuk ke akaun.
+
+Perhatian:
+Jangan sesekali tunjukkan kod QR ini kepada orang lain. Ia akan membenarkan capaian tanpa had ke akaun anda!</translation>
+    </message>
+    <message>
+        <source>Chat address:</source>
+        <translation>Alamat sembang:</translation>
+    </message>
+    <message>
+        <source>Password:</source>
+        <translation>Kata laluan:</translation>
+    </message>
+    <message>
+        <source>Hide QR code</source>
+        <translation>Sembunyi kod QR</translation>
+    </message>
+    <message>
+        <source>Show as QR code</source>
+        <translation>Tunjuk sebagai kod QR</translation>
+    </message>
+    <message>
+        <source>Hide text</source>
+        <translation>Sembunyi teks</translation>
+    </message>
+    <message>
+        <source>Show as text</source>
+        <translation>Tunjuk sebagai teks</translation>
+    </message>
+</context>
 <context>
     <name>BackButton</name>
     <message>
@@ -108,27 +231,42 @@
     </message>
     <message>
         <source>Copy Message</source>
-        <translation>Salin Mesej</translation>
+        <translation type="vanished">Salin Mesej</translation>
     </message>
     <message>
         <source>Edit Message</source>
-        <translation>Sunting Mesej</translation>
+        <translation type="vanished">Sunting Mesej</translation>
     </message>
     <message>
         <source>Spoiler</source>
-        <translation>Spoiler</translation>
+        <translation>Beberan</translation>
     </message>
     <message>
         <source>Download</source>
         <translation>Muat Turun</translation>
     </message>
+    <message>
+        <source>Copy download URL</source>
+        <translation type="vanished">Salin URL muat turun</translation>
+    </message>
+</context>
+<context>
+    <name>ChatMessageContextMenu</name>
+    <message>
+        <source>Copy message</source>
+        <translation>Salin mesej</translation>
+    </message>
+    <message>
+        <source>Edit message</source>
+        <translation>Sunting mesej</translation>
+    </message>
     <message>
         <source>Copy download URL</source>
         <translation>Salin URL muat turun</translation>
     </message>
     <message>
-        <source>Quote</source>
-        <translation type="unfinished"></translation>
+        <source>Quote message</source>
+        <translation>Petik mesej</translation>
     </message>
 </context>
 <context>
@@ -163,15 +301,15 @@
     </message>
     <message>
         <source>Select a file</source>
-        <translation>Pilih fail</translation>
+        <translation type="vanished">Pilih fail</translation>
     </message>
     <message>
         <source>Send a spoiler message</source>
-        <translation>Hantar mesej spoiler</translation>
+        <translation>Hantar mesej beberan</translation>
     </message>
     <message>
         <source>Spoiler hint</source>
-        <translation>Tip spoiler</translation>
+        <translation>Tip beberan</translation>
     </message>
     <message>
         <source>Unmute notifications</source>
@@ -209,6 +347,29 @@
         <source>All files</source>
         <translation>Semua fail</translation>
     </message>
+    <message>
+        <source>Copy message</source>
+        <translation type="vanished">Salin mesej</translation>
+    </message>
+    <message>
+        <source>Edit message</source>
+        <translation type="vanished">Sunting mesej</translation>
+    </message>
+    <message>
+        <source>Copy download URL</source>
+        <translation type="vanished">Salin URL muat turun</translation>
+    </message>
+    <message>
+        <source>Quote message</source>
+        <translation type="vanished">Petik mesej</translation>
+    </message>
+</context>
+<context>
+    <name>ClientWorker</name>
+    <message>
+        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
+        <translation>Akaun anda tidak boleh dipadam daripada pelayan. Oleh itu, ia juga tidak dibuang daripada aplikasi ini: %1</translation>
+    </message>
 </context>
 <context>
     <name>CommonEncoderSettings</name>
@@ -249,6 +410,13 @@
         <translation>Dua tapis</translation>
     </message>
 </context>
+<context>
+    <name>ConfirmationPage</name>
+    <message>
+        <source>Cancel</source>
+        <translation>Batal</translation>
+    </message>
+</context>
 <context>
     <name>ContextDrawer</name>
     <message>
@@ -256,6 +424,44 @@
         <translation type="vanished">Tindakan</translation>
     </message>
 </context>
+<context>
+    <name>DisablePasswordDisplay</name>
+    <message>
+        <source>Remove password completely</source>
+        <translation>Buang kata laluan sepenuhnya</translation>
+    </message>
+    <message>
+        <source>Your password will not be included in the QR code anymore.
+You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
+Make sure that you backed it up if you want to use your account later.</source>
+        <translation>Kata laluan anda sudah tidak akan disertakan dalam kod QR.
+Anda tidak akan mampu log masuk menerusi kod QR tanpa memasukkan kata laluan anda lagi kerana perbuatan ini tidak boleh diundur!
+Pastikan anda sandarkannya jika anda ingin gunakan akaun anda kemudian.</translation>
+    </message>
+    <message>
+        <source>Remove password</source>
+        <translation>Buang kata laluan</translation>
+    </message>
+</context>
+<context>
+    <name>DisablePlainTextPasswordDisplay</name>
+    <message>
+        <source>Do not show password as text</source>
+        <translation>Jangan tunjukkan kata laluan sebagai teks</translation>
+    </message>
+    <message>
+        <source>Your password will not be shown as text anymore.
+You won&apos;t be able to see your password as text again because this action cannot be undone!
+Make sure that you backed it up if you want to use your account later.</source>
+        <translation>Kata laluan anda sudah tidak akan ditunjukkan sebagai teks.
+Anda tidak akan mampu melihat kata laluan anda sebagai teks lagi kerana perbuatan ini tidak boleh diundur!
+Pastikan anda sandarkannya jika anda ingin gunakan akaun anda kemudian.</translation>
+    </message>
+    <message>
+        <source>Do not show password</source>
+        <translation>Jangan tunjuk kata laluan</translation>
+    </message>
+</context>
 <context>
     <name>DownloadJob</name>
     <message>
@@ -325,18 +531,18 @@
     <name>FileChooser</name>
     <message>
         <source>Select a file</source>
-        <translation>Pilih fail</translation>
+        <translation type="vanished">Pilih fail</translation>
     </message>
 </context>
 <context>
     <name>FileChooserMobile</name>
     <message>
         <source>Close</source>
-        <translation>Tutup</translation>
+        <translation type="vanished">Tutup</translation>
     </message>
     <message>
         <source>Go to parent folder</source>
-        <translation>Naik ke folder atas</translation>
+        <translation type="vanished">Naik ke folder atas</translation>
     </message>
 </context>
 <context>
@@ -350,7 +556,7 @@
     <name>GlobalDrawer</name>
     <message>
         <source>Log out</source>
-        <translation>Log keluar</translation>
+        <translation type="vanished">Log keluar</translation>
     </message>
     <message>
         <source>About</source>
@@ -378,15 +584,27 @@
     </message>
     <message>
         <source>Offline</source>
-        <translation type="unfinished"></translation>
+        <translation>Luar talian</translation>
     </message>
     <message>
         <source>Online</source>
-        <translation type="unfinished"></translation>
+        <translation>Dalam talian</translation>
     </message>
     <message>
         <source>Connecting…</source>
-        <translation type="unfinished">Menyambung…</translation>
+        <translation>Menyambung…</translation>
+    </message>
+    <message>
+        <source>Transfer account</source>
+        <translation type="vanished">Pindah akaun</translation>
+    </message>
+    <message>
+        <source>Delete account</source>
+        <translation type="vanished">Padam akaun</translation>
+    </message>
+    <message>
+        <source>Switch device</source>
+        <translation>Tukar peranti</translation>
     </message>
 </context>
 <context>
@@ -414,13 +632,30 @@
     </message>
     <message>
         <source>No password found. Please enter it.</source>
-        <translation>Tiada kata laluan dijumpai. Sila masukkan kata laluan anda.</translation>
+        <translation type="vanished">Tiada kata laluan dijumpai. Sila masukkan kata laluan anda.</translation>
     </message>
     <message>
         <source>No valid login QR code found.</source>
         <translation>Tiada kod QR log masuk yang sah dijumpai.</translation>
     </message>
 </context>
+<context>
+    <name>LocalAccountRemoval</name>
+    <message>
+        <source>Remove account from this app</source>
+        <translation>Buang akaun daripada aplikasi ini</translation>
+    </message>
+    <message>
+        <source>Your account will be removed from this app.
+Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
+        <translation>Akaun anda akan dibuang daripada aplikasi ini.
+Kata laluan anda akan dipadam, pastikan ia disimpan dalam pengurus kata laluan anda atau pastikan anda mengetahui kata laluan anda!</translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation>Buang</translation>
+    </message>
+</context>
 <context>
     <name>LoginPage</name>
     <message>
@@ -501,7 +736,7 @@
     </message>
     <message>
         <source>Log in using a QR-Code</source>
-        <translation>Log masuk menggunakan kod QR</translation>
+        <translation type="vanished">Log masuk menggunakan kod QR</translation>
     </message>
 </context>
 <context>
@@ -578,15 +813,15 @@
     <name>MessageHandler</name>
     <message>
         <source>Could not send message, as a result of not being connected.</source>
-        <translation>Tidak dapat hantar mesej, kerana anda tiada sambungan internet.</translation>
+        <translation type="vanished">Tidak dapat hantar mesej, kerana anda tiada sambungan internet.</translation>
     </message>
     <message>
         <source>Could not correct message, as a result of not being connected.</source>
-        <translation>Tidak dapat membetulkan mesej, kerana anda tidak sambung ke internet.</translation>
+        <translation type="vanished">Tidak dapat membetulkan mesej, kerana anda tidak sambung ke internet.</translation>
     </message>
     <message>
         <source>Spoiler</source>
-        <translation>Spoiler</translation>
+        <translation type="vanished">Beberan</translation>
     </message>
     <message>
         <source>Message could not be sent.</source>
@@ -597,91 +832,110 @@
         <translation>Pembetulan mesej tidak berjaya.</translation>
     </message>
 </context>
+<context>
+    <name>MessageModel</name>
+    <message>
+        <source>Pending</source>
+        <translation>Menghantar</translation>
+    </message>
+    <message>
+        <source>Sent</source>
+        <translation>Dihantar</translation>
+    </message>
+    <message>
+        <source>Delivered</source>
+        <translation>Diterima</translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation>Ralat</translation>
+    </message>
+</context>
 <context>
     <name>MultimediaSettings</name>
     <message>
         <source>Multimedia Settings</source>
-        <translation type="unfinished">Tetapan Multimedia</translation>
+        <translation>Tetapan Multimedia</translation>
     </message>
     <message>
         <source>Configure</source>
-        <translation type="unfinished">Tetapkan</translation>
+        <translation>Tetapkan</translation>
     </message>
     <message>
         <source>Image Capture</source>
-        <translation type="unfinished">Tangkapan Imej</translation>
+        <translation>Tangkapan Imej</translation>
     </message>
     <message>
         <source>Audio Recording</source>
-        <translation type="unfinished">Rakaman Audio</translation>
+        <translation>Rakaman Audio</translation>
     </message>
     <message>
         <source>Video Recording</source>
-        <translation type="unfinished">Rakaman Video</translation>
+        <translation>Rakaman Video</translation>
     </message>
     <message>
         <source>Camera</source>
-        <translation type="unfinished">Kamera</translation>
+        <translation>Kamera</translation>
     </message>
     <message>
         <source>Audio input</source>
-        <translation type="unfinished">Kemasukan audio</translation>
+        <translation>Kemasukan audio</translation>
     </message>
     <message>
         <source>Container</source>
-        <translation type="unfinished">Bekas</translation>
+        <translation>Bekas</translation>
     </message>
     <message>
         <source>Image</source>
-        <translation type="unfinished">Imej</translation>
+        <translation>Imej</translation>
     </message>
     <message>
         <source>Audio</source>
-        <translation type="unfinished">Audio</translation>
+        <translation>Audio</translation>
     </message>
     <message>
         <source>Video</source>
-        <translation type="unfinished">Video</translation>
+        <translation>Video</translation>
     </message>
     <message>
         <source>Codec</source>
-        <translation type="unfinished">Kodek</translation>
+        <translation>Kodek</translation>
     </message>
     <message>
         <source>Resolution</source>
-        <translation type="unfinished">Resolusi</translation>
+        <translation>Resolusi</translation>
     </message>
     <message>
         <source>Quality</source>
-        <translation type="unfinished">Kualiti</translation>
+        <translation>Kualiti</translation>
     </message>
     <message>
         <source>Sample Rate</source>
-        <translation type="unfinished">Kadar Sampel</translation>
+        <translation>Kadar Sampel</translation>
     </message>
     <message>
         <source>Frame Rate</source>
-        <translation type="unfinished">Kadar Bingkai</translation>
+        <translation>Kadar Bingkai</translation>
     </message>
     <message>
         <source>Ready</source>
-        <translation type="unfinished">Sedia</translation>
+        <translation>Sedia</translation>
     </message>
     <message>
-        <source>Initializing...</source>
-        <translation type="unfinished">Mengasalkan...</translation>
+        <source>Initializing…</source>
+        <translation>Mengasalkan…</translation>
     </message>
     <message>
         <source>Unavailable</source>
-        <translation type="unfinished">Tidak tersedia</translation>
+        <translation>Tidak tersedia</translation>
     </message>
     <message>
-        <source>Recording...</source>
-        <translation type="unfinished">Merakam...</translation>
+        <source>Recording…</source>
+        <translation>Merakam…</translation>
     </message>
     <message>
         <source>Paused</source>
-        <translation type="unfinished">Dijedakan</translation>
+        <translation>Dijedakan</translation>
     </message>
 </context>
 <context>
@@ -755,16 +1009,16 @@
         <translation type="vanished">Sedia</translation>
     </message>
     <message>
-        <source>Initializing...</source>
-        <translation type="vanished">Mengasalkan...</translation>
+        <source>Initializing…</source>
+        <translation type="vanished">Mengasalkan…</translation>
     </message>
     <message>
         <source>Unavailable</source>
         <translation type="vanished">Tidak tersedia</translation>
     </message>
     <message>
-        <source>Recording...</source>
-        <translation type="vanished">Merakam...</translation>
+        <source>Recording…</source>
+        <translation type="vanished">Merakam…</translation>
     </message>
     <message>
         <source>Paused</source>
@@ -778,22 +1032,48 @@
         <translation>Sedia</translation>
     </message>
     <message>
-        <source>Initializing...</source>
-        <translation>Mengasalkan...</translation>
+        <source>Initializing…</source>
+        <translation>Mengasalkan…</translation>
     </message>
     <message>
         <source>Unavailable</source>
         <translation>Tidak tersedia</translation>
     </message>
     <message>
-        <source>Recording... %1</source>
-        <translation>Merakam... %1</translation>
+        <source>Recording… %1</source>
+        <translation>Merakam… %1</translation>
     </message>
     <message>
         <source>Paused %1</source>
         <translation>Dijedakan %1</translation>
     </message>
 </context>
+<context>
+    <name>PasswordRemovalPage</name>
+    <message>
+        <source>Remove password</source>
+        <translation>Buang kata laluan</translation>
+    </message>
+    <message>
+        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
+        <translation>Anda boleh pilih sama ada anda hanya ingin kata laluan anda tidak ditunjukkan sebagai teks lagi untuk &lt;b&gt;%1&lt;/b&gt; ataupun anda ingin membuang kata laluan sepenuhnya daripada pindahan akaun. Jika anda membuang kata laluan sepenuhnya, anda tidak akan mampu menggunakan fungsi pindahan akaun secara imbasan tanpa memasukkan kata laluan anda kerana kata laluan akan turut dibuang daripada kod QR.</translation>
+    </message>
+    <message>
+        <source>Do not show password as text</source>
+        <translation>Jangan tunjuk kata laluan sebagai teks</translation>
+    </message>
+    <message>
+        <source>Remove completely</source>
+        <translation>Buang sepenuhnya</translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Mark as read</source>
+        <translation>Tanda sebagai telah dibaca</translation>
+    </message>
+</context>
 <context>
     <name>QmlUtils</name>
     <message>
@@ -826,43 +1106,58 @@
     </message>
     <message>
         <source>Invisible</source>
-        <translation>Tidak kelihatan</translation>
+        <translation type="vanished">Tidak kelihatan</translation>
     </message>
     <message>
         <source>Invalid username or password.</source>
-        <translation type="unfinished">Nama pengguna atau kata laluan tidak sah.</translation>
+        <translation>Nama pengguna atau kata laluan tidak sah.</translation>
     </message>
     <message>
         <source>Cannot connect to the server. Please check your internet connection.</source>
-        <translation type="unfinished">Tidak dapat menghubungi pelayan. Sila periksa sambungan internet anda.</translation>
+        <translation>Tidak dapat menghubungi pelayan. Sila periksa sambungan internet anda.</translation>
     </message>
     <message>
         <source>The server doesn&apos;t support secure connections.</source>
-        <translation type="unfinished">Pelayan tidak menyokong sambungan selamat.</translation>
+        <translation>Pelayan tidak menyokong sambungan selamat.</translation>
     </message>
     <message>
         <source>Error while trying to connect securely.</source>
-        <translation type="unfinished">Ralat ketika cuba untuk menyambung secara selamat.</translation>
+        <translation>Ralat ketika cuba untuk menyambung secara selamat.</translation>
     </message>
     <message>
         <source>Could not resolve the server&apos;s address. Please check your server name.</source>
-        <translation type="unfinished"></translation>
+        <translation>Tidak dapat menyelesaikan alamat pelayan. Sila periksa nama pelayan anda.</translation>
     </message>
     <message>
         <source>Could not connect to the server.</source>
-        <translation type="unfinished">Tidak dapat menghubungi pelayan.</translation>
+        <translation type="obsolete">Tidak dapat menghubungi pelayan.</translation>
     </message>
     <message>
         <source>Authentification protocol not supported by the server.</source>
-        <translation type="unfinished">Protokol pengesahan tidak disokong oleh pelayan.</translation>
+        <translation>Protokol pengesahan tidak disokong oleh pelayan.</translation>
     </message>
     <message>
         <source>This server does not support registration.</source>
-        <translation type="unfinished"></translation>
+        <translation>Pelayan ini tidak menyokong pendaftaran.</translation>
     </message>
     <message>
-        <source>An unknown error occured.</source>
-        <translation type="unfinished"></translation>
+        <source>The server is offline or blocked by a firewall.</source>
+        <translation>Pelayan berada di luar talian atau disekat tembok api.</translation>
+    </message>
+    <message>
+        <source>The connection could not be refreshed.</source>
+        <translation>Sambungan tidak dapat disegarkan semula.</translation>
+    </message>
+    <message>
+        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
+        <translation>Capaian internet tidak dibenarkan. Sila periksa tatarajah capaian internet sistem anda.</translation>
+    </message>
+</context>
+<context>
+    <name>QrCodeGenerator</name>
+    <message>
+        <source>Generating the QR code failed: %1</source>
+        <translation>Penjanaan kod QR telah gagal: %1</translation>
     </message>
 </context>
 <context>
@@ -885,6 +1180,45 @@ Cuba tutup aplikasi lain yang menggunakan kamera.</translation>
         <source>The camera format &apos;%1&apos; is not supported.</source>
         <translation>Format kamera &apos;%1&apos; tidak disokong.</translation>
     </message>
+    <message>
+        <source>Logging in…</source>
+        <translation type="vanished">Sedang log masuk…</translation>
+    </message>
+    <message>
+        <source>Scan the QR code from your existing device to transfer your account.</source>
+        <translation>Imbas kod QR daripada peranti anda yang sedia ada untuk memindahkan akaun anda.</translation>
+    </message>
+    <message>
+        <source>Show explanation</source>
+        <translation>Tunjukkan penjelasan</translation>
+    </message>
+    <message>
+        <source>Scan</source>
+        <translation>Imbas</translation>
+    </message>
+    <message>
+        <source>Continue without QR code</source>
+        <translation>Teruskan tanpa kod QR</translation>
+    </message>
+    <message>
+        <source>Connecting…</source>
+        <translation>Menyambung…</translation>
+    </message>
+</context>
+<context>
+    <name>RegistrationLoginDecisionPage</name>
+    <message>
+        <source>Set up</source>
+        <translation>Persediakan</translation>
+    </message>
+    <message>
+        <source>Register a new account</source>
+        <translation>Daftar akaun baharu</translation>
+    </message>
+    <message>
+        <source>Use an existing account</source>
+        <translation>Guna akaun sedia ada</translation>
+    </message>
 </context>
 <context>
     <name>RegistrationManager</name>
@@ -897,6 +1231,23 @@ Cuba tutup aplikasi lain yang menggunakan kamera.</translation>
         <translation>Gagal menukar kata laluan: %1</translation>
     </message>
 </context>
+<context>
+    <name>RemoteAccountDeletion</name>
+    <message>
+        <source>Delete account completely</source>
+        <translation>Padam akaun keseluruhannya</translation>
+    </message>
+    <message>
+        <source>Your account will be deleted completely, which means from this app and from the server.
+You will not be able to use your account again!</source>
+        <translation>Akaun anda akan dipadam keseluruhannya, iaitu dipadam daripada aplikasi ini dan juga daripada pelayan.
+Anda tidak akan mampu menggunakan akaun anda lagi!</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Padam</translation>
+    </message>
+</context>
 <context>
     <name>RosterAddContactSheet</name>
     <message>
@@ -909,7 +1260,7 @@ Cuba tutup aplikasi lain yang menggunakan kamera.</translation>
     </message>
     <message>
         <source>user@example.org</source>
-        <translation>contoh＠emel.com</translation>
+        <translation>contohemel@example.org</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -987,7 +1338,7 @@ Cuba tutup aplikasi lain yang menggunakan kamera.</translation>
     </message>
     <message>
         <source>Spoiler</source>
-        <translation>Spoiler</translation>
+        <translation>Beberan</translation>
     </message>
     <message>
         <source>Could not rename contact, as a result of not being connected.</source>
@@ -1037,7 +1388,7 @@ Cuba tutup aplikasi lain yang menggunakan kamera.</translation>
     </message>
     <message>
         <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your roster?</source>
-        <translation>Adakah anda ingin memadam kenalan &lt;b&gt;%1&lt;/b&gt; daripada roster anda?</translation>
+        <translation>Adakah anda ingin memadam kenalan &lt;b&gt;%1&lt;/b&gt; daripada senarai anda?</translation>
     </message>
 </context>
 <context>
@@ -1048,7 +1399,7 @@ Cuba tutup aplikasi lain yang menggunakan kamera.</translation>
     </message>
     <message>
         <source>Edit name:</source>
-        <translation>Sunting nama:</translation>
+        <translation type="vanished">Sunting nama:</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -1074,6 +1425,71 @@ Cuba tutup aplikasi lain yang menggunakan kamera.</translation>
         <translation>Kapsyen</translation>
     </message>
 </context>
+<context>
+    <name>ServerListModel</name>
+    <message>
+        <source>Custom server</source>
+        <translation>Pelayan tersuai</translation>
+    </message>
+    <message>
+        <source>No limitation</source>
+        <extracomment>Unlimited file size for uploading files
+----------
+Deletion of message history saved on server</extracomment>
+        <translation>Tiada had</translation>
+    </message>
+    <message>
+        <source>%1 days</source>
+        <translation>%1 hari</translation>
+    </message>
+</context>
+<context>
+    <name>SettingsContent</name>
+    <message>
+        <source>Change password</source>
+        <translation>Tukar kata laluan</translation>
+    </message>
+    <message>
+        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
+        <translation>Tukar kata laluan akaun anda. Anda perlu masukkan ia semula di kesemua peranti anda yang lain.</translation>
+    </message>
+    <message>
+        <source>Multimedia Settings</source>
+        <translation>Tetapan Multimedia</translation>
+    </message>
+    <message>
+        <source>Configure photo, video and audio recording settings</source>
+        <translation>Menatarajah tetapan rakaman gambar, video dan audio</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>Tetapan</translation>
+    </message>
+    <message>
+        <source>Account security</source>
+        <translation>Keselamatan akaun</translation>
+    </message>
+    <message>
+        <source>configure whether this device can be used to log in on a new device</source>
+        <translation>tetapkan sama ada peranti ini boleh digunakan untuk log masuk peranti baharu</translation>
+    </message>
+    <message>
+        <source>Remove account from Kaidan</source>
+        <translation>Buang akaun daripada Kaidan</translation>
+    </message>
+    <message>
+        <source>Remove account from this app</source>
+        <translation>Buang akaun daripada aplikasi ini</translation>
+    </message>
+    <message>
+        <source>Delete account</source>
+        <translation>Padam akaun</translation>
+    </message>
+    <message>
+        <source>Delete account from the server</source>
+        <translation>Padam akaun daripada pelayan</translation>
+    </message>
+</context>
 <context>
     <name>SettingsPage</name>
     <message>
@@ -1082,19 +1498,33 @@ Cuba tutup aplikasi lain yang menggunakan kamera.</translation>
     </message>
     <message>
         <source>Change password</source>
-        <translation>Tukar kata laluan</translation>
+        <translation type="vanished">Tukar kata laluan</translation>
     </message>
     <message>
         <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
-        <translation>Tukar kata laluan akaun anda. Anda perlu log masuk semula di kesemua peranti anda yang lain.</translation>
+        <translation type="vanished">Tukar kata laluan akaun anda. Anda perlu log masuk semula di kesemua peranti anda yang lain.</translation>
     </message>
     <message>
         <source>Multimedia Settings</source>
-        <translation type="unfinished">Tetapan Multimedia</translation>
+        <translation type="obsolete">Tetapan Multimedia</translation>
+    </message>
+</context>
+<context>
+    <name>SettingsSheet</name>
+    <message>
+        <source>Settings</source>
+        <translation type="vanished">Tetapan</translation>
+    </message>
+</context>
+<context>
+    <name>StartPage</name>
+    <message>
+        <source>Enjoy free communication on every device!</source>
+        <translation>Nikmati perhubungan percuma di setiap peranti!</translation>
     </message>
     <message>
-        <source>Configure photo, video and audio recording settings</source>
-        <translation type="unfinished"></translation>
+        <source>Let&apos;s start</source>
+        <translation>Mari mulakan</translation>
     </message>
 </context>
 <context>
@@ -1105,7 +1535,7 @@ Cuba tutup aplikasi lain yang menggunakan kamera.</translation>
     </message>
     <message>
         <source>You received a subscription request by &lt;b&gt;%1&lt;/b&gt;. If you accept it, the account will have access to your presence status.</source>
-        <translation>Anda menerima permintaan langganan daripada &lt;b&gt;%1&lt;/b&gt;. Jika anda terima, akaun tersebut boleh mencapai status kehadiran anda.</translation>
+        <translation>Anda mendapat permintaan langganan daripada &lt;b&gt;%1&lt;/b&gt;. Jika anda terima, akaun tersebut boleh mencapai status kehadiran anda.</translation>
     </message>
     <message>
         <source>Decline</source>
@@ -1140,6 +1570,10 @@ Cuba tutup aplikasi lain yang menggunakan kamera.</translation>
         <source>File</source>
         <translation>Fail</translation>
     </message>
+    <message>
+        <source>Message could not be sent.</source>
+        <translation>Mesej tidak dapat dihantar.</translation>
+    </message>
 </context>
 <context>
     <name>UserProfilePage</name>
