@@ -19,6 +19,10 @@
         <source>View source code online</source>
         <translation>Vis kildekoden på nett</translation>
     </message>
+    <message>
+        <source>Report problems</source>
+        <translation>Innrapporter problemer</translation>
+    </message>
 </context>
 <context>
     <name>AboutSheet</name>
@@ -35,6 +39,77 @@
         <translation type="vanished">Kildekode på GitHub</translation>
     </message>
 </context>
+<context>
+    <name>AccountDeletionFromClientAndServerConfirmationPage</name>
+    <message>
+        <source>Delete</source>
+        <translation type="obsolete">Slett</translation>
+    </message>
+</context>
+<context>
+    <name>AccountSecurity</name>
+    <message>
+        <source>Account Security</source>
+        <translation>Kontosikkerhet</translation>
+    </message>
+    <message>
+        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
+        <translation type="unfinished">Tillat tillegg av nye enheter ved bruk av QR-kode, men aldri vis passord som tekst. Denne handlingen kan ikke angres, så overvei å lagre passordet på annet vis først.</translation>
+    </message>
+    <message>
+        <source>Disable showing the password</source>
+        <translation>Skru av visning av passordet</translation>
+    </message>
+    <message>
+        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
+        <translation>Ikke vis passordet i noen form. Denne handlingen kan ikke angres.</translation>
+    </message>
+    <message>
+        <source>Disable showing the QR-Code and password</source>
+        <translation>Skru av visning av QR-kode og passord</translation>
+    </message>
+</context>
+<context>
+    <name>AccountTransferPage</name>
+    <message>
+        <source>Transfer account to another device</source>
+        <translation>Overfør konto til en annen enhet</translation>
+    </message>
+    <message>
+        <source>Scan the QR code or enter the credentials as text on another device to log in on it.
+
+Attention:
+Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
+        <translation>Skann QR-koden eller skriv inn identitetsdetaljene som tekst på en annen enhet for å logge inn på den.
+
+Merk:
+Aldri vis denne QR-koden til noen andre. Den gir ubegrenset tilganger til kontoen din!</translation>
+    </message>
+    <message>
+        <source>Chat address:</source>
+        <translation>Sludreadresse:</translation>
+    </message>
+    <message>
+        <source>Password:</source>
+        <translation>Passord:</translation>
+    </message>
+    <message>
+        <source>Hide QR code</source>
+        <translation>Skjul QR-kode</translation>
+    </message>
+    <message>
+        <source>Show as QR code</source>
+        <translation>Vis som QR-kode</translation>
+    </message>
+    <message>
+        <source>Hide text</source>
+        <translation>Skjul tekst</translation>
+    </message>
+    <message>
+        <source>Show as text</source>
+        <translation>Vis som tekst</translation>
+    </message>
+</context>
 <context>
     <name>BackButton</name>
     <message>
@@ -93,11 +168,11 @@
     </message>
     <message>
         <source>Copy Message</source>
-        <translation>Kopier melding</translation>
+        <translation type="vanished">Kopier melding</translation>
     </message>
     <message>
         <source>Edit Message</source>
-        <translation>Rediger melding</translation>
+        <translation type="vanished">Rediger melding</translation>
     </message>
     <message>
         <source>Spoiler</source>
@@ -107,13 +182,24 @@
         <source>Download</source>
         <translation>Last ned</translation>
     </message>
+</context>
+<context>
+    <name>ChatMessageContextMenu</name>
     <message>
-        <source>Copy download URL</source>
-        <translation type="unfinished"></translation>
+        <source>Copy message</source>
+        <translation>Kopier melding</translation>
     </message>
     <message>
-        <source>Quote</source>
-        <translation type="unfinished"></translation>
+        <source>Edit message</source>
+        <translation>Rediger melding</translation>
+    </message>
+    <message>
+        <source>Copy download URL</source>
+        <translation>Kopier nedlastings-nettadresse</translation>
+    </message>
+    <message>
+        <source>Quote message</source>
+        <translation>Siter melding</translation>
     </message>
 </context>
 <context>
@@ -148,7 +234,7 @@
     </message>
     <message>
         <source>Select a file</source>
-        <translation>Velg en fil</translation>
+        <translation type="vanished">Velg en fil</translation>
     </message>
     <message>
         <source>Send a spoiler message</source>
@@ -160,15 +246,15 @@
     </message>
     <message>
         <source>Unmute notifications</source>
-        <translation type="unfinished"></translation>
+        <translation>Opphev forstumming av merknader</translation>
     </message>
     <message>
         <source>Mute notifications</source>
-        <translation type="unfinished"></translation>
+        <translation>Forstum merknader</translation>
     </message>
     <message>
         <source>View profile</source>
-        <translation type="unfinished"></translation>
+        <translation>Vis profil</translation>
     </message>
     <message>
         <source>Search</source>
@@ -180,54 +266,68 @@
     </message>
     <message>
         <source>Search up</source>
-        <translation type="unfinished"></translation>
+        <translation>Søk oppover</translation>
     </message>
     <message>
         <source>Search down</source>
-        <translation type="unfinished"></translation>
+        <translation>Søk nedover</translation>
     </message>
     <message>
         <source>All files</source>
-        <translation type="unfinished"></translation>
+        <translation>Alle filer</translation>
+    </message>
+</context>
+<context>
+    <name>ClientWorker</name>
+    <message>
+        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
+        <translation>Kontoen din kunne ikke slettes fra tjeneren. Derfor ble den heller ikke fjernet fra dette programmet: %1</translation>
     </message>
 </context>
 <context>
     <name>CommonEncoderSettings</name>
     <message>
         <source>Very low</source>
-        <translation type="unfinished"></translation>
+        <translation>Veldig lavt</translation>
     </message>
     <message>
         <source>Low</source>
-        <translation type="unfinished"></translation>
+        <translation>Lavt</translation>
     </message>
     <message>
         <source>Normal</source>
-        <translation type="unfinished"></translation>
+        <translation>Normalt</translation>
     </message>
     <message>
         <source>High</source>
-        <translation type="unfinished"></translation>
+        <translation>Høyt</translation>
     </message>
     <message>
         <source>Very high</source>
-        <translation type="unfinished"></translation>
+        <translation>Veldig høyt</translation>
     </message>
     <message>
         <source>Constant quality</source>
-        <translation type="unfinished"></translation>
+        <translation>Konstant kvalitet</translation>
     </message>
     <message>
         <source>Constant bit rate</source>
-        <translation type="unfinished"></translation>
+        <translation>Konstant bitrate</translation>
     </message>
     <message>
         <source>Average bit rate</source>
-        <translation type="unfinished"></translation>
+        <translation>Gjennomsnittlig bitrate</translation>
     </message>
     <message>
         <source>Two pass</source>
-        <translation type="unfinished"></translation>
+        <translation>Dobbelt-arbeidet</translation>
+    </message>
+</context>
+<context>
+    <name>ConfirmationPage</name>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">Avbryt</translation>
     </message>
 </context>
 <context>
@@ -237,6 +337,44 @@
         <translation type="vanished">Handling</translation>
     </message>
 </context>
+<context>
+    <name>DisablePasswordDisplay</name>
+    <message>
+        <source>Remove password completely</source>
+        <translation>Fjern passord fullstendig</translation>
+    </message>
+    <message>
+        <source>Your password will not be included in the QR code anymore.
+You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
+Make sure that you backed it up if you want to use your account later.</source>
+        <translation>Passordet ditt vil ikke lenger være å finne i QR-koden.
+Du vil ikke kunne logge inn via QR-koden uten å skrive passordet ditt igjen, fordi handlingen ikke kan angres.
+Forsikre deg om at du har sikkerhetskopiert det hvis du ønsker å bruke kontoen din senere.</translation>
+    </message>
+    <message>
+        <source>Remove password</source>
+        <translation>Fjern passord</translation>
+    </message>
+</context>
+<context>
+    <name>DisablePlainTextPasswordDisplay</name>
+    <message>
+        <source>Do not show password as text</source>
+        <translation>Ikke vis passordet som tekst</translation>
+    </message>
+    <message>
+        <source>Your password will not be shown as text anymore.
+You won&apos;t be able to see your password as text again because this action cannot be undone!
+Make sure that you backed it up if you want to use your account later.</source>
+        <translation>Passordet ditt vil ikke lenger bli vist som tekst.
+Du vil ikke kunne se passordet ditt som tekst igjen fordi handlingen ikke kan angres.
+Forsikre deg om at du har sikkerhetskopiert passordet hvis du ønsker å bruke den senere.</translation>
+    </message>
+    <message>
+        <source>Do not show password</source>
+        <translation>Ikke vis passord</translation>
+    </message>
+</context>
 <context>
     <name>DownloadJob</name>
     <message>
@@ -306,7 +444,7 @@
     <name>FileChooser</name>
     <message>
         <source>Select a file</source>
-        <translation>Velg en fil</translation>
+        <translation type="vanished">Velg en fil</translation>
     </message>
 </context>
 <context>
@@ -317,11 +455,11 @@
     </message>
     <message>
         <source>Close</source>
-        <translation>Lukk</translation>
+        <translation type="vanished">Lukk</translation>
     </message>
     <message>
         <source>Go to parent folder</source>
-        <translation>Gå til ovennevnt mappe</translation>
+        <translation type="vanished">Gå til ovennevnt mappe</translation>
     </message>
 </context>
 <context>
@@ -339,7 +477,7 @@
     </message>
     <message>
         <source>Log out</source>
-        <translation>Logg ut</translation>
+        <translation type="vanished">Logg ut</translation>
     </message>
     <message>
         <source>About</source>
@@ -363,12 +501,16 @@
     </message>
     <message>
         <source>Online</source>
-        <translation type="unfinished"></translation>
+        <translation>Pålogget</translation>
     </message>
     <message>
         <source>Connecting…</source>
         <translation type="unfinished">Kobler til…</translation>
     </message>
+    <message>
+        <source>Switch device</source>
+        <translation>Bytt enhet</translation>
+    </message>
 </context>
 <context>
     <name>Kaidan</name>
@@ -394,12 +536,25 @@
         <translation type="vanished">Kunne ikke sende fil, som resultat av å ikke være tilkoblet.</translation>
     </message>
     <message>
-        <source>No password found. Please enter it.</source>
-        <translation type="unfinished"></translation>
+        <source>No valid login QR code found.</source>
+        <translation>Fant ingen gyldig QR-kode for innlogging.</translation>
+    </message>
+</context>
+<context>
+    <name>LocalAccountRemoval</name>
+    <message>
+        <source>Remove account from this app</source>
+        <translation>Fjern konto fra dette programmet</translation>
     </message>
     <message>
-        <source>No valid login QR code found.</source>
-        <translation type="unfinished"></translation>
+        <source>Your account will be removed from this app.
+Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
+        <translation>Kontoen din vil bli fjernet fra dette programmet.
+Passordet ditt vil bli slettet, forsikre deg om at det er lagret i en passordshåndterer, eller at du husker det!</translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation>Fjern</translation>
     </message>
 </context>
 <context>
@@ -476,94 +631,90 @@
         <source>An unknown error occured; see log for details.</source>
         <translation type="vanished">En ukjent feil inntraff; sjekk loggen for detaljer.</translation>
     </message>
-    <message>
-        <source>Log in using a QR-Code</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>MediaRecorder</name>
     <message>
         <source>Default</source>
-        <translation type="unfinished"></translation>
+        <translation>Forvalg</translation>
     </message>
 </context>
 <context>
     <name>MediaUtils</name>
     <message>
         <source>Take picture</source>
-        <translation type="unfinished"></translation>
+        <translation>Ta bilde</translation>
     </message>
     <message>
         <source>Record video</source>
-        <translation type="unfinished"></translation>
+        <translation>Ta opp video</translation>
     </message>
     <message>
         <source>Record voice</source>
-        <translation type="unfinished"></translation>
+        <translation>Ta opp stemme</translation>
     </message>
     <message>
         <source>Send location</source>
-        <translation type="unfinished"></translation>
+        <translation>Send plassering</translation>
     </message>
     <message>
         <source>Choose file</source>
-        <translation type="unfinished"></translation>
+        <translation>Velg fil</translation>
     </message>
     <message>
         <source>Choose image</source>
-        <translation type="unfinished"></translation>
+        <translation>Velg bilde</translation>
     </message>
     <message>
         <source>Choose video</source>
-        <translation type="unfinished"></translation>
+        <translation>Velg video</translation>
     </message>
     <message>
         <source>Choose audio file</source>
-        <translation type="unfinished"></translation>
+        <translation>Velg lydfil</translation>
     </message>
     <message>
         <source>Choose document</source>
-        <translation type="unfinished"></translation>
+        <translation>Velg dokument</translation>
     </message>
     <message>
         <source>All files</source>
-        <translation type="unfinished"></translation>
+        <translation>Alle filer</translation>
     </message>
     <message>
         <source>Images</source>
-        <translation type="unfinished"></translation>
+        <translation>Bilder</translation>
     </message>
     <message>
         <source>Videos</source>
-        <translation type="unfinished"></translation>
+        <translation>Videoer</translation>
     </message>
     <message>
         <source>Audio files</source>
-        <translation type="unfinished"></translation>
+        <translation>Lydfiler</translation>
     </message>
     <message>
         <source>Documents</source>
-        <translation type="unfinished"></translation>
+        <translation>Dokumenter</translation>
     </message>
     <message>
         <source>%1 (%2)</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 (%2)</translation>
     </message>
 </context>
 <context>
     <name>MessageHandler</name>
     <message>
         <source>Could not send message, as a result of not being connected.</source>
-        <translation type="unfinished">Kunne ikke sende melding, som følge av manglende tilkobling.</translation>
+        <translation type="obsolete">Kunne ikke sende melding, som følge av manglende tilkobling.</translation>
     </message>
     <message>
         <source>Could not correct message, as a result of not being connected.</source>
-        <translation type="unfinished">Kunne ikke korrigere melding, siden du ikke er tilkoblet.</translation>
+        <translation type="obsolete">Kunne ikke korrigere melding, siden du ikke er tilkoblet.</translation>
     </message>
     <message>
         <source>Spoiler</source>
-        <translation>Avsløring</translation>
+        <translation type="vanished">Avsløring</translation>
     </message>
     <message>
         <source>Message could not be sent.</source>
@@ -574,39 +725,58 @@
         <translation type="unfinished">Meldingstilkobling mislyktes.</translation>
     </message>
 </context>
+<context>
+    <name>MessageModel</name>
+    <message>
+        <source>Pending</source>
+        <translation>Venter</translation>
+    </message>
+    <message>
+        <source>Sent</source>
+        <translation>Sendt</translation>
+    </message>
+    <message>
+        <source>Delivered</source>
+        <translation>Levert</translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished">Feil</translation>
+    </message>
+</context>
 <context>
     <name>MultimediaSettings</name>
     <message>
         <source>Multimedia Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Multimediainnstillinger</translation>
     </message>
     <message>
         <source>Configure</source>
-        <translation type="unfinished"></translation>
+        <translation>Sett opp</translation>
     </message>
     <message>
         <source>Image Capture</source>
-        <translation type="unfinished"></translation>
+        <translation>Bildeknipsing</translation>
     </message>
     <message>
         <source>Audio Recording</source>
-        <translation type="unfinished"></translation>
+        <translation>Lydopptak</translation>
     </message>
     <message>
         <source>Video Recording</source>
-        <translation type="unfinished"></translation>
+        <translation>Videoopptak</translation>
     </message>
     <message>
         <source>Camera</source>
-        <translation type="unfinished"></translation>
+        <translation>Kamera</translation>
     </message>
     <message>
         <source>Audio input</source>
-        <translation type="unfinished"></translation>
+        <translation>Lydinngang</translation>
     </message>
     <message>
         <source>Container</source>
-        <translation type="unfinished"></translation>
+        <translation>Beholder</translation>
     </message>
     <message>
         <source>Image</source>
@@ -622,43 +792,43 @@
     </message>
     <message>
         <source>Codec</source>
-        <translation type="unfinished"></translation>
+        <translation>Kodek</translation>
     </message>
     <message>
         <source>Resolution</source>
-        <translation type="unfinished"></translation>
+        <translation>Oppløsning</translation>
     </message>
     <message>
         <source>Quality</source>
-        <translation type="unfinished"></translation>
+        <translation>Kvalitet</translation>
     </message>
     <message>
         <source>Sample Rate</source>
-        <translation type="unfinished"></translation>
+        <translation>Samplingstakt</translation>
     </message>
     <message>
         <source>Frame Rate</source>
-        <translation type="unfinished"></translation>
+        <translation>Rammetakt</translation>
     </message>
     <message>
         <source>Ready</source>
-        <translation type="unfinished"></translation>
+        <translation>Klar</translation>
     </message>
     <message>
-        <source>Initializing...</source>
-        <translation type="unfinished"></translation>
+        <source>Initializing…</source>
+        <translation>Igangsetter…</translation>
     </message>
     <message>
         <source>Unavailable</source>
-        <translation type="unfinished"></translation>
+        <translation>Utilgjengelig</translation>
     </message>
     <message>
-        <source>Recording...</source>
-        <translation type="unfinished"></translation>
+        <source>Recording…</source>
+        <translation>Tar opp…</translation>
     </message>
     <message>
         <source>Paused</source>
-        <translation type="unfinished"></translation>
+        <translation>Pauset</translation>
     </message>
 </context>
 <context>
@@ -680,23 +850,49 @@
     <name>NewMedia</name>
     <message>
         <source>Ready</source>
-        <translation type="unfinished"></translation>
+        <translation>Klar</translation>
     </message>
     <message>
-        <source>Initializing...</source>
-        <translation type="unfinished"></translation>
+        <source>Initializing…</source>
+        <translation>Igangsetter…</translation>
     </message>
     <message>
         <source>Unavailable</source>
-        <translation type="unfinished"></translation>
+        <translation>Utilgjengelig</translation>
     </message>
     <message>
-        <source>Recording... %1</source>
-        <translation type="unfinished"></translation>
+        <source>Recording… %1</source>
+        <translation>Tar opp… %1</translation>
     </message>
     <message>
         <source>Paused %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Satt på pause %1</translation>
+    </message>
+</context>
+<context>
+    <name>PasswordRemovalPage</name>
+    <message>
+        <source>Remove password</source>
+        <translation>Fjern passord</translation>
+    </message>
+    <message>
+        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
+        <translation type="unfinished">Du kan bestemme deg for å ikke vise passordet for &lt;b&gt;%1&lt;/b&gt; som tekst i fremtiden, eller å fjerne det helt fra konto-overføringen. Hvis du fjerner passordet helt, vil du ikke kunne bruke konto-overføring via skanning uten å skrive inn passordet ditt, fordi det også fjernes fra QR-koden.</translation>
+    </message>
+    <message>
+        <source>Do not show password as text</source>
+        <translation>Ikke vis passordet som tekst</translation>
+    </message>
+    <message>
+        <source>Remove completely</source>
+        <translation>Fjern fullstendig</translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Mark as read</source>
+        <translation>Marker som lest</translation>
     </message>
 </context>
 <context>
@@ -729,10 +925,6 @@
         <source>Error</source>
         <translation type="unfinished">Feil</translation>
     </message>
-    <message>
-        <source>Invisible</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Invalid username or password.</source>
         <translation type="unfinished">Ugyldig brukernavn eller passord.</translation>
@@ -751,11 +943,11 @@
     </message>
     <message>
         <source>Could not resolve the server&apos;s address. Please check your server name.</source>
-        <translation type="unfinished"></translation>
+        <translation>Kunne ikke fortolke tjenerens adresse. Sjekk ditt tjenernavn.</translation>
     </message>
     <message>
         <source>Could not connect to the server.</source>
-        <translation type="unfinished">Kunne ikke koble til tjeneren.</translation>
+        <translation type="obsolete">Kunne ikke koble til tjeneren.</translation>
     </message>
     <message>
         <source>Authentification protocol not supported by the server.</source>
@@ -763,31 +955,82 @@
     </message>
     <message>
         <source>This server does not support registration.</source>
-        <translation type="unfinished"></translation>
+        <translation>Denne tjeneren støtter ikke registrering.</translation>
     </message>
     <message>
-        <source>An unknown error occured.</source>
-        <translation type="unfinished"></translation>
+        <source>The server is offline or blocked by a firewall.</source>
+        <translation>Tjeneren er nede eller blokkert av en brannmur.</translation>
+    </message>
+    <message>
+        <source>The connection could not be refreshed.</source>
+        <translation>Tilkoblingen kunne ikke gjenoppfriskes.</translation>
+    </message>
+    <message>
+        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
+        <translation type="unfinished">Innvilg internettilgang i systemets tilgangsoppsett.</translation>
+    </message>
+</context>
+<context>
+    <name>QrCodeGenerator</name>
+    <message>
+        <source>Generating the QR code failed: %1</source>
+        <translation>Kunne ikke generere QR-kode: %1</translation>
     </message>
 </context>
 <context>
     <name>QrCodeScannerPage</name>
     <message>
         <source>Scan QR code</source>
-        <translation type="unfinished"></translation>
+        <translation>Skann QR-kode</translation>
     </message>
     <message>
         <source>There is no camera available.</source>
-        <translation type="unfinished"></translation>
+        <translation>Kamera ikke tilgjengelig.</translation>
     </message>
     <message>
         <source>Your camera is busy.
 Try to close other applications using the camera.</source>
-        <translation type="unfinished"></translation>
+        <translation>Kamera ditt er opptatt.
+Prøv å lukke andre programmer ved bruk av kameraet.</translation>
     </message>
     <message>
         <source>The camera format &apos;%1&apos; is not supported.</source>
-        <translation type="unfinished"></translation>
+        <translation>Kameraformatet &quot;%1&quot; støttes ikke.</translation>
+    </message>
+    <message>
+        <source>Scan the QR code from your existing device to transfer your account.</source>
+        <translation>Skann QR-koden fra din eksisterende enhet for å overføre kontoen din.</translation>
+    </message>
+    <message>
+        <source>Show explanation</source>
+        <translation>Vis forklaring</translation>
+    </message>
+    <message>
+        <source>Scan</source>
+        <translation>Skann</translation>
+    </message>
+    <message>
+        <source>Continue without QR code</source>
+        <translation>Fortsett uten QR-kode</translation>
+    </message>
+    <message>
+        <source>Connecting…</source>
+        <translation type="unfinished">Kobler til…</translation>
+    </message>
+</context>
+<context>
+    <name>RegistrationLoginDecisionPage</name>
+    <message>
+        <source>Set up</source>
+        <translation>Sett opp</translation>
+    </message>
+    <message>
+        <source>Register a new account</source>
+        <translation>Registrer ny konto</translation>
+    </message>
+    <message>
+        <source>Use an existing account</source>
+        <translation>Bruk eksisterende konto</translation>
     </message>
 </context>
 <context>
@@ -801,6 +1044,23 @@ Try to close other applications using the camera.</source>
         <translation>Klarte ikke å endre passord: %1</translation>
     </message>
 </context>
+<context>
+    <name>RemoteAccountDeletion</name>
+    <message>
+        <source>Delete account completely</source>
+        <translation>Slett konto fullstendig</translation>
+    </message>
+    <message>
+        <source>Your account will be deleted completely, which means from this app and from the server.
+You will not be able to use your account again!</source>
+        <translation>Kontoen din vil slettes fullstendig, fra programmet og tjeneren.
+Du vil ikke kunne bruke kontoen igjen.</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished">Slett</translation>
+    </message>
+</context>
 <context>
     <name>RosterAddContactSheet</name>
     <message>
@@ -895,7 +1155,7 @@ Try to close other applications using the camera.</source>
     </message>
     <message>
         <source>Could not rename contact, as a result of not being connected.</source>
-        <translation type="unfinished"></translation>
+        <translation>Kunne ikke gi kontakten nytt navn, fordi den ikke er tilkoblet.</translation>
     </message>
 </context>
 <context>
@@ -918,7 +1178,7 @@ Try to close other applications using the camera.</source>
     </message>
     <message>
         <source>Search contacts</source>
-        <translation type="unfinished"></translation>
+        <translation>Søk i kontakter</translation>
     </message>
 </context>
 <context>
@@ -952,11 +1212,7 @@ Try to close other applications using the camera.</source>
     <name>RosterRenameContactSheet</name>
     <message>
         <source>Rename contact</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Edit name:</source>
-        <translation type="unfinished"></translation>
+        <translation>Gi kontakten nytt navn</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -964,7 +1220,7 @@ Try to close other applications using the camera.</source>
     </message>
     <message>
         <source>Rename</source>
-        <translation type="unfinished"></translation>
+        <translation>Gi nytt navn</translation>
     </message>
 </context>
 <context>
@@ -982,6 +1238,71 @@ Try to close other applications using the camera.</source>
         <translation>Bildetekst</translation>
     </message>
 </context>
+<context>
+    <name>ServerListModel</name>
+    <message>
+        <source>Custom server</source>
+        <translation>Egendefinert tjener</translation>
+    </message>
+    <message>
+        <source>No limitation</source>
+        <extracomment>Unlimited file size for uploading files
+----------
+Deletion of message history saved on server</extracomment>
+        <translation>Ingen begrensning</translation>
+    </message>
+    <message>
+        <source>%1 days</source>
+        <translation>%1 dager</translation>
+    </message>
+</context>
+<context>
+    <name>SettingsContent</name>
+    <message>
+        <source>Change password</source>
+        <translation type="unfinished">Endre passord</translation>
+    </message>
+    <message>
+        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
+        <translation type="unfinished">Endrer passord på kontoen din. Du vil måtte skrive det inn igjen på dine andre enheter.</translation>
+    </message>
+    <message>
+        <source>Multimedia Settings</source>
+        <translation>Multimedia-innstillinger</translation>
+    </message>
+    <message>
+        <source>Configure photo, video and audio recording settings</source>
+        <translation>Sett opp bilde- video- og lyd-opptaksinnstillinger</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation type="unfinished">Innstillinger</translation>
+    </message>
+    <message>
+        <source>Account security</source>
+        <translation>Kontosikkerhet</translation>
+    </message>
+    <message>
+        <source>configure whether this device can be used to log in on a new device</source>
+        <translation>Sett opp hvorvidt denne enheten kan brukes for å logge inn på en annen</translation>
+    </message>
+    <message>
+        <source>Remove account from Kaidan</source>
+        <translation>Fjern konto fra Kaidan</translation>
+    </message>
+    <message>
+        <source>Remove account from this app</source>
+        <translation>Fjern konto fra dette programmet</translation>
+    </message>
+    <message>
+        <source>Delete account</source>
+        <translation>Slett konto</translation>
+    </message>
+    <message>
+        <source>Delete account from the server</source>
+        <translation>Slett konto fra tjeneren</translation>
+    </message>
+</context>
 <context>
     <name>SettingsPage</name>
     <message>
@@ -990,19 +1311,29 @@ Try to close other applications using the camera.</source>
     </message>
     <message>
         <source>Change password</source>
-        <translation>Endre passord</translation>
+        <translation type="vanished">Endre passord</translation>
     </message>
     <message>
         <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
-        <translation>Endrer passord på kontoen din. Du vil måtte skrive det inn igjen på dine andre enheter.</translation>
+        <translation type="vanished">Endrer passord på kontoen din. Du vil måtte skrive det inn igjen på dine andre enheter.</translation>
+    </message>
+</context>
+<context>
+    <name>SettingsSheet</name>
+    <message>
+        <source>Settings</source>
+        <translation type="obsolete">Innstillinger</translation>
+    </message>
+</context>
+<context>
+    <name>StartPage</name>
+    <message>
+        <source>Enjoy free communication on every device!</source>
+        <translation>Nyt fri kommunikasjon på alle enheter.</translation>
     </message>
     <message>
-        <source>Multimedia Settings</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Configure photo, video and audio recording settings</source>
-        <translation type="unfinished"></translation>
+        <source>Let&apos;s start</source>
+        <translation>La oss begynne</translation>
     </message>
 </context>
 <context>
@@ -1048,23 +1379,27 @@ Try to close other applications using the camera.</source>
         <source>File</source>
         <translation>Fil</translation>
     </message>
+    <message>
+        <source>Message could not be sent.</source>
+        <translation type="unfinished">Meldingen kunne ikke sendes.</translation>
+    </message>
 </context>
 <context>
     <name>UserProfilePage</name>
     <message>
         <source>Profile</source>
-        <translation type="unfinished"></translation>
+        <translation>Profil</translation>
     </message>
 </context>
 <context>
     <name>VCardModel</name>
     <message>
         <source>Name</source>
-        <translation type="unfinished"></translation>
+        <translation>Navn</translation>
     </message>
     <message>
         <source>Nickname</source>
-        <translation type="unfinished"></translation>
+        <translation>Kallenavn</translation>
     </message>
     <message>
         <source>About</source>
@@ -1072,15 +1407,15 @@ Try to close other applications using the camera.</source>
     </message>
     <message>
         <source>Email</source>
-        <translation type="unfinished"></translation>
+        <translation>E-post</translation>
     </message>
     <message>
         <source>Birthday</source>
-        <translation type="unfinished"></translation>
+        <translation>Geburtsdag</translation>
     </message>
     <message>
         <source>Website</source>
-        <translation type="unfinished"></translation>
+        <translation>Nettside</translation>
     </message>
 </context>
 </TS>
