@@ -15,6 +15,74 @@
         <source>View source code online</source>
         <translation>Переглянути початковий код у інтернеті</translation>
     </message>
+    <message>
+        <source>Report problems</source>
+        <translation>Повідомити про проблеми</translation>
+    </message>
+</context>
+<context>
+    <name>AccountSecurity</name>
+    <message>
+        <source>Account Security</source>
+        <translation>Безпека облікового запису</translation>
+    </message>
+    <message>
+        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
+        <translation>Дозволити додавання нових пристроїв за допомогою QR-коду, але ніколи не показувати пароль як текст. Цю дію неможливо скасувати, тому вам варто зберегти пароль в інший спосіб, перш ніж користатися кодом.</translation>
+    </message>
+    <message>
+        <source>Disable showing the password</source>
+        <translation>Вимкнути показ пароля</translation>
+    </message>
+    <message>
+        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
+        <translation>Не показувати пароль у жодній формі. Наслідки цієї дії не можна скасувати.</translation>
+    </message>
+    <message>
+        <source>Disable showing the QR-Code and password</source>
+        <translation>Вимкнути показ QR-коду і пароля</translation>
+    </message>
+</context>
+<context>
+    <name>AccountTransferPage</name>
+    <message>
+        <source>Transfer account to another device</source>
+        <translation>Перенести обліковий запис на інший пристрій</translation>
+    </message>
+    <message>
+        <source>Scan the QR code or enter the credentials as text on another device to log in on it.
+
+Attention:
+Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
+        <translation>Заскануйте QR-код або введіть реєстраційні дані як текст на іншому пристрої, щоб увійти до облікового запису на ньому.
+
+Увага:
+Ніколи не показуйте цей QR-код стороннім особам. Цей код надає необмежений доступ до вашого облікового запису!</translation>
+    </message>
+    <message>
+        <source>Chat address:</source>
+        <translation>Адреса спілкування:</translation>
+    </message>
+    <message>
+        <source>Password:</source>
+        <translation>Пароль:</translation>
+    </message>
+    <message>
+        <source>Hide QR code</source>
+        <translation>Приховати QR-код</translation>
+    </message>
+    <message>
+        <source>Show as QR code</source>
+        <translation>Показати як QR-код</translation>
+    </message>
+    <message>
+        <source>Hide text</source>
+        <translation>Сховати текст</translation>
+    </message>
+    <message>
+        <source>Show as text</source>
+        <translation>Показати як текст</translation>
+    </message>
 </context>
 <context>
     <name>ChangePassword</name>
@@ -63,11 +131,11 @@
     <name>ChatMessage</name>
     <message>
         <source>Copy Message</source>
-        <translation>Скопіювати повідомлення</translation>
+        <translation type="vanished">Скопіювати повідомлення</translation>
     </message>
     <message>
         <source>Edit Message</source>
-        <translation>Редагування повідомлення</translation>
+        <translation type="vanished">Редагування повідомлення</translation>
     </message>
     <message>
         <source>Spoiler</source>
@@ -79,11 +147,30 @@
     </message>
     <message>
         <source>Copy download URL</source>
-        <translation>Копіювати адресу даних</translation>
+        <translation type="vanished">Копіювати адресу даних</translation>
     </message>
     <message>
         <source>Quote</source>
-        <translation type="unfinished"></translation>
+        <translation type="vanished">Цитування</translation>
+    </message>
+</context>
+<context>
+    <name>ChatMessageContextMenu</name>
+    <message>
+        <source>Copy message</source>
+        <translation>Скопіювати повідомлення</translation>
+    </message>
+    <message>
+        <source>Edit message</source>
+        <translation>Редагування повідомлення</translation>
+    </message>
+    <message>
+        <source>Copy download URL</source>
+        <translation>Копіювати адресу даних</translation>
+    </message>
+    <message>
+        <source>Quote message</source>
+        <translation>Процитувати повідомлення</translation>
     </message>
 </context>
 <context>
@@ -114,7 +201,7 @@
     </message>
     <message>
         <source>Select a file</source>
-        <translation>Виберіть файл</translation>
+        <translation type="vanished">Виберіть файл</translation>
     </message>
     <message>
         <source>Send a spoiler message</source>
@@ -161,6 +248,13 @@
         <translation>усі файли</translation>
     </message>
 </context>
+<context>
+    <name>ClientWorker</name>
+    <message>
+        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
+        <translation>Не вдалося вилучити ваш обліковий запис із сервера. Як наслідок, його також не було вилучено з цієї програми: %1</translation>
+    </message>
+</context>
 <context>
     <name>CommonEncoderSettings</name>
     <message>
@@ -200,6 +294,51 @@
         <translation>Два проходи</translation>
     </message>
 </context>
+<context>
+    <name>ConfirmationPage</name>
+    <message>
+        <source>Cancel</source>
+        <translation>Скасувати</translation>
+    </message>
+</context>
+<context>
+    <name>DisablePasswordDisplay</name>
+    <message>
+        <source>Remove password completely</source>
+        <translation>Вилучити пароль повністю</translation>
+    </message>
+    <message>
+        <source>Your password will not be included in the QR code anymore.
+You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
+Make sure that you backed it up if you want to use your account later.</source>
+        <translation>Ваш пароль більше не включатиметься до QR-коду.
+Ви не зможете скористатися входом за допомогою QR-коду без введення вашого пароля, оскільки наслідки цієї дії неможливо скасувати!
+Переконайтеся, що у вас є резервна копія пароля, якщо хочете надалі користуватися вашим обліковим записом.</translation>
+    </message>
+    <message>
+        <source>Remove password</source>
+        <translation>Вилучити пароль</translation>
+    </message>
+</context>
+<context>
+    <name>DisablePlainTextPasswordDisplay</name>
+    <message>
+        <source>Do not show password as text</source>
+        <translation>Не показувати пароль як текст</translation>
+    </message>
+    <message>
+        <source>Your password will not be shown as text anymore.
+You won&apos;t be able to see your password as text again because this action cannot be undone!
+Make sure that you backed it up if you want to use your account later.</source>
+        <translation>Ваш пароль більше не буде показано у текстовому форматі.
+Ви не зможете бачити ваш пароль як текст, оскільки наслідки цієї дії неможливо скасувати!
+Переконайтеся, що у вас є резервна копія пароля, якщо хочете надалі користуватися вашим обліковим записом.</translation>
+    </message>
+    <message>
+        <source>Do not show password</source>
+        <translation>Не показувати пароль</translation>
+    </message>
+</context>
 <context>
     <name>DownloadJob</name>
     <message>
@@ -269,25 +408,25 @@
     <name>FileChooser</name>
     <message>
         <source>Select a file</source>
-        <translation>Виберіть файл</translation>
+        <translation type="vanished">Виберіть файл</translation>
     </message>
 </context>
 <context>
     <name>FileChooserMobile</name>
     <message>
         <source>Go to parent folder</source>
-        <translation>Перейти до батьківської теки</translation>
+        <translation type="vanished">Перейти до батьківської теки</translation>
     </message>
     <message>
         <source>Close</source>
-        <translation>Закрити</translation>
+        <translation type="vanished">Закрити</translation>
     </message>
 </context>
 <context>
     <name>GlobalDrawer</name>
     <message>
         <source>Log out</source>
-        <translation>Вийти</translation>
+        <translation type="vanished">Вийти</translation>
     </message>
     <message>
         <source>About</source>
@@ -307,15 +446,19 @@
     </message>
     <message>
         <source>Offline</source>
-        <translation type="unfinished">Поза мережею</translation>
+        <translation>Поза мережею</translation>
     </message>
     <message>
         <source>Online</source>
-        <translation type="unfinished"></translation>
+        <translation>У мережі</translation>
     </message>
     <message>
         <source>Connecting…</source>
-        <translation type="unfinished"></translation>
+        <translation>Встановлюємо з&apos;єднання…</translation>
+    </message>
+    <message>
+        <source>Switch device</source>
+        <translation>Перемкнути пристрій</translation>
     </message>
 </context>
 <context>
@@ -327,13 +470,30 @@
     </message>
     <message>
         <source>No password found. Please enter it.</source>
-        <translation>Не знайдено збереженого пароля. Будь ласка, введіть його.</translation>
+        <translation type="vanished">Не знайдено збереженого пароля. Будь ласка, введіть його.</translation>
     </message>
     <message>
         <source>No valid login QR code found.</source>
         <translation>Не знайдено коректного коду QR для входу.</translation>
     </message>
 </context>
+<context>
+    <name>LocalAccountRemoval</name>
+    <message>
+        <source>Remove account from this app</source>
+        <translation>Вилучити обліковий запис з цієї програми</translation>
+    </message>
+    <message>
+        <source>Your account will be removed from this app.
+Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
+        <translation>Ваш обліковий запис буде вилучено з цієї програми.
+Ваш пароль буде вилучено — не забудьте зберегти його у програмі для керування паролями або запам&apos;ятати його!</translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation>Вилучити</translation>
+    </message>
+</context>
 <context>
     <name>LoginPage</name>
     <message>
@@ -398,7 +558,7 @@
     </message>
     <message>
         <source>Log in using a QR-Code</source>
-        <translation>Вхід за допомогою QR-коду</translation>
+        <translation type="vanished">Вхід за допомогою QR-коду</translation>
     </message>
 </context>
 <context>
@@ -475,15 +635,15 @@
     <name>MessageHandler</name>
     <message>
         <source>Could not send message, as a result of not being connected.</source>
-        <translation>Не вдалося надіслати повідомлення через те, що немає з&apos;єднання.</translation>
+        <translation type="vanished">Не вдалося надіслати повідомлення через те, що немає з&apos;єднання.</translation>
     </message>
     <message>
         <source>Could not correct message, as a result of not being connected.</source>
-        <translation>Не вдалося виправити повідомлення через те, що немає з&apos;єднання.</translation>
+        <translation type="vanished">Не вдалося виправити повідомлення через те, що немає з&apos;єднання.</translation>
     </message>
     <message>
         <source>Spoiler</source>
-        <translation>Спойлер</translation>
+        <translation type="vanished">Спойлер</translation>
     </message>
     <message>
         <source>Message could not be sent.</source>
@@ -494,91 +654,110 @@
         <translation>Спроба виправити повідомлення зазнала невдачі.</translation>
     </message>
 </context>
+<context>
+    <name>MessageModel</name>
+    <message>
+        <source>Pending</source>
+        <translation>Очікування</translation>
+    </message>
+    <message>
+        <source>Sent</source>
+        <translation>Надіслані</translation>
+    </message>
+    <message>
+        <source>Delivered</source>
+        <translation>Доставлено</translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation>Помилка</translation>
+    </message>
+</context>
 <context>
     <name>MultimediaSettings</name>
     <message>
         <source>Multimedia Settings</source>
-        <translation type="unfinished">Параметри мультимедійних даних</translation>
+        <translation>Параметри мультимедійних даних</translation>
     </message>
     <message>
         <source>Configure</source>
-        <translation type="unfinished">Налаштувати</translation>
+        <translation>Налаштувати</translation>
     </message>
     <message>
         <source>Image Capture</source>
-        <translation type="unfinished">Захоплення зображень</translation>
+        <translation>Захоплення зображень</translation>
     </message>
     <message>
         <source>Audio Recording</source>
-        <translation type="unfinished">Запис звуку</translation>
+        <translation>Запис звуку</translation>
     </message>
     <message>
         <source>Video Recording</source>
-        <translation type="unfinished">Запис відео</translation>
+        <translation>Запис відео</translation>
     </message>
     <message>
         <source>Camera</source>
-        <translation type="unfinished">Відеокамера</translation>
+        <translation>Відеокамера</translation>
     </message>
     <message>
         <source>Audio input</source>
-        <translation type="unfinished">Звуковий вхід</translation>
+        <translation>Звуковий вхід</translation>
     </message>
     <message>
         <source>Container</source>
-        <translation type="unfinished">Контейнер</translation>
+        <translation>Контейнер</translation>
     </message>
     <message>
         <source>Image</source>
-        <translation type="unfinished">Зображення</translation>
+        <translation>Зображення</translation>
     </message>
     <message>
         <source>Audio</source>
-        <translation type="unfinished">Звук</translation>
+        <translation>Звук</translation>
     </message>
     <message>
         <source>Video</source>
-        <translation type="unfinished">Відео</translation>
+        <translation>Відео</translation>
     </message>
     <message>
         <source>Codec</source>
-        <translation type="unfinished">Кодек</translation>
+        <translation>Кодек</translation>
     </message>
     <message>
         <source>Resolution</source>
-        <translation type="unfinished">Роздільність</translation>
+        <translation>Роздільність</translation>
     </message>
     <message>
         <source>Quality</source>
-        <translation type="unfinished">Якість</translation>
+        <translation>Якість</translation>
     </message>
     <message>
         <source>Sample Rate</source>
-        <translation type="unfinished">Частота дискретизації</translation>
+        <translation>Частота дискретизації</translation>
     </message>
     <message>
         <source>Frame Rate</source>
-        <translation type="unfinished">Частота кадрів</translation>
+        <translation>Частота кадрів</translation>
     </message>
     <message>
         <source>Ready</source>
-        <translation type="unfinished">Готово</translation>
+        <translation>Готово</translation>
     </message>
     <message>
-        <source>Initializing...</source>
-        <translation type="unfinished">Ініціалізація…</translation>
+        <source>Initializing…</source>
+        <translation>Ініціалізація…</translation>
     </message>
     <message>
         <source>Unavailable</source>
-        <translation type="unfinished">Немає даних</translation>
+        <translation>Немає даних</translation>
     </message>
     <message>
-        <source>Recording...</source>
-        <translation type="unfinished">Запис…</translation>
+        <source>Recording…</source>
+        <translation>Запис…</translation>
     </message>
     <message>
         <source>Paused</source>
-        <translation type="unfinished">Призупинено</translation>
+        <translation>Призупинено</translation>
     </message>
 </context>
 <context>
@@ -652,7 +831,7 @@
         <translation type="vanished">Готово</translation>
     </message>
     <message>
-        <source>Initializing...</source>
+        <source>Initializing…</source>
         <translation type="vanished">Ініціалізація…</translation>
     </message>
     <message>
@@ -660,7 +839,7 @@
         <translation type="vanished">Немає даних</translation>
     </message>
     <message>
-        <source>Recording...</source>
+        <source>Recording…</source>
         <translation type="vanished">Запис…</translation>
     </message>
     <message>
@@ -675,7 +854,7 @@
         <translation>Готово</translation>
     </message>
     <message>
-        <source>Initializing...</source>
+        <source>Initializing…</source>
         <translation>Ініціалізація…</translation>
     </message>
     <message>
@@ -683,7 +862,7 @@
         <translation>Немає даних</translation>
     </message>
     <message>
-        <source>Recording... %1</source>
+        <source>Recording… %1</source>
         <translation>Запис… %1</translation>
     </message>
     <message>
@@ -691,6 +870,32 @@
         <translation>Призупинено %1</translation>
     </message>
 </context>
+<context>
+    <name>PasswordRemovalPage</name>
+    <message>
+        <source>Remove password</source>
+        <translation>Вилучити пароль</translation>
+    </message>
+    <message>
+        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
+        <translation>Ви можете наказати програмі лише більше не показувати ваш пароль до &lt;b&gt;%1&lt;/b&gt; або наказати їй повністю вилучити пароль із перенесення облікових записів. Якщо ви повністю вилучите ваш пароль, ви не зможете скористатися засобом перенесення облікових записів шляхом сканування коду без введення вашого пароля, оскільки пароль буде вилучено з QR-коду.</translation>
+    </message>
+    <message>
+        <source>Do not show password as text</source>
+        <translation>Не показувати пароль як текст</translation>
+    </message>
+    <message>
+        <source>Remove completely</source>
+        <translation>Вилучити повністю</translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Mark as read</source>
+        <translation>Позначити як прочитане</translation>
+    </message>
+</context>
 <context>
     <name>QmlUtils</name>
     <message>
@@ -723,43 +928,62 @@
     </message>
     <message>
         <source>Invisible</source>
-        <translation>Невидимий</translation>
+        <translation type="vanished">Невидимий</translation>
     </message>
     <message>
         <source>Invalid username or password.</source>
-        <translation type="unfinished">Некоректне ім’я користувача або пароль.</translation>
+        <translation>Некоректне ім’я користувача або пароль.</translation>
     </message>
     <message>
         <source>Cannot connect to the server. Please check your internet connection.</source>
-        <translation type="unfinished">Не вдалося встановити з&apos;єднання із сервером. Будь ласка, перевірте, чи маєте ви з&apos;єднання із інтернетом.</translation>
+        <translation>Не вдалося встановити з&apos;єднання із сервером. Будь ласка, перевірте, чи маєте ви з&apos;єднання із інтернетом.</translation>
     </message>
     <message>
         <source>The server doesn&apos;t support secure connections.</source>
-        <translation type="unfinished">На сервері не передбачено можливості захищених з&apos;єднань.</translation>
+        <translation>На сервері не передбачено можливості захищених з&apos;єднань.</translation>
     </message>
     <message>
         <source>Error while trying to connect securely.</source>
-        <translation type="unfinished">Помилка під час спроби встановлення захищеного з&apos;єднання.</translation>
+        <translation>Помилка під час спроби встановлення захищеного з&apos;єднання.</translation>
     </message>
     <message>
         <source>Could not resolve the server&apos;s address. Please check your server name.</source>
-        <translation type="unfinished"></translation>
+        <translation>Не вдалося визначити адресу сервера. Будь ласка, перевірте, чи правильно вказано назву сервера.</translation>
     </message>
     <message>
         <source>Could not connect to the server.</source>
-        <translation type="unfinished">Не вдалося встановити з’єднання із віддаленим сервером.</translation>
+        <translation type="vanished">Не вдалося встановити з’єднання із сервером.</translation>
     </message>
     <message>
         <source>Authentification protocol not supported by the server.</source>
-        <translation type="unfinished">На сервері не передбачено підтримки протоколу розпізнавання.</translation>
+        <translation>На сервері не передбачено підтримки протоколу розпізнавання.</translation>
     </message>
     <message>
         <source>This server does not support registration.</source>
-        <translation type="unfinished"></translation>
+        <translation>На сервері не передбачено підтримки реєстрації.</translation>
     </message>
     <message>
         <source>An unknown error occured.</source>
-        <translation type="unfinished"></translation>
+        <translation type="vanished">Сталася невідома помилка.</translation>
+    </message>
+    <message>
+        <source>The server is offline or blocked by a firewall.</source>
+        <translation>Цей сервер перебуває поза мережею або його заблоковано брандмауером.</translation>
+    </message>
+    <message>
+        <source>The connection could not be refreshed.</source>
+        <translation>Не вдалося освіжити з&apos;єднання.</translation>
+    </message>
+    <message>
+        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
+        <translation>З&apos;єднання з інтернетом заборонено. Будь ласка, перевірте налаштування доступу до інтернету у вашій системі.</translation>
+    </message>
+</context>
+<context>
+    <name>QrCodeGenerator</name>
+    <message>
+        <source>Generating the QR code failed: %1</source>
+        <translation>Не вдалося створити QR-код: %1</translation>
     </message>
 </context>
 <context>
@@ -782,6 +1006,41 @@ Try to close other applications using the camera.</source>
         <source>The camera format &apos;%1&apos; is not supported.</source>
         <translation>Підримки формату відеокамери «%1» не передбачено.</translation>
     </message>
+    <message>
+        <source>Connecting…</source>
+        <translation>Встановлення з’єднання…</translation>
+    </message>
+    <message>
+        <source>Scan the QR code from your existing device to transfer your account.</source>
+        <translation>Заскануйте QR-код з вашого наявного пристрою, щоб перенести ваш обліковий запис.</translation>
+    </message>
+    <message>
+        <source>Show explanation</source>
+        <translation>Показати пояснення</translation>
+    </message>
+    <message>
+        <source>Scan</source>
+        <translation>Сканувати</translation>
+    </message>
+    <message>
+        <source>Continue without QR code</source>
+        <translation>Продовжити без QR-коду</translation>
+    </message>
+</context>
+<context>
+    <name>RegistrationLoginDecisionPage</name>
+    <message>
+        <source>Set up</source>
+        <translation>Налаштувати</translation>
+    </message>
+    <message>
+        <source>Register a new account</source>
+        <translation>Зареєструвати новий обліковий запис</translation>
+    </message>
+    <message>
+        <source>Use an existing account</source>
+        <translation>Використати наявний обліковий запис</translation>
+    </message>
 </context>
 <context>
     <name>RegistrationManager</name>
@@ -794,6 +1053,23 @@ Try to close other applications using the camera.</source>
         <translation>Не вдалося змінити пароль: %1</translation>
     </message>
 </context>
+<context>
+    <name>RemoteAccountDeletion</name>
+    <message>
+        <source>Delete account completely</source>
+        <translation>Вилучити обліковий запис повністю</translation>
+    </message>
+    <message>
+        <source>Your account will be deleted completely, which means from this app and from the server.
+You will not be able to use your account again!</source>
+        <translation>Ваш обліковий запис буде повністю вилучено. Це означає, що його буде вилучено з цієї програми і з сервера.
+Ви більше не зможете скористатися вашим обліковим записом!</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Вилучити</translation>
+    </message>
+</context>
 <context>
     <name>RosterAddContactSheet</name>
     <message>
@@ -937,7 +1213,7 @@ Try to close other applications using the camera.</source>
     </message>
     <message>
         <source>Edit name:</source>
-        <translation>Редагування назви:</translation>
+        <translation type="vanished">Редагування назви:</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -964,7 +1240,25 @@ Try to close other applications using the camera.</source>
     </message>
 </context>
 <context>
-    <name>SettingsPage</name>
+    <name>ServerListModel</name>
+    <message>
+        <source>Custom server</source>
+        <translation>Нетиповий сервер</translation>
+    </message>
+    <message>
+        <source>No limitation</source>
+        <extracomment>Unlimited file size for uploading files
+----------
+Deletion of message history saved on server</extracomment>
+        <translation>Без обмежень</translation>
+    </message>
+    <message>
+        <source>%1 days</source>
+        <translation>%1 дні</translation>
+    </message>
+</context>
+<context>
+    <name>SettingsContent</name>
     <message>
         <source>Settings</source>
         <translation>Параметри</translation>
@@ -979,11 +1273,69 @@ Try to close other applications using the camera.</source>
     </message>
     <message>
         <source>Multimedia Settings</source>
-        <translation type="unfinished">Параметри мультимедійних даних</translation>
+        <translation>Параметри мультимедійних даних</translation>
     </message>
     <message>
         <source>Configure photo, video and audio recording settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Налаштуйте параметри обробки фотографій, відео та звукових записів</translation>
+    </message>
+    <message>
+        <source>Account security</source>
+        <translation>Безпека облікового запису</translation>
+    </message>
+    <message>
+        <source>configure whether this device can be used to log in on a new device</source>
+        <translation>Налаштуйте, чи можна використовувати цей пристрій для входу з нового пристрою</translation>
+    </message>
+    <message>
+        <source>Remove account from Kaidan</source>
+        <translation>Вилучити обліковий запис з Kaidan</translation>
+    </message>
+    <message>
+        <source>Remove account from this app</source>
+        <translation>Вилучити обліковий запис з цієї програми</translation>
+    </message>
+    <message>
+        <source>Delete account</source>
+        <translation>Вилучити обліковий запис</translation>
+    </message>
+    <message>
+        <source>Delete account from the server</source>
+        <translation>Вилучити обліковий запис з сервера</translation>
+    </message>
+</context>
+<context>
+    <name>SettingsPage</name>
+    <message>
+        <source>Settings</source>
+        <translation>Параметри</translation>
+    </message>
+    <message>
+        <source>Change password</source>
+        <translation type="vanished">Змінити пароль</translation>
+    </message>
+    <message>
+        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
+        <translation type="vanished">Змінити пароль до вашого облікового запису. Вам доведеться повторно ввести цей пароль на усіх інших ваших пристроях для спілкування.</translation>
+    </message>
+    <message>
+        <source>Multimedia Settings</source>
+        <translation type="vanished">Параметри мультимедійних даних</translation>
+    </message>
+    <message>
+        <source>Configure photo, video and audio recording settings</source>
+        <translation type="vanished">Налаштуйте параметри обробки фотографій, відео та звукових записів</translation>
+    </message>
+</context>
+<context>
+    <name>StartPage</name>
+    <message>
+        <source>Enjoy free communication on every device!</source>
+        <translation>Насолоджуйтеся вільним спілкуванням на будь-якому пристрої!</translation>
+    </message>
+    <message>
+        <source>Let&apos;s start</source>
+        <translation>Розпочнімо</translation>
     </message>
 </context>
 <context>
@@ -1015,6 +1367,10 @@ Try to close other applications using the camera.</source>
         <source>File</source>
         <translation>Файл</translation>
     </message>
+    <message>
+        <source>Message could not be sent.</source>
+        <translation>Повідомлення не вдалося надіслати.</translation>
+    </message>
 </context>
 <context>
     <name>UserProfilePage</name>
