@@ -28,14 +28,12 @@
  *  along with Kaidan.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef CLIENTWORKER_H
-#define CLIENTWORKER_H
+#pragma once
 
 // Qt
 #include <QObject>
 #include <QSettings>
 #include <QTimer>
-class QGuiApplication;
 // QXmpp
 #include <QXmppClient.h>
 // Kaidan
@@ -125,18 +123,24 @@ public:
 	 * @param caches All caches running in the main thread for communication with the UI.
 	 * @param kaidan Main back-end class, running in the main thread.
 	 * @param enableLogging If logging of the XMPP stream should be done.
-	 * @param app The QGuiApplication to determine if the window is active.
 	 * @param parent Optional QObject-based parent.
 	 */
-	ClientWorker(Caches *caches, Kaidan *kaidan, bool enableLogging, QGuiApplication *app, QObject *parent = nullptr);
+	ClientWorker(Caches *caches, Kaidan *kaidan, bool enableLogging, QObject *parent = nullptr);
 
-	VCardManager *getVCardManager() const;
+	VCardManager *vCardManager() const;
 
 	/**
 	 * Returns all models and caches.
 	 */
 	Caches *caches() const;
 
+	/**
+	 * Returns whether the application window is active.
+	 *
+	 * The application window is active when it is in the foreground and focused.
+	 */
+	bool isApplicationWindowActive() const;
+
 public slots:
 	/**
 	 * Main function of the client thread
@@ -150,7 +154,7 @@ public slots:
 	 */
 	void setCredentials(ClientWorker::Credentials creds)
 	{
-		this->creds = creds;
+		m_creds = creds;
 	}
 
 	/**
@@ -190,7 +194,7 @@ public slots:
 	 *
 	 * @param error error of the failed account deletion
 	 */
-	void handleAccountDeletionFromServerFailed(QXmppStanza::Error error);
+	void handleAccountDeletionFromServerFailed(const QXmppStanza::Error &error);
 
 	/**
 	 * Changes the user's password.
@@ -209,10 +213,19 @@ public slots:
 	void changeDisplayName(const QString &displayName);
 
 signals:
+	/**
+	 * Requests to show a notification for a chat message via the system's notification channel.
+	 *
+	 * @param senderJid JID of the message's sender
+	 * @param senderName name of the message's sender
+	 * @param message message to show
+	 */
+	void showMessageNotificationRequested(const QString &senderJid, const QString &senderName, const QString &message);
+
 	// Those signals are emitted by Kaidan.cpp and are used by this class.
 	void connectRequested();
 	void disconnectRequested();
-	void credentialsUpdated(ClientWorker::Credentials creds);
+	void credentialsUpdated(ClientWorker::Credentials m_creds);
 	void registrationFormRequested();
 
 	/**
@@ -228,6 +241,13 @@ signals:
 	void deleteAccountFromDatabase();
 
 private slots:
+	/**
+	 * Sets the value to know whether the application window is active.
+	 *
+	 * @param active true if the application window is active, false otherwise
+	 */
+	void setIsApplicationWindowActive(bool active);
+
 	/**
 	 * Called when an authenticated connection to the server is established.
 	 */
@@ -243,35 +263,31 @@ private slots:
 	 */
 	void onConnectionError(QXmppClient::Error error);
 
-	/**
-	 * Uses the QGuiApplication state to reduce network traffic when window is minimized
-	 */
-	void setCsiState(Qt::ApplicationState state);
-
 private:
 	/**
 	 * Generates the resource part of a JID with a suffix consisting of a dot followed by random alphanumeric characters.
 	 *
 	 * @param length number of random alphanumeric characters the suffix should consist of after the dot
 	 */
-	QString generateJidResourceWithRandomSuffix(const QString jidResourcePrefix, unsigned int length = 4) const;
+	QString generateJidResourceWithRandomSuffix(const QString &jidResourcePrefix, unsigned int length = 4) const;
 
 	Caches *m_caches;
-	Kaidan *kaidan;
-	QXmppClient *client;
-	LogHandler *logger;
-	Credentials creds;
-	bool enableLogging;
-	QGuiApplication *app;
 
-	RegistrationManager *registrationManager;
-	RosterManager *rosterManager;
-	MessageHandler *msgHandler;
-	DiscoveryManager *discoManager;
-	VCardManager *vCardManager;
-	UploadManager *uploadManager;
-	DownloadManager *downloadManager;
+	Kaidan *m_kaidan;
+	QXmppClient *m_client;
+	LogHandler *m_logger;
+	Credentials m_creds;
+	bool m_enableLogging;
 
+	RegistrationManager *m_registrationManager;
+	RosterManager *m_rosterManager;
+	MessageHandler *m_msgHandler;
+	DiscoveryManager *m_discoManager;
+	VCardManager *m_vCardManager;
+	UploadManager *m_uploadManager;
+	DownloadManager *m_downloadManager;
+
+	bool m_isApplicationWindowActive;
 	bool m_isReconnecting = false;
 	QXmppConfiguration m_configToBeUsedOnNextConnect;
 
@@ -284,5 +300,3 @@ private:
 	QString m_passwordToBeSetOnNextConnect;
 	QString m_displayNameToBeSetOnNextConnect;
 };
-
-#endif // CLIENTWORKER_H
