@@ -28,8 +28,7 @@
  *  along with Kaidan.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef DATABASE_H
-#define DATABASE_H
+#pragma once
 
 #include <QObject>
 #include <QSqlDatabase>
@@ -110,6 +109,8 @@ private:
 	void convertDatabaseToV8();
 	void convertDatabaseToV9();
 	void convertDatabaseToV10();
+	void convertDatabaseToV11();
+	void convertDatabaseToV12();
 
 	QSqlDatabase m_database;
 
@@ -123,5 +124,3 @@ private:
 
 	int m_transactions = 0;
 };
-
-#endif // DATABASE_H
