@@ -37,19 +37,20 @@
 #define KAIDAN_SETTINGS_AUTH_JID "auth/jid"
 #define KAIDAN_SETTINGS_AUTH_JID_RESOURCE_PREFIX "auth/jidResourcePrefix"
 #define KAIDAN_SETTINGS_AUTH_PASSWD "auth/password"
+#define KAIDAN_SETTINGS_AUTH_PASSWD_VISIBILITY "auth/passwordVisibility"
+#define KAIDAN_SETTINGS_NOTIFICATIONS_MUTED "muted/"
 
 #define KAIDAN_JID_RESOURCE_DEFAULT_PREFIX APPLICATION_DISPLAY_NAME
 
 #define INVITATION_URL "https://i.kaidan.im/#"
-#define APPLICATION_SOURCE_CODE_URL "https://invent.kde.org/kde/kaidan"
-#define ISSUE_TRACKING_URL "https://invent.kde.org/kde/kaidan/issues"
+#define APPLICATION_SOURCE_CODE_URL "https://invent.kde.org/network/kaidan"
+#define ISSUE_TRACKING_URL "https://invent.kde.org/network/kaidan/issues"
 
-#define MESSAGE_MAX_CHARS 1e4
+constexpr auto MESSAGE_MAX_CHARS = 1e4;
 
 // XML namespaces
 #define NS_SPOILERS "urn:xmpp:spoiler:0"
 #define NS_CARBONS "urn:xmpp:carbons:2"
-#define NS_REGISTER "jabber:iq:register"
 
 // SQL
 #define DB_CONNECTION "kaidan-messages"
@@ -64,13 +65,13 @@
 //
 
 // Length of generated usernames
-#define GENERATED_USERNAME_LENGTH 6
+constexpr auto GENERATED_USERNAME_LENGTH = 6;
 
 // Lower bound of the length for generated passwords (inclusive)
-#define GENERATED_PASSWORD_LENGTH_LOWER_BOUND 20
+constexpr auto GENERATED_PASSWORD_LENGTH_LOWER_BOUND = 20;
 
 // Upper bound of the length for generated passwords (inclusive)
-#define GENERATED_PASSWORD_LENGTH_UPPER_BOUND 30
+constexpr auto GENERATED_PASSWORD_LENGTH_UPPER_BOUND = 30;
 
 // Characters used for password generation
 #define GENERATED_PASSWORD_ALPHABET QLatin1String( \
@@ -85,7 +86,7 @@
 #define GENERATED_PASSWORD_ALPHABET_LENGTH GENERATED_PASSWORD_ALPHABET.size()
 
 // QXmpp version compatibility
-#define QXMPP_REQUIRED_VERSION_FOR_REGISTRATION QT_VERSION_CHECK(1, 2, 0)
+constexpr auto QXMPP_REQUIRED_VERSION_FOR_REGISTRATION = QT_VERSION_CHECK(1, 2, 0);
 
 /**
  * Path of the JSON server list file
@@ -96,7 +97,7 @@
  * Number of servers required in a country so that only servers from that country are
  * randomly selected.
  */
-#define SERVER_LIST_MIN_SERVERS_FROM_COUNTRY 2
+constexpr auto SERVER_LIST_MIN_SERVERS_FROM_COUNTRY = 2;
 
 /**
  * Name of the @c QQuickImageProvider for Bits of Binary.
