@@ -45,6 +45,7 @@
 #include "Database.h"
 #include "MessageDb.h"
 #include "MessageModel.h"
+#include "Notifications.h"
 #include "PresenceCache.h"
 #include "QmlUtils.h"
 #include "RosterDb.h"
@@ -63,6 +64,8 @@ Kaidan::Kaidan(QGuiApplication *app, bool enableLogging, QObject *parent)
 	Q_ASSERT(!s_instance);
 	s_instance = this;
 
+	connect(app, &QGuiApplication::applicationStateChanged, this, &Kaidan::handleApplicationStateChanged);
+
 	// Database setup
 	m_database->moveToThread(m_dbThrd);
 	m_msgDb->moveToThread(m_dbThrd);
@@ -90,19 +93,25 @@ Kaidan::Kaidan(QGuiApplication *app, bool enableLogging, QObject *parent)
 		m_caches->settings->value(KAIDAN_SETTINGS_AUTH_PASSWD).toString().toUtf8()
 	));
 	// Use a default prefix for the JID's resource part if no prefix is already set.
-	if (creds.jidResourcePrefix.isEmpty())
+	if (m_creds.jidResourcePrefix.isEmpty())
 		setJidResourcePrefix(KAIDAN_JID_RESOURCE_DEFAULT_PREFIX);
-	creds.isFirstTry = false;
+	m_creds.isFirstTry = false;
+
+	setPasswordVisibility(PasswordVisibility(
+		m_caches->settings->value(KAIDAN_SETTINGS_AUTH_PASSWD_VISIBILITY).toUInt()));
 
 	//
 	// Start ClientWorker on new thread
 	//
 
-	m_client = new ClientWorker(m_caches, this, enableLogging, app);
-	m_client->setCredentials(creds);
+	m_client = new ClientWorker(m_caches, this, enableLogging);
+	m_client->setCredentials(m_creds);
 	m_client->moveToThread(m_cltThrd);
 
 	connect(m_client, &ClientWorker::connectionErrorChanged, this, &Kaidan::setConnectionError);
+	connect(m_client, &ClientWorker::showMessageNotificationRequested, this, [](const QString &senderJid, const QString &senderName, const QString &message) {
+		Notifications::sendMessageNotification(senderJid, senderName, message);
+	});
 	connect(m_cltThrd, &QThread::started, m_client, &ClientWorker::main);
 
 	m_client->setObjectName("XmppClient");
@@ -118,7 +127,7 @@ Kaidan::~Kaidan()
 
 void Kaidan::start()
 {
-	if (creds.jid.isEmpty() || creds.password.isEmpty())
+	if (m_creds.jid.isEmpty() || m_creds.password.isEmpty())
 		emit newCredentialsNeeded();
 	else
 		mainConnect();
@@ -126,36 +135,44 @@ void Kaidan::start()
 
 void Kaidan::mainConnect()
 {
-	emit m_client->credentialsUpdated(creds);
+	emit m_client->credentialsUpdated(m_creds);
 	emit m_client->connectRequested();
 }
 
 void Kaidan::requestRegistrationForm()
 {
-	emit m_client->credentialsUpdated(creds);
+	emit m_client->credentialsUpdated(m_creds);
 	emit m_client->registrationFormRequested();
 }
 
 void Kaidan::mainDisconnect()
 {
 	// disconnect the client if connected or connecting
-	if (connectionState != ConnectionState::StateDisconnected)
+	if (m_connectionState != ConnectionState::StateDisconnected)
 		emit m_client->disconnectRequested();
 }
 
+void Kaidan::handleApplicationStateChanged(Qt::ApplicationState applicationState)
+{
+	if (applicationState == Qt::ApplicationActive)
+		emit applicationWindowActiveChanged(true);
+	else
+		emit applicationWindowActiveChanged(false);
+}
+
 void Kaidan::setConnectionState(QXmppClient::State state)
 {
-	if (this->connectionState != static_cast<ConnectionState>(state)) {
-		this->connectionState = static_cast<ConnectionState>(state);
+	if (m_connectionState != static_cast<ConnectionState>(state)) {
+		m_connectionState = static_cast<ConnectionState>(state);
 		emit connectionStateChanged();
 
 		// Open the possibly cached URI when connected.
 		// This is needed because the XMPP URIs can't be opened when Kaidan is not connected.
-		if (connectionState == ConnectionState::StateConnected && !openUriCache.isEmpty()) {
+		if (m_connectionState == ConnectionState::StateConnected && !m_openUriCache.isEmpty()) {
 			// delay is needed because sometimes the RosterPage needs to be loaded first
-			QTimer::singleShot(300, [=] () {
-				emit xmppUriReceived(openUriCache);
-				openUriCache = "";
+			QTimer::singleShot(300, this, [=] () {
+				emit xmppUriReceived(m_openUriCache);
+				m_openUriCache = "";
 			});
 		}
 	}
@@ -163,7 +180,7 @@ void Kaidan::setConnectionState(QXmppClient::State state)
 
 void Kaidan::setConnectionError(ClientWorker::ConnectionError error)
 {
-	connectionError = error;
+	m_connectionError = error;
 	emit connectionErrorChanged(error);
 }
 
@@ -177,25 +194,27 @@ void Kaidan::deleteCredentials()
 	m_caches->settings->remove(KAIDAN_SETTINGS_AUTH_PASSWD);
 	setPassword(QString());
 
+	setPasswordVisibility(PasswordVisible);
+
 	emit newCredentialsNeeded();
 }
 
 bool Kaidan::notificationsMuted(const QString &jid)
 {
-	return m_caches->settings->value(QString("muted/") + jid, false).toBool();
+	return m_caches->settings->value(QString(KAIDAN_SETTINGS_NOTIFICATIONS_MUTED) + jid, false).toBool();
 }
 
 void Kaidan::setNotificationsMuted(const QString &jid, bool muted)
 {
-	m_caches->settings->setValue(QString("muted/") + jid, muted);
+	m_caches->settings->setValue(QString(KAIDAN_SETTINGS_NOTIFICATIONS_MUTED) + jid, muted);
 	emit notificationsMutedChanged(jid);
 }
 
 void Kaidan::setJid(const QString &jid)
 {
-	creds.jid = jid;
+	m_creds.jid = jid;
 	// credentials were modified -> first try
-	creds.isFirstTry = true;
+	m_creds.isFirstTry = true;
 	emit jidChanged();
 }
 
@@ -203,7 +222,7 @@ void Kaidan::setJidResourcePrefix(const QString &jidResourcePrefix)
 {
 	// JID resource won't influence the authentication, so we don't need
 	// to set the first try flag and can save it.
-	creds.jidResourcePrefix = jidResourcePrefix;
+	m_creds.jidResourcePrefix = jidResourcePrefix;
 
 	m_caches->settings->setValue(KAIDAN_SETTINGS_AUTH_JID_RESOURCE_PREFIX, jidResourcePrefix);
 	emit jidResourcePrefixChanged();
@@ -211,15 +230,28 @@ void Kaidan::setJidResourcePrefix(const QString &jidResourcePrefix)
 
 void Kaidan::setPassword(const QString &password)
 {
-	creds.password = password;
+	m_creds.password = password;
 	// credentials were modified -> first try
-	creds.isFirstTry = true;
+	m_creds.isFirstTry = true;
 	emit passwordChanged();
 }
 
-quint8 Kaidan::getConnectionError() const
+void Kaidan::setPasswordVisibility(PasswordVisibility passwordVisibility)
 {
-	return static_cast<quint8>(connectionError);
+	m_caches->settings->setValue(KAIDAN_SETTINGS_AUTH_PASSWD_VISIBILITY, quint8(passwordVisibility));
+	emit passwordVisibilityChanged();
+}
+
+Kaidan::PasswordVisibility Kaidan::passwordVisibility() const
+{
+	return m_caches->settings
+		->value(KAIDAN_SETTINGS_AUTH_PASSWD_VISIBILITY, PasswordVisible)
+		.value<Kaidan::PasswordVisibility>();
+}
+
+quint8 Kaidan::connectionError() const
+{
+	return quint8(m_connectionError);
 }
 
 void Kaidan::addOpenUri(const QString &uri)
@@ -227,36 +259,39 @@ void Kaidan::addOpenUri(const QString &uri)
 	if (!QXmppUri::isXmppUri(uri))
 		return;
 
-	if (connectionState == ConnectionState::StateConnected) {
+	if (m_connectionState == ConnectionState::StateConnected) {
 		emit xmppUriReceived(uri);
 	} else {
 		//: The link is an XMPP-URI (i.e. 'xmpp:kaidan@muc.kaidan.im?join' for joining a chat)
 		emit passiveNotificationRequested(tr("The link will be opened after you have connected."));
-		openUriCache = uri;
+		m_openUriCache = uri;
 	}
 }
 
-bool Kaidan::logInByUri(const QString &uri)
+quint8 Kaidan::logInByUri(const QString &uri)
 {
 	if (!QXmppUri::isXmppUri(uri)) {
 		notifyForInvalidLoginUri();
-		return false;
+		return quint8(LoginByUriState::InvalidLoginUri);
 	}
 
 	QXmppUri parsedUri(uri);
 
-	if (!CredentialsValidator::isAccountJidValid(parsedUri.jid()) || !parsedUri.hasAction(QXmppUri::Action::Login) || !CredentialsValidator::isPasswordValid(parsedUri.password())) {
+	if (!CredentialsValidator::isAccountJidValid(parsedUri.jid())) {
 		notifyForInvalidLoginUri();
-		return false;
+		return quint8(LoginByUriState::InvalidLoginUri);
 	}
 
 	setJid(parsedUri.jid());
-	setPassword(parsedUri.password());
+
+	if (!parsedUri.hasAction(QXmppUri::Login) || !CredentialsValidator::isPasswordValid(parsedUri.password())) {
+		return quint8(LoginByUriState::PasswordNeeded);
+	}
 
 	// Connect with the extracted credentials.
+	setPassword(parsedUri.password());
 	mainConnect();
-
-	return true;
+	return quint8(LoginByUriState::Connecting);
 }
 
 void Kaidan::notifyForInvalidLoginUri()
@@ -265,7 +300,7 @@ void Kaidan::notifyForInvalidLoginUri()
 	emit passiveNotificationRequested(tr("No valid login QR code found."));
 }
 
-ClientWorker *Kaidan::getClient() const
+ClientWorker *Kaidan::client() const
 {
 	return m_client;
 }
