@@ -28,8 +28,7 @@
  *  along with Kaidan.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef KAIDAN_H
-#define KAIDAN_H
+#pragma once
 
 // Qt
 #include <QColor>
@@ -58,20 +57,31 @@ class Kaidan : public QObject
 {
 	Q_OBJECT
 
-	Q_PROPERTY(RosterModel* rosterModel READ getRosterModel CONSTANT)
-	Q_PROPERTY(MessageModel* messageModel READ getMessageModel CONSTANT)
-	Q_PROPERTY(AvatarFileStorage* avatarStorage READ getAvatarStorage NOTIFY avatarStorageChanged)
-	Q_PROPERTY(PresenceCache* presenceCache READ getPresenceCache CONSTANT)
-	Q_PROPERTY(TransferCache* transferCache READ getTransferCache CONSTANT)
+	Q_PROPERTY(RosterModel* rosterModel READ rosterModel CONSTANT)
+	Q_PROPERTY(MessageModel* messageModel READ messageModel CONSTANT)
+	Q_PROPERTY(AvatarFileStorage* avatarStorage READ avatarStorage NOTIFY avatarStorageChanged)
+	Q_PROPERTY(PresenceCache* presenceCache READ presenceCache CONSTANT)
+	Q_PROPERTY(TransferCache* transferCache READ transferCache CONSTANT)
 	Q_PROPERTY(ServerFeaturesCache* serverFeaturesCache READ serverFeaturesCache CONSTANT)
-	Q_PROPERTY(QSettings* settings READ getSettings CONSTANT)
-	Q_PROPERTY(quint8 connectionState READ getConnectionState NOTIFY connectionStateChanged)
-	Q_PROPERTY(quint8 connectionError READ getConnectionError NOTIFY connectionErrorChanged)
-	Q_PROPERTY(QString jid READ getJid WRITE setJid NOTIFY jidChanged)
-	Q_PROPERTY(QString jidResourcePrefix READ getJidResourcePrefix WRITE setJidResourcePrefix NOTIFY jidResourcePrefixChanged)
-	Q_PROPERTY(QString password READ getPassword WRITE setPassword NOTIFY passwordChanged)
+	Q_PROPERTY(QSettings* settings READ settings CONSTANT)
+	Q_PROPERTY(quint8 connectionState READ connectionState NOTIFY connectionStateChanged)
+	Q_PROPERTY(quint8 connectionError READ connectionError NOTIFY connectionErrorChanged)
+	Q_PROPERTY(QString jid READ jid WRITE setJid NOTIFY jidChanged)
+	Q_PROPERTY(QString jidResourcePrefix READ jidResourcePrefix WRITE setJidResourcePrefix NOTIFY jidResourcePrefixChanged)
+	Q_PROPERTY(QString password READ password WRITE setPassword NOTIFY passwordChanged)
+	Q_PROPERTY(PasswordVisibility passwordVisibility READ passwordVisibility WRITE setPasswordVisibility NOTIFY passwordVisibilityChanged)
 
 public:
+	/**
+	 * State which specifies in which way a password is shown on the account transfer page
+	 */
+	enum PasswordVisibility {
+		PasswordVisible, ///< The password is included in the QR code and shown as plain text.
+		PasswordVisibleQrOnly, ///< The password is included in the QR code but not shown as plain text.
+		PasswordInvisible ///< The password is neither included in the QR code nor shown as plain text.
+	};
+	Q_ENUM(PasswordVisibility)
+
 	static Kaidan *instance();
 
 	Kaidan(QGuiApplication *app, bool enableLogging = true, QObject *parent = nullptr);
@@ -105,15 +115,15 @@ public:
 	/**
 	 * Returns the current ConnectionState
 	 */
-	Q_INVOKABLE quint8 getConnectionState() const
+	quint8 connectionState() const
 	{
-		return (quint8) connectionState;
+		return quint8(m_connectionState);
 	}
 
 	/**
 	 * Returns the last connection error.
 	 */
-	Q_INVOKABLE quint8 getConnectionError() const;
+	quint8 connectionError() const;
 
 	/**
 	 * Set own JID used for connection
@@ -126,9 +136,9 @@ public:
 	/**
 	 * Get the current JID
 	 */
-	QString getJid() const
+	QString jid() const
 	{
-		return creds.jid;
+		return m_creds.jid;
 	}
 
 	/**
@@ -141,9 +151,9 @@ public:
 	/**
 	 * Provides the prefix of the JID's resource part.
 	 */
-	QString getJidResourcePrefix() const
+	QString jidResourcePrefix() const
 	{
-		return creds.jidResourcePrefix;
+		return m_creds.jidResourcePrefix;
 	}
 
 	/**
@@ -154,32 +164,42 @@ public:
 	/**
 	 * Get the currently used password
 	 */
-	QString getPassword() const
+	QString password() const
 	{
-		return creds.password;
+		return m_creds.password;
 	}
 
-	RosterModel* getRosterModel() const
+	/**
+	 * Sets the visibility of the password on the account transfer page.
+	 */
+	void setPasswordVisibility(PasswordVisibility passwordVisibility);
+
+	/**
+	 * Returns the visibility of the password on the account transfer page.
+	 */
+	PasswordVisibility passwordVisibility() const;
+
+	RosterModel* rosterModel() const
 	{
 		return m_caches->rosterModel;
 	}
 
-	MessageModel* getMessageModel() const
+	MessageModel* messageModel() const
 	{
 		return m_caches->msgModel;
 	}
 
-	AvatarFileStorage* getAvatarStorage() const
+	AvatarFileStorage* avatarStorage() const
 	{
 		return m_caches->avatarStorage;
 	}
 
-	PresenceCache* getPresenceCache() const
+	PresenceCache* presenceCache() const
 	{
 		return m_caches->presCache;
 	}
 
-	TransferCache* getTransferCache() const
+	TransferCache* transferCache() const
 	{
 		return m_caches->transferCache;
 	}
@@ -189,12 +209,12 @@ public:
 		return m_caches->serverFeaturesCache;
 	}
 
-	QSettings* getSettings() const
+	QSettings* settings() const
 	{
 		return m_caches->settings;
 	}
 
-	ClientWorker *getClient() const;
+	ClientWorker *client() const;
 
 	RosterDb *rosterDb() const;
 
@@ -208,11 +228,37 @@ public:
 	/**
 	 * Connects to the server by the parsed credentials (bare JID and password) from a given XMPP URI (e.g. from scanning a QR code) like "xmpp:user@example.org?login;password=abc"
 	 *
-	 * @return true if the login worked
+	 * The URI is used in the following cases.
+	 *
+	 * Login attempt (LoginByUriState::Connecting is returned):
+	 *	xmpp:user@example.org?login;password=abc
+	 *
+	 * Pre-fill of JID for opening login page (LoginByUriState::PasswordNeeded is returned):
+	 *	xmpp:user@example.org?login;password=
+	 *	xmpp:user@example.org?login;password
+	 *	xmpp:user@example.org?login;
+	 *	xmpp:user@example.org?login
+	 *	xmpp:user@example.org?
+	 *	xmpp:user@example.org
+	 *
+	 * In all other cases, LoginByUriState::InvalidLoginUri is returned.
+	 *
+	 * @param uri string which can be an XMPP login URI
+	 *
+	 * @return the state which specifies how the XMPP login URI was used
 	 */
-	Q_INVOKABLE bool logInByUri(const QString &uri);
+	Q_INVOKABLE quint8 logInByUri(const QString &uri);
 
 signals:
+	/**
+	 * Emitted when the application window becomes active or inactive.
+	 *
+	 * The application window is active when it is in the foreground and focused.
+	 *
+	 * @param active true if the application window becomes active, false otherwise
+	 */
+	void applicationWindowActiveChanged(bool active);
+
 	void avatarStorageChanged();
 
 	/**
@@ -255,6 +301,23 @@ signals:
 	 */
 	void loggedInWithNewCredentials();
 
+	/**
+	 * Raises the window to the foreground so that it is on top of all other windows.
+	 */
+	void raiseWindowRequested();
+
+	/**
+	 * Opens the chat page for a given JID.
+	 *
+	 * @param chatJid JID of the chat for which the chat page is opened
+	 */
+	void openChatPageRequested(const QString chatJid);
+
+	/**
+	 * Emitted when the removal state of the password on the account transfer page changed.
+	 */
+	void passwordVisibilityChanged();
+
 	/**
 	 * Show passive notification
 	 */
@@ -305,7 +368,7 @@ signals:
 	 *
 	 * To get/check the last message id, use `kaidan.messageModel.lastMessageId(jid)`
 	 */
-	void correctMessage(QString toJid, QString msgId, QString message);
+	void correctMessage(const QString &msgId, const QString &message);
 
 	/**
 	 * Upload and send file
@@ -387,6 +450,13 @@ signals:
 	void registrationFailed(quint8 error, const QString &errrorMessage);
 
 public slots:
+	/**
+	 * Handles a changed application state and emits whether the application window is active.
+	 *
+	 * @param applicationState state of the GUI application
+	 */
+	void handleApplicationStateChanged(Qt::ApplicationState applicationState);
+
 	/**
 	 * Set current connection state
 	 */
@@ -419,14 +489,12 @@ public slots:
 	/**
 	 * Sets the notifications to muted/unmuted.
 	 *
-	 * @param muted true if notifications should be muted.
-	 * @param jid contains the current chatpartner's jid.
+	 * @param muted true if notifications should be muted
+	 * @param jid JID of the entity for that notifications should be muted or unmuted
 	 */
 	void setNotificationsMuted(const QString& jid, bool muted);
 
 private:
-	void connectDatabases();
-
 	/**
 	 * Notifies if no valid login URI was found.
 	 */
@@ -440,12 +508,10 @@ private:
 	ClientWorker::Caches *m_caches;
 	ClientWorker *m_client;
 
-	ClientWorker::Credentials creds;
-	QString openUriCache;
-	ConnectionState connectionState = ConnectionState::StateDisconnected;
-	ClientWorker::ConnectionError connectionError = ClientWorker::NoError;
+	ClientWorker::Credentials m_creds;
+	QString m_openUriCache;
+	ConnectionState m_connectionState = ConnectionState::StateDisconnected;
+	ClientWorker::ConnectionError m_connectionError = ClientWorker::NoError;
 
 	static Kaidan *s_instance;
 };
-
-#endif
