@@ -28,13 +28,14 @@
  *  along with Kaidan.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef MESSAGEDB_H
-#define MESSAGEDB_H
+#pragma once
+
+#include "Enums.h"
+#include "Message.h"
 
 #include <functional>
 #include <QObject>
 
-class Message;
 class QSqlQuery;
 class QSqlRecord;
 
@@ -78,10 +79,20 @@ signals:
 	                            int index);
 
 	/**
-	 * Emitted, when new messages have been fetched
+	 *  Emitted to fetch pending messages.
+	 */
+	void fetchPendingMessagesRequested(const QString &userJid);
+
+	/**
+	 * Emitted when new messages have been fetched
 	 */
 	void messagesFetched(const QVector<Message> &messages);
 
+	/**
+	 * Emitted when pending messages have been fetched
+	 */
+	void pendingMessagesFetched(const QVector<Message> &messages);
+
 public slots:
 	/**
 	 * @brief Fetches more entries from the database and emits messagesFetched() with
@@ -95,6 +106,13 @@ public slots:
 	                   const QString &user2,
 	                   int index);
 
+	/**
+	 * @brief Fetches messages that are marked as pending.
+	 *
+	 * @param userJid JID of the user whose messages should be fetched
+	 */
+	void fetchPendingMessages(const QString &userJid);
+
 	/**
 	 * Fetches the last message and returns it.
 	 */
@@ -132,18 +150,6 @@ public slots:
 	void updateMessageRecord(const QString &id,
 	                         const QSqlRecord &updateRecord);
 
-	/**
-	 * Marks a message as sent using an UPDATE query.
-	 */
-	void setMessageAsSent(const QString &msgId);
-
-	/**
-	 * Marks a message as delivered using an UPDATE query.
-	 */
-	void setMessageAsDelivered(const QString &msgId);
-
 private:
 	static MessageDb *s_instance;
 };
-
-#endif // MESSAGEDB_H
