@@ -40,24 +40,22 @@
 #include <QXmppRosterManager.h>
 #include <QXmppUtils.h>
 // Kaidan
+#include "ClientWorker.h"
 #include "Kaidan.h"
-#include "Message.h"
 #include "MessageModel.h"
-#include "Notifications.h"
 #include "MediaUtils.h"
 
-MessageHandler::MessageHandler(Kaidan *kaidan, QXmppClient *client, MessageModel *model,
-                               QObject *parent)
-	: QObject(parent), kaidan(kaidan), client(client), model(model)
+MessageHandler::MessageHandler(Kaidan *kaidan, ClientWorker *clientWorker, QXmppClient *client, MessageModel *model)
+    : QObject(clientWorker), kaidan(kaidan), m_clientWorker(clientWorker), client(client), model(model)
 {
 	connect(client, &QXmppClient::messageReceived, this, &MessageHandler::handleMessage);
 	connect(kaidan, &Kaidan::sendMessage, this, &MessageHandler::sendMessage);
-	connect(kaidan, &Kaidan::correctMessage, this, &MessageHandler::correctMessage);
+	connect(model, &MessageModel::sendCorrectedMessageRequested, this, &MessageHandler::sendCorrectedMessage);
 
 	client->addExtension(&receiptManager);
 	connect(&receiptManager, &QXmppMessageReceiptManager::messageDelivered,
-	        this, [=] (const QString&, const QString &id) {
-		emit model->setMessageAsDeliveredRequested(id);
+		this, [=] (const QString&, const QString &id) {
+		emit model->setMessageDeliveryStateRequested(id, Enums::DeliveryState::Delivered);
 	});
 
 	carbonManager = new QXmppCarbonManager();
@@ -77,6 +75,9 @@ MessageHandler::MessageHandler(Kaidan *kaidan, QXmppClient *client, MessageModel
 
 	connect(discoManager, &QXmppDiscoveryManager::infoReceived,
 	        this, &MessageHandler::handleDiscoInfo);
+
+	connect(model, &MessageModel::pendingMessagesFetched,
+			this, &MessageHandler::handlePendingMessages);
 }
 
 MessageHandler::~MessageHandler()
@@ -86,29 +87,23 @@ MessageHandler::~MessageHandler()
 
 void MessageHandler::handleMessage(const QXmppMessage &msg)
 {
-    if (msg.body().isEmpty() || msg.type() == QXmppMessage::Error)
+	if (msg.type() == QXmppMessage::Error) {
+		emit model->setMessageDeliveryStateRequested(msg.id(), Enums::DeliveryState::Error, msg.error().text());
+		return;
+	}
+
+	if (msg.body().isEmpty())
 		return;
 
 	Message message;
 	message.setFrom(QXmppUtils::jidToBareJid(msg.from()));
 	message.setTo(QXmppUtils::jidToBareJid(msg.to()));
-	message.setSentByMe(msg.from() == client->configuration().jidBare());
+	message.setSentByMe(QXmppUtils::jidToBareJid(msg.from()) == client->configuration().jidBare());
 	message.setId(msg.id());
 	message.setBody(msg.body());
 	message.setMediaType(MessageType::MessageText); // default to text message without media
-#if (QXMPP_VERSION) >= QT_VERSION_CHECK(1, 1, 0)
 	message.setIsSpoiler(msg.isSpoiler());
 	message.setSpoilerHint(msg.spoilerHint());
-#else
-	for (const QXmppElement &extension : msg.extensions()) {
-		if (extension.tagName() == "spoiler" &&
-		    extension.attribute("xmlns") == NS_SPOILERS) {
-			message.setIsSpoiler(true);
-			message.setSpoilerHint(extension.value());
-			break;
-		}
-	}
-#endif
 
 	// check if message contains a link and also check out of band url
 	QStringList bodyWords = message.body().split(" ");
@@ -176,17 +171,12 @@ void MessageHandler::handleMessage(const QXmppMessage &msg)
 	if (contactName.isEmpty())
 		contactName = contactJid;
 
-	if (!message.sentByMe())
-		Notifications::sendMessageNotification(contactJid, contactName, msg.body());
-
-	// TODO: Move back following call to RosterManager::handleMessage when spoiler
-	// messages are implemented in QXmpp
-	const QString lastMessage =
-		message.isSpoiler() ? message.spoilerHint().isEmpty() ? tr("Spoiler")
-								      : message.spoilerHint()
-				    : msg.body();
-
-	emit kaidan->getRosterModel()->setLastMessageRequested(contactJid, lastMessage);
+	// Show a notification for the message in the following cases:
+	//  * The message was not sent by the user from another resource and received via Message Carbons.
+	//  * Notifications from the chat partner are not muted.
+	//  * The corresponding chat is not opened while the application window is active.
+	if (!message.sentByMe() && !kaidan->notificationsMuted(contactJid) && (model->currentChatJid() != message.from() || !m_clientWorker->isApplicationWindowActive()))
+		emit m_clientWorker->showMessageNotificationRequested(contactJid, contactName, msg.body());
 }
 
 void MessageHandler::sendMessage(const QString& toJid,
@@ -194,16 +184,6 @@ void MessageHandler::sendMessage(const QString& toJid,
                                  bool isSpoiler,
                                  const QString& spoilerHint)
 {
-	// TODO: Add offline message cache and send when connnected again
-	if (client->state() != QXmppClient::ConnectedState) {
-		emit kaidan->passiveNotificationRequested(
-			tr("Could not send message, as a result of not being connected.")
-		);
-		qWarning() << "[client] [MessageHandler] Could not send message, as a result of "
-		              "not being connected.";
-		return;
-	}
-
 	Message msg;
 	msg.setFrom(client->configuration().jidBare());
 	msg.setTo(toJid);
@@ -212,6 +192,7 @@ void MessageHandler::sendMessage(const QString& toJid,
 	msg.setReceiptRequested(true);
 	msg.setSentByMe(true);
 	msg.setMediaType(MessageType::MessageText); // text message without media
+	msg.setDeliveryState(Enums::DeliveryState::Pending);
 	msg.setStamp(QDateTime::currentDateTimeUtc());
 	if (isSpoiler) {
 		msg.setIsSpoiler(isSpoiler);
@@ -236,50 +217,25 @@ void MessageHandler::sendMessage(const QString& toJid,
 	}
 
 	emit model->addMessageRequested(msg);
-
-	if (client->sendPacket(static_cast<QXmppMessage>(msg)))
-		emit model->setMessageAsSentRequested(msg.id());
-	else
-	        emit kaidan->passiveNotificationRequested(tr("Message could not be sent."));
-	// TODO: handle error
+	sendPendingMessage(msg);
 }
 
-void MessageHandler::correctMessage(const QString& toJid,
-                                    const QString& msgId,
-                                    const QString& body)
+void MessageHandler::sendCorrectedMessage(const Message &msg)
 {
-	// TODO: load old message from model and put everything into the new message
-	//       instead of only the new body
-
-	// TODO: Add offline message cache and send when connnected again
-	if (client->state() != QXmppClient::ConnectedState) {
+	auto deliveryState = Enums::DeliveryState::Sent;
+	QString errorText;
+	if (!client->sendPacket(msg)) {
+		// TODO store in the database only error codes, assign text messages right in the QML
 		emit kaidan->passiveNotificationRequested(
-			tr("Could not correct message, as a result of not being connected.")
-		);
-		qWarning() << "[client] [MessageHandler] Could not correct message, as a result of "
-		              "not being connected.";
-		return;
+			tr("Message correction was not successful."));
+		errorText = "Message correction was not successful.";
+		deliveryState = Enums::DeliveryState::Error;
 	}
 
-	Message msg;
-	msg.setFrom(client->configuration().jidBare());
-	msg.setTo(toJid);
-	msg.setId(QXmppUtils::generateStanzaHash(28));
-	msg.setBody(body);
-	msg.setReceiptRequested(true);
-	msg.setSentByMe(true);
-	msg.setMediaType(MessageType::MessageText); // text message without media
-	msg.setIsEdited(true);
-	msg.setReplaceId(msgId);
-
-	emit model->updateMessageRequested(msgId, [=] (Message &msg) {
-		msg.setBody(body);
+	emit model->updateMessageRequested(msg.id(), [=] (Message &localMessage) {
+		localMessage.setDeliveryState(deliveryState);
+		localMessage.setErrorText(errorText);
 	});
-	if (client->sendPacket(msg))
-		emit model->setMessageAsSentRequested(msg.id());
-	else
-		emit kaidan->passiveNotificationRequested(
-	                        tr("Message correction was not successful."));
 }
 
 void MessageHandler::handleDiscoInfo(const QXmppDiscoveryIq &info)
@@ -290,3 +246,43 @@ void MessageHandler::handleDiscoInfo(const QXmppDiscoveryIq &info)
 	if (info.features().contains(NS_CARBONS))
 		carbonManager->setCarbonsEnabled(true);
 }
+
+void MessageHandler::sendPendingMessage(const Message &message)
+{
+	if (client->state() == QXmppClient::ConnectedState) {
+		bool success;
+		// if the message is a pending edition of the existing in the history message
+		// I need to send it with the most recent stamp
+		// for that I'm gonna copy that message and update in the copy just the stamp
+		if (message.isEdited()) {
+			Message msg = message;
+			msg.setStamp(QDateTime::currentDateTimeUtc());
+			success = client->sendPacket(msg);
+		} else {
+			success = client->sendPacket(message);
+		}
+
+		if (success)
+			emit model->setMessageDeliveryStateRequested(message.id(), Enums::DeliveryState::Sent);
+		// TODO this "true" from sendPacket doesn't yet mean the message was successfully sent
+
+		else {
+			qWarning() << "[client] [MessageHandler] Could not send message, as a result of"
+				<< "QXmppClient::sendPacket returned false.";
+
+			// The error message of the message is saved untranslated. To make
+			// translation work in the UI, the tr() call of the passive
+			// notification must contain exactly the same string.
+			emit kaidan->passiveNotificationRequested(tr("Message could not be sent."));
+			emit model->setMessageDeliveryStateRequested(message.id(), Enums::DeliveryState::Error, "Message could not be sent.");
+		}
+	}
+}
+
+void MessageHandler::handlePendingMessages(const QVector<Message> &messages)
+{
+	for (const Message &message : qAsConst(messages)) {
+		sendPendingMessage(message);
+	}
+}
+
