@@ -28,15 +28,17 @@
  *  along with Kaidan.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef MESSAGEHANDLER_H
-#define MESSAGEHANDLER_H
+#pragma once
 
 // Qt
 #include <QObject>
 // QXmpp
 #include <QXmppGlobal.h>
 #include <QXmppMessageReceiptManager.h>
+// Kaidan
+#include "Message.h"
 
+class ClientWorker;
 class Kaidan;
 class MessageModel;
 class QXmppMessage;
@@ -51,8 +53,7 @@ class MessageHandler : public QObject
 	Q_OBJECT
 
 public:
-	MessageHandler(Kaidan *kaidan, QXmppClient *client, MessageModel *model,
-	               QObject *parent = nullptr);
+	MessageHandler(Kaidan *kaidan, ClientWorker *clientWorker, QXmppClient *client, MessageModel *model);
 
 	~MessageHandler();
 
@@ -70,20 +71,26 @@ public slots:
 	/**
 	 * Sends the corrected version of a message.
 	 */
-	void correctMessage(const QString& toJid, const QString& msgId, const QString& newBody);
+	void sendCorrectedMessage(const Message &msg);
 
 	/**
 	 * Handles service discovery info and enables carbons if feature was found.
 	 */
 	void handleDiscoInfo(const QXmppDiscoveryIq &);
 
+private slots:
+	/**
+	 * Handles pending messages found in the database.
+	 */
+	void handlePendingMessages(const QVector<Message> &messages);
+
+	void sendPendingMessage(const Message &message);
+
 private:
 	Kaidan *kaidan;
+	ClientWorker *m_clientWorker;
 	QXmppClient *client;
 	QXmppMessageReceiptManager receiptManager;
 	MessageModel *model;
 	QXmppCarbonManager *carbonManager;
-	QString chatPartner;
 };
-
-#endif // MESSAGEHANDLER_H
