@@ -32,17 +32,25 @@
 // Kaidan
 #include "Kaidan.h"
 #include "MessageDb.h"
+#include "QmlUtils.h"
 // Qt 5
 // QXmpp
 #include <QXmppUtils.h>
 
+// defines that the message is suitable for correction only if it is among the N latest messages
+constexpr int MAX_CORRECTION_MESSAGE_COUNT_DEPTH = 20;
+// defines that the message is suitable for correction only if it has ben sent not earlier than N days ago
+constexpr int MAX_CORRECTION_MESSAGE_DAYS_DEPTH = 2;
+
 MessageModel::MessageModel(Kaidan *kaidan, MessageDb *msgDb, QObject *parent)
-        : QAbstractListModel(parent),
-          kaidan(kaidan),
-          msgDb(msgDb)
+	: QAbstractListModel(parent),
+	  kaidan(kaidan),
+	  msgDb(msgDb)
 {
 	connect(msgDb, &MessageDb::messagesFetched,
 	        this, &MessageModel::handleMessagesFetched);
+	connect(msgDb, &MessageDb::pendingMessagesFetched,
+	        this, &MessageModel::pendingMessagesFetched);
 
 	connect(this, &MessageModel::addMessageRequested,
 	        this, &MessageModel::addMessage);
@@ -51,18 +59,13 @@ MessageModel::MessageModel(Kaidan *kaidan, MessageDb *msgDb, QObject *parent)
 
 	connect(this, &MessageModel::updateMessageRequested,
 	        this, &MessageModel::updateMessage);
-	connect(this, &MessageModel::updateMessageRequested,
+	connect(this, &MessageModel::updateMessageInDatabaseRequested,
 	        msgDb, &MessageDb::updateMessage);
 
-	connect(this, &MessageModel::setMessageAsSentRequested,
-	        this, &MessageModel::setMessageAsSent);
-	connect(this, &MessageModel::setMessageAsSentRequested,
-	        msgDb, &MessageDb::setMessageAsSent);
-
-	connect(this, &MessageModel::setMessageAsDeliveredRequested,
-	        this, &MessageModel::setMessageAsDelivered);
-	connect(this, &MessageModel::setMessageAsDeliveredRequested,
-	        msgDb, &MessageDb::setMessageAsDelivered);
+	connect(this, &MessageModel::setMessageDeliveryStateRequested,
+	        this, &MessageModel::setMessageDeliveryState);
+	connect(kaidan, &Kaidan::correctMessage,
+	        this, &MessageModel::correctMessage);
 }
 
 MessageModel::~MessageModel() = default;
@@ -72,7 +75,7 @@ bool MessageModel::isEmpty() const
 	return m_messages.isEmpty();
 }
 
-int MessageModel::rowCount(const QModelIndex&) const
+int MessageModel::rowCount(const QModelIndex &) const
 {
 	return m_messages.length();
 }
@@ -88,8 +91,7 @@ QHash<int, QByteArray> MessageModel::roleNames() const
 	roles[SentByMe] = "sentByMe";
 	roles[MediaType] = "mediaType";
 	roles[IsEdited] = "isEdited";
-	roles[IsSent] = "isSent";
-	roles[IsDelivered] = "isDelivered";
+	roles[DeliveryState] = "deliveryState";
 	roles[MediaUrl] = "mediaUrl";
 	roles[MediaSize] = "mediaSize";
 	roles[MediaContentType] = "mediaContentType";
@@ -98,6 +100,9 @@ QHash<int, QByteArray> MessageModel::roleNames() const
 	roles[MediaThumb] = "mediaThumb";
 	roles[IsSpoiler] = "isSpoiler";
 	roles[SpoilerHint] = "spoilerHint";
+	roles[ErrorText] = "errorText";
+	roles[DeliveryStateIcon] = "deliveryStateIcon";
+	roles[DeliveryStateName] = "deliveryStateName";
 	return roles;
 }
 
@@ -123,13 +128,11 @@ QVariant MessageModel::data(const QModelIndex &index, int role) const
 	case SentByMe:
 		return msg.sentByMe();
 	case MediaType:
-		return int(msg.mediaType());
+		return QVariant::fromValue(msg.mediaType());
 	case IsEdited:
 		return msg.isEdited();
-	case IsSent:
-		return msg.isSent();
-	case IsDelivered:
-		return msg.isDelivered();
+	case DeliveryState:
+		return QVariant::fromValue(msg.deliveryState());
 	case MediaUrl:
 		return msg.outOfBandUrl();
 	case MediaLocation:
@@ -144,6 +147,32 @@ QVariant MessageModel::data(const QModelIndex &index, int role) const
 		return msg.isSpoiler();
 	case SpoilerHint:
 		return msg.spoilerHint();
+	case ErrorText:
+		return msg.errorText();
+	case DeliveryStateIcon:
+		switch (msg.deliveryState()) {
+		case DeliveryState::Pending:
+			return QmlUtils::getResourcePath("images/dots.svg");
+		case DeliveryState::Sent:
+			return QmlUtils::getResourcePath("images/check-mark-pale.svg");
+		case DeliveryState::Delivered:
+			return QmlUtils::getResourcePath("images/check-mark.svg");
+		case DeliveryState::Error:
+			return QmlUtils::getResourcePath("images/cross.svg");
+		}
+		return {};
+	case DeliveryStateName:
+		switch (msg.deliveryState()) {
+		case DeliveryState::Pending:
+			return tr("Pending");
+		case DeliveryState::Sent:
+			return tr("Sent");
+		case DeliveryState::Delivered:
+			return tr("Delivered");
+		case DeliveryState::Error:
+			return tr("Error");
+		}
+		return {};
 
 	// TODO: add (only useful as soon as we have got SIMS)
 	case MediaThumb:
@@ -154,8 +183,7 @@ QVariant MessageModel::data(const QModelIndex &index, int role) const
 
 void MessageModel::fetchMore(const QModelIndex &)
 {
-	emit msgDb->fetchMessagesRequested(kaidan->getJid(), chatPartner(),
-	                                   m_messages.size());
+	emit msgDb->fetchMessagesRequested(kaidan->jid(), m_currentChatJid, m_messages.size());
 }
 
 bool MessageModel::canFetchMore(const QModelIndex &) const
@@ -163,31 +191,47 @@ bool MessageModel::canFetchMore(const QModelIndex &) const
 	return !m_fetchedAll;
 }
 
-QString MessageModel::chatPartner()
+QString MessageModel::currentChatJid()
 {
-	return m_chatPartner;
+	return m_currentChatJid;
 }
 
-void MessageModel::setChatPartner(const QString &chatPartner)
+void MessageModel::setCurrentChatJid(const QString &currentChatJid)
 {
-	if (chatPartner == m_chatPartner)
+	if (currentChatJid == m_currentChatJid)
 		return;
 
-	m_chatPartner = chatPartner;
+	m_currentChatJid = currentChatJid;
 	m_fetchedAll = false;
 
-	emit chatPartnerChanged(chatPartner);
+	emit currentChatJidChanged(currentChatJid);
 	clearAll();
 }
 
-bool MessageModel::canCorrectMessage(const QString &msgId) const
+bool MessageModel::canCorrectMessage(int index) const
 {
-	// Only allow correction of the latest message sent by us
-	for (const auto &msg : m_messages) {
-		if (msg.from() == kaidan->getJid())
-			return msg.id() == msgId;
+	// check index validity
+	if (index < 0 || index >= m_messages.size())
+		return false;
+
+	// message needs to be sent by us and needs to be no error message
+	const auto &msg = m_messages.at(index);
+	if (!msg.sentByMe() || msg.deliveryState() == Enums::DeliveryState::Error)
+		return false;
+
+	// check time limit
+	const auto timeThreshold =
+		QDateTime::currentDateTimeUtc().addDays(-MAX_CORRECTION_MESSAGE_DAYS_DEPTH);
+	if (msg.stamp() < timeThreshold)
+		return false;
+
+	// check messages count limit
+	for (int i = 0, count = 0; i < index; i++) {
+		if (m_messages.at(i).sentByMe() && ++count == MAX_CORRECTION_MESSAGE_COUNT_DEPTH)
+			return false;
 	}
-	return false;
+
+	return true;
 }
 
 void MessageModel::handleMessagesFetched(const QVector<Message> &msgs)
@@ -197,7 +241,7 @@ void MessageModel::handleMessagesFetched(const QVector<Message> &msgs)
 
 	beginInsertRows(QModelIndex(), rowCount(), rowCount() + msgs.length() - 1);
 	for (auto msg : msgs) {
-		msg.setSentByMe(kaidan->getJid() == msg.from());
+		msg.setSentByMe(kaidan->jid() == msg.from());
 		processMessage(msg);
 		m_messages << msg;
 	}
@@ -225,9 +269,8 @@ void MessageModel::insertMessage(int idx, const Message &msg)
 
 void MessageModel::addMessage(Message msg)
 {
-	if (QXmppUtils::jidToBareJid(msg.from()) == m_chatPartner
-	    || QXmppUtils::jidToBareJid(msg.to()) == m_chatPartner) {
-
+	if (QXmppUtils::jidToBareJid(msg.from()) == m_currentChatJid ||
+			QXmppUtils::jidToBareJid(msg.to()) == m_currentChatJid) {
 		processMessage(msg);
 
 		// index where to add the new message
@@ -246,7 +289,7 @@ void MessageModel::addMessage(Message msg)
 }
 
 void MessageModel::updateMessage(const QString &id,
-                                 const std::function<void (Message &)> &updateMsg)
+                                 const std::function<void(Message &)> &updateMsg)
 {
 	for (int i = 0; i < m_messages.length(); i++) {
 		if (m_messages.at(i).id() == id) {
@@ -277,19 +320,15 @@ void MessageModel::updateMessage(const QString &id,
 			break;
 		}
 	}
+
+	emit updateMessageInDatabaseRequested(id, updateMsg);
 }
 
-void MessageModel::setMessageAsSent(const QString &msgId)
+void MessageModel::setMessageDeliveryState(const QString &msgId, Enums::DeliveryState state, const QString &errText)
 {
-	updateMessage(msgId, [] (Message &msg) {
-		msg.setIsSent(true);
-	});
-}
-
-void MessageModel::setMessageAsDelivered(const QString &msgId)
-{
-	updateMessage(msgId, [] (Message &msg) {
-		msg.setIsDelivered(true);
+	updateMessage(msgId, [state, errText](Message &msg) {
+		msg.setDeliveryState(state);
+		msg.setErrorText(errText);
 	});
 }
 
@@ -331,3 +370,48 @@ void MessageModel::processMessage(Message &msg)
 		msg.setBody(body);
 	}
 }
+
+void MessageModel::sendPendingMessages()
+{
+	emit msgDb->fetchPendingMessagesRequested(kaidan->jid());
+}
+
+void MessageModel::correctMessage(const QString &msgId, const QString &message)
+{
+	const auto hasCorrectId = [&msgId](const Message& msg) {
+		return msg.id() == msgId;
+	};
+	auto itr = std::find_if(m_messages.begin(), m_messages.end(), hasCorrectId);
+
+	if (itr != m_messages.end()) {
+		Message &msg = *itr;
+		msg.setBody(message);
+		if (msg.deliveryState() != Enums::DeliveryState::Pending) {
+			msg.setId(QXmppUtils::generateStanzaHash(28));
+			// Set replaceId only on first correction, so it's always the original id
+			// (`id` is the id of the current edit, `replaceId` is the original id)
+			if (!msg.isEdited()) {
+				msg.setIsEdited(true);
+				msg.setReplaceId(msgId);
+			}
+			msg.setDeliveryState(Enums::DeliveryState::Pending);
+
+			if (ConnectionState(kaidan->connectionState()) == Enums::ConnectionState::StateConnected) {
+				// the trick with the time is important for the servers
+				// this way they can tell which version of the message is the latest
+				Message copy = msg;
+				copy.setStamp(QDateTime::currentDateTimeUtc());
+				emit sendCorrectedMessageRequested(copy);
+			}
+		} else if (!msg.isEdited()) {
+			msg.setStamp(QDateTime::currentDateTimeUtc());
+		}
+
+		QModelIndex index = createIndex(std::distance(m_messages.begin(), itr), 0);
+		emit dataChanged(index, index);
+
+		emit updateMessageInDatabaseRequested(msgId, [=] (Message &localMessage) {
+			localMessage = msg;
+		});
+	}
+}
