@@ -28,8 +28,7 @@
  *  along with Kaidan.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef MESSAGEMODEL_H
-#define MESSAGEMODEL_H
+#pragma once
 
 #include <QAbstractListModel>
 #include "Message.h"
@@ -40,8 +39,7 @@ class Kaidan;
 class MessageModel : public QAbstractListModel
 {
 	Q_OBJECT
-	Q_PROPERTY(QString chatPartner READ chatPartner WRITE setChatPartner
-	                               NOTIFY chatPartnerChanged)
+	Q_PROPERTY(QString currentChatJid READ currentChatJid WRITE setCurrentChatJid NOTIFY currentChatJidChanged)
 
 public:
 	enum MessageRoles {
@@ -53,8 +51,7 @@ public:
 		SentByMe,
 		MediaType,
 		IsEdited,
-		IsSent,
-		IsDelivered,
+		DeliveryState,
 		MediaUrl,
 		MediaSize,
 		MediaContentType,
@@ -62,7 +59,10 @@ public:
 		MediaLocation,
 		MediaThumb,
 		IsSpoiler,
-		SpoilerHint
+		SpoilerHint,
+		ErrorText,
+		DeliveryStateIcon,
+		DeliveryStateName
 	};
 	Q_ENUM(MessageRoles)
 
@@ -77,10 +77,10 @@ public:
 	Q_INVOKABLE void fetchMore(const QModelIndex &parent) override;
 	Q_INVOKABLE bool canFetchMore(const QModelIndex &parent) const override;
 
-	QString chatPartner();
-	void setChatPartner(const QString &chatPartner);
+	QString currentChatJid();
+	void setCurrentChatJid(const QString &currentChatJid);
 
-	Q_INVOKABLE bool canCorrectMessage(const QString &msgId) const;
+	Q_INVOKABLE bool canCorrectMessage(int index) const;
 
 	/**
 	 * Searches from the most recent to the oldest message to find a given substring (case insensitive).
@@ -106,14 +106,22 @@ public:
 	 */
 	Q_INVOKABLE int searchForMessageFromOldToNew(const QString &searchString, const int startIndex = -1) const;
 
+	/**
+	 * Sends pending messages again after searching them in the database.
+	 */
+	Q_INVOKABLE void sendPendingMessages();
+
 signals:
-	void chatPartnerChanged(const QString &chatPartner);
+	void currentChatJidChanged(const QString &currentChatJid);
 
 	void addMessageRequested(const Message &msg);
 	void updateMessageRequested(const QString &id,
 	                            const std::function<void (Message &)> &updateMsg);
-	void setMessageAsSentRequested(const QString &msgId);
-	void setMessageAsDeliveredRequested(const QString &msgId);
+	void setMessageDeliveryStateRequested(const QString &msgId, Enums::DeliveryState state, const QString &errText = QString());
+	void pendingMessagesFetched(const QVector<Message> &messages);
+	void sendCorrectedMessageRequested(const Message &msg);
+	void updateMessageInDatabaseRequested(const QString &id,
+	                                      const std::function<void (Message &)> &updateMsg);
 
 private slots:
 	void handleMessagesFetched(const QVector<Message> &m_messages);
@@ -121,8 +129,9 @@ private slots:
 	void addMessage(Message msg);
 	void updateMessage(const QString &id,
 	                   const std::function<void (Message &)> &updateMsg);
-	void setMessageAsSent(const QString &msgId);
-	void setMessageAsDelivered(const QString &msgId);
+
+	void setMessageDeliveryState(const QString &msgId, Enums::DeliveryState state, const QString &errText = QString());
+	void correctMessage(const QString &msgId, const QString &message);
 
 private:
 	void clearAll();
@@ -138,8 +147,6 @@ private:
 	MessageDb *msgDb;
 
 	QVector<Message> m_messages;
-	QString m_chatPartner;
+	QString m_currentChatJid;
 	bool m_fetchedAll = false;
 };
-
-#endif // MESSAGEMODEL_H
