@@ -28,32 +28,59 @@
  *  along with Kaidan.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-// Kaidan
 #include "Notifications.h"
-#include "Kaidan.h"
-// Qt
-#include <QVariant>
+
 // KNotifications
 #ifdef HAVE_KNOTIFICATIONS
 #include <KNotification>
 #endif
 
-#ifdef HAVE_KNOTIFICATIONS
-void Notifications::sendMessageNotification(const QString& jid, const QString& fromName, const QString& message)
-{
-	if (!Kaidan::instance()->notificationsMuted(jid)) {
-		KNotification *notification = new KNotification("new-message");
-		notification->setText(message);
-		notification->setTitle(fromName);
-#ifdef Q_OS_ANDROID
-		notification->setIconName("kaidan-bw");
+// Kaidan
+#include "Kaidan.h"
+
+// Q_OS_BSD4 includes all BSD variants and also Q_OS_DARWIN
+// Q_OS_LINUX is also defined on Android
+#if (defined(Q_OS_LINUX) || defined(Q_OS_BSD4) || defined(Q_OS_HURD)) && \
+	!defined(Q_OS_ANDROID) && !defined(Q_OS_DARWIN)
+#define DESKTOP_LINUX_ALIKE_OS
 #endif
+
+#ifdef HAVE_KNOTIFICATIONS
+#ifdef DESKTOP_LINUX_ALIKE_OS
+static bool IS_USING_GNOME = qEnvironmentVariable("XDG_CURRENT_DESKTOP").contains("GNOME", Qt::CaseInsensitive);
+#endif
+
+void Notifications::sendMessageNotification(const QString &senderJid, const QString &senderName, const QString &message)
+{
+	KNotification *notification = new KNotification("new-message");
+	notification->setText(message);
+	notification->setTitle(senderName);
+#ifdef DESKTOP_LINUX_ALIKE_OS
+	if (IS_USING_GNOME)
 		notification->setFlags(KNotification::Persistent);
-		notification->sendEvent();
-	}
+#endif
+#ifdef Q_OS_ANDROID
+	notification->setIconName("kaidan-bw");
+#endif
+	notification->setDefaultAction("Open");
+	notification->setActions(QStringList {
+	    QObject::tr("Mark as read")
+	});
+
+	QObject::connect(notification, &KNotification::defaultActivated, [=] {
+		emit Kaidan::instance()->openChatPageRequested(senderJid);
+		emit Kaidan::instance()->raiseWindowRequested();
+	});
+	QObject::connect(notification, &KNotification::action1Activated, [=] {
+		emit Kaidan::instance()->rosterModel()->updateItemRequested(senderJid, [=](RosterItem &item) {
+			item.setUnreadMessages(0);
+		});
+	});
+
+	notification->sendEvent();
 }
 #else
 void Notifications::sendMessageNotification(const QString&, const QString&, const QString&)
 {
 }
-#endif
+#endif // HAVE_KNOTIFICATIONS
