@@ -28,17 +28,13 @@
  *  along with Kaidan.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef QMLUTILS_H
-#define QMLUTILS_H
+#pragma once
 
 #include <QObject>
 #include <QUrl>
 
 #include "ClientWorker.h"
 #include "Globals.h"
-#include "Enums.h"
-
-using namespace Enums;
 
 /**
  * @brief C++ utitlities to be used in QML
@@ -57,21 +53,6 @@ public:
 	QmlUtils(QObject *parent = nullptr);
 	~QmlUtils();
 
-	/**
-	 * Returns the icon belonging to the given presence status type
-	 */
-	Q_INVOKABLE static QString presenceTypeToIcon(Enums::AvailabilityTypes type);
-
-	/**
-	 * Returns the text belonging to the given presence status type
-	 */
-	Q_INVOKABLE static QString presenceTypeToText(Enums::AvailabilityTypes type);
-
-	/**
-	 * Returns the color belonging to the given presence status type
-	 */
-	Q_INVOKABLE static QColor presenceTypeToColor(Enums::AvailabilityTypes type);
-
 	/**
 	 * Returns an error message for a connection error.
 	 *
@@ -174,5 +155,3 @@ private:
 	 */
 	static QString processMsgFormatting(const QStringList &words, bool isFirst = true);
 };
-
-#endif // QMLUTILS_H
