@@ -203,13 +203,13 @@ void RegistrationManager::handleRegistrationFailed(const QXmppStanza::Error &err
 		}
 		break;
 	default:
-// Workaround: Catch an error which is wrongly emitted by older QXmpp versions although the registration was succesful.
-#if (QXMPP_VERSION) <= QT_VERSION_CHECK(1, 2, 0)
+#if QXMPP_VERSION == QT_VERSION_CHECK(1, 2, 0)
+		// Workaround: Catch an error which is wrongly emitted by QXmpp
+		// v1.2.0 although the registration was succesful.
 		if (error.text().isEmpty())
 			return;
-#else
-		break;
 #endif
+		break;
 	}
 
 	emit kaidan->registrationFailed(quint8(registrationError), error.text());
@@ -258,8 +258,12 @@ void RegistrationManager::copyUserDefinedValuesToNewForm(const QXmppDataForm &ol
 	// Copy values from the last form.
 	const QList<QXmppDataForm::Field> oldFields = oldForm.fields();
 	for (const auto &field : oldFields) {
-		// Only copy fields which are required, visible to the user and do not have a media element (e.g. CAPTCHA).
-		if (field.isRequired() && field.type() != QXmppDataForm::Field::HiddenField && field.media().isNull()) {
+		// Only copy fields which:
+		//  * are required,
+		//  * are visible to the user
+		//  * do not have a media element (e.g. CAPTCHA)
+		if (field.isRequired() && field.type() != QXmppDataForm::Field::HiddenField &&
+			field.mediaSources().isEmpty()) {
 			for (auto &fieldFromNewForm : newForm.fields()) {
 				if (fieldFromNewForm.key() == field.key()) {
 					fieldFromNewForm.setValue(field.value());
