@@ -46,33 +46,33 @@ RosterManager::RosterManager(Kaidan *kaidan,
                              VCardManager *vCardManager,
                              QObject *parent)
     : QObject(parent),
-      kaidan(kaidan),
-      client(client),
-      model(model),
-      avatarStorage(avatarStorage),
-      vCardManager(vCardManager),
-      manager(client->findExtension<QXmppRosterManager>())
+	  m_kaidan(kaidan),
+	  m_client(client),
+	  m_model(model),
+	  m_avatarStorage(avatarStorage),
+	  m_vCardManager(vCardManager),
+	  m_manager(client->findExtension<QXmppRosterManager>())
 {
-	connect(manager, &QXmppRosterManager::rosterReceived,
+	connect(m_manager, &QXmppRosterManager::rosterReceived,
 	        this, &RosterManager::populateRoster);
 
-	connect(manager, &QXmppRosterManager::itemAdded,
+	connect(m_manager, &QXmppRosterManager::itemAdded,
 		this, [this, vCardManager, model] (const QString &jid) {
-		emit model->addItemRequested(RosterItem(manager->getRosterEntry(jid)));
+		emit model->addItemRequested(RosterItem(m_manager->getRosterEntry(jid)));
 
 		vCardManager->fetchVCard(jid);
 	});
 
-	connect(manager, &QXmppRosterManager::itemChanged,
+	connect(m_manager, &QXmppRosterManager::itemChanged,
 		this, [this, model] (const QString &jid) {
-		emit model->updateItemRequested(m_chatPartner, [=] (RosterItem &item) {
-			item.setName(manager->getRosterEntry(jid).name());
+		emit model->updateItemRequested(jid, [=] (RosterItem &item) {
+			item.setName(m_manager->getRosterEntry(jid).name());
 		});
 	});
 
-	connect(manager, &QXmppRosterManager::itemRemoved, model, &RosterModel::removeItemRequested);
+	connect(m_manager, &QXmppRosterManager::itemRemoved, model, &RosterModel::removeItemRequested);
 
-	connect(manager, &QXmppRosterManager::subscriptionReceived,
+	connect(m_manager, &QXmppRosterManager::subscriptionReceived,
 	        this, [kaidan] (const QString &jid) {
 		// emit signal to ask user
 		emit kaidan->subscriptionRequestReceived(jid, QString());
@@ -80,23 +80,18 @@ RosterManager::RosterManager(Kaidan *kaidan,
 	connect(kaidan, &Kaidan::subscriptionRequestAnswered,
 	        this, [=] (QString jid, bool accepted) {
 		if (accepted) {
-			manager->acceptSubscription(jid);
+			m_manager->acceptSubscription(jid);
 
 			// do not send a subscription request if both users have already subscribed
 			// each others presence
-			if (manager->getRosterEntry(jid).subscriptionType() != QXmppRosterIq::Item::Both)
-				manager->subscribe(jid);
+			if (m_manager->getRosterEntry(jid).subscriptionType() != QXmppRosterIq::Item::Both)
+				m_manager->subscribe(jid);
 		} else {
-			manager->refuseSubscription(jid);
+			m_manager->refuseSubscription(jid);
 		}
 	});
 
-	// update local copy of chat partner
-	connect(kaidan->getMessageModel(), &MessageModel::chatPartnerChanged,
-	        this, [=] (const QString &jid) {
-		        m_chatPartner = jid;
-	        }
-	);
+	connect(kaidan->messageModel(), &MessageModel::currentChatJidChanged, this, &RosterManager::setCurrentChatJid);
 
 	// user actions
 	connect(kaidan, &Kaidan::addContact, this, &RosterManager::addContact);
@@ -112,26 +107,31 @@ void RosterManager::populateRoster()
 	qDebug() << "[client] [RosterManager] Populating roster";
 	// create a new list of contacts
 	QHash<QString, RosterItem> items;
-	const QStringList bareJids = manager->getRosterBareJids();
+	const QStringList bareJids = m_manager->getRosterBareJids();
 	const auto currentTime = QDateTime::currentDateTimeUtc();
 	for (const auto &jid : bareJids) {
-		items[jid] = RosterItem(manager->getRosterEntry(jid), currentTime);
+		items[jid] = RosterItem(m_manager->getRosterEntry(jid), currentTime);
 
-		if (avatarStorage->getHashOfJid(jid).isEmpty())
-			vCardManager->fetchVCard(jid);
+		if (m_avatarStorage->getHashOfJid(jid).isEmpty())
+			m_vCardManager->fetchVCard(jid);
 	}
 
 	// replace current contacts with new ones from server
-	emit model->replaceItemsRequested(items);
+	emit m_model->replaceItemsRequested(items);
+}
+
+void RosterManager::setCurrentChatJid(const QString &currentChatJid)
+{
+	m_currentChatJid = currentChatJid;
 }
 
 void RosterManager::addContact(const QString &jid, const QString &name, const QString &msg)
 {
-	if (client->state() == QXmppClient::ConnectedState) {
-		manager->addItem(jid, name);
-		manager->subscribe(jid, msg);
+	if (m_client->state() == QXmppClient::ConnectedState) {
+		m_manager->addItem(jid, name);
+		m_manager->subscribe(jid, msg);
 	} else {
-		emit kaidan->passiveNotificationRequested(
+		emit m_kaidan->passiveNotificationRequested(
 			tr("Could not add contact, as a result of not being connected.")
 		);
 		qWarning() << "[client] [RosterManager] Could not add contact, as a result of "
@@ -141,11 +141,11 @@ void RosterManager::addContact(const QString &jid, const QString &name, const QS
 
 void RosterManager::removeContact(const QString &jid)
 {
-	if (client->state() == QXmppClient::ConnectedState) {
-		manager->unsubscribe(jid);
-		manager->removeItem(jid);
+	if (m_client->state() == QXmppClient::ConnectedState) {
+		m_manager->unsubscribe(jid);
+		m_manager->removeItem(jid);
 	} else {
-		emit kaidan->passiveNotificationRequested(
+		emit m_kaidan->passiveNotificationRequested(
 			tr("Could not remove contact, as a result of not being connected.")
 		);
 		qWarning() << "[client] [RosterManager] Could not remove contact, as a result of "
@@ -155,10 +155,10 @@ void RosterManager::removeContact(const QString &jid)
 
 void RosterManager::renameContact(const QString &jid, const QString &newContactName)
 {
-	if (client->state() == QXmppClient::ConnectedState) {
-		manager->renameItem(jid, newContactName);
+	if (m_client->state() == QXmppClient::ConnectedState) {
+		m_manager->renameItem(jid, newContactName);
 	} else {
-		emit kaidan->passiveNotificationRequested(
+		emit m_kaidan->passiveNotificationRequested(
 			tr("Could not rename contact, as a result of not being connected.")
 		);
 		qWarning() << "[client] [RosterManager] Could not rename contact, as a result of "
@@ -169,15 +169,15 @@ void RosterManager::renameContact(const QString &jid, const QString &newContactN
 void RosterManager::handleSendMessage(const QString &jid, const QString &message,
                                       bool isSpoiler, const QString &spoilerHint)
 {
-	if (client->state() == QXmppClient::ConnectedState) {
+	if (m_client->state() == QXmppClient::ConnectedState) {
 		// update roster item
 		const QString lastMessage =
 		        isSpoiler ? spoilerHint.isEmpty() ? tr("Spoiler")
 		                                          : spoilerHint
 		                  : message;
 		// sorting order in contact list
-		emit model->setLastExchangedRequested(jid, QDateTime::currentDateTimeUtc());
-		emit model->setLastMessageRequested(jid, lastMessage);
+		emit m_model->setLastExchangedRequested(jid, QDateTime::currentDateTimeUtc());
+		emit m_model->setLastMessageRequested(jid, lastMessage);
 	}
 }
 
@@ -188,22 +188,36 @@ void RosterManager::handleMessage(const QXmppMessage &msg)
 
 	// msg.from() can be our JID, if it's a carbon/forward from another client
 	QString fromJid = QXmppUtils::jidToBareJid(msg.from());
-	bool sentByMe = fromJid == client->configuration().jidBare();
+	bool sentByMe = fromJid == m_client->configuration().jidBare();
 	QString contactJid = sentByMe ? QXmppUtils::jidToBareJid(msg.to())
 	                              : fromJid;
 
 	// update last exchanged datetime (sorting order in contact list)
-	emit model->setLastExchangedRequested(contactJid, QDateTime::currentDateTimeUtc());
+	emit m_model->setLastExchangedRequested(contactJid, QDateTime::currentDateTimeUtc());
 
 	// update unread message counter, if chat is not active
 	if (sentByMe) {
 		// if we sent a message (with another device), reset counter
-		emit model->updateItemRequested(contactJid, [](RosterItem &item) {
+		emit m_model->updateItemRequested(contactJid, [](RosterItem &item) {
 			item.setUnreadMessages(0);
 		});
-	} else if (m_chatPartner != contactJid) {
-		emit model->updateItemRequested(contactJid, [](RosterItem &item) {
+	} else if (m_currentChatJid != contactJid) {
+		emit m_model->updateItemRequested(contactJid, [](RosterItem &item) {
 			item.setUnreadMessages(item.unreadMessages() + 1);
 		});
 	}
+
+	// Update last message of the contact
+	QString lastMessage;
+	if (msg.isSpoiler()) {
+		if (msg.spoilerHint().isEmpty()) {
+			lastMessage = tr("Spoiler");
+		} else {
+			lastMessage = msg.spoilerHint();
+		}
+	} else {
+		lastMessage = msg.body();
+	}
+
+	emit Kaidan::instance()->rosterModel()->setLastMessageRequested(contactJid, lastMessage);
 }
