@@ -28,8 +28,7 @@
  *  along with Kaidan.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef ROSTERMANAGER_H
-#define ROSTERMANAGER_H
+#pragma once
 
 // Qt
 #include <QObject>
@@ -49,7 +48,7 @@ class RosterManager : public QObject
 
 public:
 	RosterManager(Kaidan *kaidan, QXmppClient *client, RosterModel *rosterModel,
-	              AvatarFileStorage *avatarStorage, VCardManager *vCardManager,
+				  AvatarFileStorage *avatarStorage, VCardManager *vCardManager,
 	              QObject *parent = nullptr);
 
 public slots:
@@ -61,17 +60,15 @@ public slots:
 
 private slots:
 	void populateRoster();
+	void setCurrentChatJid(const QString &currentChatJid);
 	void handleMessage(const QXmppMessage &msg);
 
 private:
-	Kaidan *kaidan;
-	QXmppClient *client;
-	RosterModel *model;
-	AvatarFileStorage *avatarStorage;
-	VCardManager *vCardManager;
-
-	QXmppRosterManager *manager;
-	QString m_chatPartner;
+	Kaidan *m_kaidan;
+	QXmppClient *m_client;
+	RosterModel *m_model;
+	AvatarFileStorage *m_avatarStorage;
+	VCardManager *m_vCardManager;
+	QXmppRosterManager *m_manager;
+	QString m_currentChatJid;
 };
-
-#endif // ROSTERMANAGER_H
