@@ -64,7 +64,7 @@ RosterModel::RosterModel(RosterDb *rosterDb, QObject *parent)
 	connect(this, &RosterModel::replaceItemsRequested,
 	        this, &RosterModel::replaceItems);
 	connect(this, &RosterModel::replaceItemsRequested,
-	        rosterDb, &RosterDb::replaceItems);
+		rosterDb, &RosterDb::replaceItems);
 
 	// This is only done in the model, the database is updated automatically by the new
 	// messages:
@@ -78,17 +78,15 @@ RosterModel::RosterModel(RosterDb *rosterDb, QObject *parent)
 		m_items.clear();
 		endResetModel();
 
-		emit rosterDb->fetchItemsRequested(Kaidan::instance()->getJid());
+		emit rosterDb->fetchItemsRequested(Kaidan::instance()->jid());
 	});
 }
 
 void RosterModel::setMessageModel(MessageModel *model)
 {
-	connect(model, &MessageModel::chatPartnerChanged,
-	        this, [=] (const QString &chatPartner) {
+	connect(model, &MessageModel::currentChatJidChanged, this, [=] (const QString &currentChatJid) {
 		// reset unread message counter
-		emit updateItemRequested(chatPartner,
-		                         [] (RosterItem &item) {
+		emit updateItemRequested(currentChatJid, [] (RosterItem &item) {
 			item.setUnreadMessages(0);
 		});
 	});
@@ -137,6 +135,23 @@ QVariant RosterModel::data(const QModelIndex &index, int role) const
 	return {};
 }
 
+std::optional<const RosterItem> RosterModel::findItem(const QString &jid) const
+{
+	for (const auto &item : qAsConst(m_items)) {
+		if (item.jid() == jid)
+			return item;
+	}
+
+	return std::nullopt;
+}
+
+QString RosterModel::itemName(const QString &jid) const
+{
+	if (auto item = findItem(jid))
+		return item->name();
+	return {};
+}
+
 void RosterModel::handleItemsFetched(const QVector<RosterItem> &items)
 {
 	beginResetModel();
@@ -163,7 +178,6 @@ void RosterModel::removeItem(const QString &jid)
 		}
 		i++;
 	}
-
 }
 
 void RosterModel::updateItem(const QString &jid,
@@ -179,6 +193,8 @@ void RosterModel::updateItem(const QString &jid,
 			if (m_items.at(i) == item)
 				return;
 
+			m_items.replace(i, item);
+
 			// item was changed: refresh all roles
 			emit dataChanged(index(i), index(i), {});
 
