@@ -28,11 +28,14 @@
  *  along with Kaidan.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef ROSTERMODEL_H
-#define ROSTERMODEL_H
+#pragma once
 
+// std
+#include <optional>
+// Qt
 #include <QAbstractListModel>
 #include <QVector>
+// Kaidan
 #include "RosterItem.h"
 
 class Kaidan;
@@ -61,6 +64,13 @@ public:
 	Q_REQUIRED_RESULT QHash<int, QByteArray> roleNames() const override;
 	Q_REQUIRED_RESULT QVariant data(const QModelIndex &index, int role) const override;
 
+	/**
+	 * Retrieves the name of a roster item.
+	 *
+	 * @return Name of the roster item or a null string
+	 */
+	Q_INVOKABLE QString itemName(const QString &jid) const;
+
 signals:
 	void addItemRequested(const RosterItem &item);
 	void removeItemRequested(const QString &jid);
@@ -82,6 +92,11 @@ private slots:
 	void setLastExchanged(const QString &contactJid, const QDateTime &newLastExchanged);
 
 private:
+	/**
+	 * Searches for the roster item with a given JID.
+	 */
+	std::optional<const RosterItem> findItem(const QString &jid) const;
+
 	void insertContact(int i, const RosterItem &item);
 	int updateItemPosition(int currentIndex);
 	int positionToInsert(const RosterItem &item);
@@ -89,5 +104,3 @@ private:
 	RosterDb *rosterDb;
 	QVector<RosterItem> m_items;
 };
-
-#endif // ROSTERMODEL_H
