@@ -37,7 +37,7 @@ VCardModel::VCardModel(QObject *parent)
 	: QAbstractListModel(parent)
 {
 	connect(
-		Kaidan::instance()->getClient()->getVCardManager(),
+		Kaidan::instance()->client()->vCardManager(),
 		&VCardManager::vCardReceived,
 		this,
 		&VCardModel::handleVCardReceived
@@ -116,7 +116,7 @@ void VCardModel::setJid(const QString &jid)
 	m_jid = jid;
 	emit jidChanged();
 
-	Kaidan::instance()->vCardRequested(jid);
+	emit Kaidan::instance()->vCardRequested(jid);
 }
 
 VCardModel::Item::Item(const QString &key, const QString &value)
