@@ -33,17 +33,17 @@
 
 #include <QFile>
 #include <QFileInfo>
-#include <QNetworkReply>
 #include <QMutex>
-#include "QXmppUploadRequestManager.h"
+#include <QNetworkReply>
+#include <QXmppHttpUploadIq.h>
+#include <QXmppUploadRequestManager.h>
 
 class QNetworkAccessManager;
-class QXmppHttpUploadRequestIq;
 class QXmppUploadManager; // needed for QXmppHttpUpload
 
 /// \class QXmppHttpUpload Represents a single HTTP file upload.
 
-class QXMPP_EXPORT QXmppHttpUpload : public QXmppLoggable
+class QXmppHttpUpload : public QXmppLoggable
 {
     Q_OBJECT
     Q_PROPERTY(qint64 bytesSent READ bytesSent NOTIFY bytesSentChanged)
@@ -117,7 +117,7 @@ bool operator==(const QXmppHttpUpload &l, const QXmppHttpUpload &r);
 /// \class QXmppHttpUploadManager This class extends the \see QXmppUploadCoreManager by also
 /// handling the actual upload via. HTTP.
 
-class QXMPP_EXPORT QXmppUploadManager : public QXmppUploadRequestManager
+class QXmppUploadManager : public QXmppUploadRequestManager
 {
     Q_OBJECT
 
@@ -130,7 +130,7 @@ public:
 
 public slots:
     const QXmppHttpUpload* uploadFile(const QFileInfo &file, bool allowParallel = false,
-                                      QString customFileName = "");
+                                      QString customFileName = QString());
 
 signals:
     void uploadSucceeded(const QXmppHttpUpload *upload);
