@@ -43,14 +43,19 @@ REPLACE_USER_IDS = [
 	("Jonah Brüchert <jbb.mail@gmx.de>", "Jonah Brüchert <jbb@kaidan.im>"),
 	("Jonah Bruechert <jbb.mail@gmx.de>", "Jonah Brüchert <jbb@kaidan.im>"),
 	("Georg <s.g.b@gmx.de>", "geobra <s.g.b@gmx.de>"),
-	("Muhammad Nur Hidayat Yasuyoshi (MNH48.com) <muhdnurhidayat96@yahoo.com>",
-	 "Muhammad Nur Hidayat Yasuyoshi <mnh48mail@gmail.com>"),
+	("Muhammad Nur Hidayat Yasuyoshi (MNH48.com) <muhdnurhidayat96@yahoo.com>", "Muhammad Nur Hidayat Yasuyoshi <translation@mnh48.moe>"),
+	("Muhammad Nur Hidayat Yasuyoshi <mnh48mail@gmail.com>", "Muhammad Nur Hidayat Yasuyoshi <translation@mnh48.moe>"),
+	("Muhammad Nur Hidayat Yasuyoshi <admin@mnh48.moe>", "Muhammad Nur Hidayat Yasuyoshi <translation@mnh48.moe>"),
+	("Yaya - Nurul Azeera Hidayah @ Muhammad Nur Hidayat Yasuyoshi <translation@mnh48.moe>", "Muhammad Nur Hidayat Yasuyoshi <translation@mnh48.moe>"),
 	("Joeke de Graaf <mappack@null.net>", "Joeke de Graaf <joeke.de.graaf@student.nhlstenden.com>"),
 	("X advocatux <advocatux@airpost.net>", "advocatux <advocatux@airpost.net>"),
 	("ZatroxDE <zatroxde@outlook.com>", "Robert Maerkisch <zatroxde@protonmail.ch>"),
 	("X oiseauroch <tobias.ollive@mailoo.org>", "oiseauroch <tobias.ollive@mailoo.org>"),
 	("X ssantos <ssantos@web.de>", "ssantos <ssantos@web.de>"),
-	("X Txaume <txaumevw@gmail.com>", "Txaume <txaumevw@gmail.com>")
+	("X Txaume <txaumevw@gmail.com>", "Txaume <txaumevw@gmail.com>"),
+	("X mondstern <hello@mondstern.tk>", "mondstern <hello@mondstern.tk>"),
+	("Jeannette L <j.lavoie@net-c.ca>", "Jeannette Lavoie <j.lavoie@net-c.ca>"),
+	("aevw _ <arcanevw@tuta.io>", "aevw <arcanevw@tuta.io>"),
 ]
 
 # These user ids will be excluded from any targets
@@ -62,7 +67,10 @@ EXCLUDE_USER_IDS = [
 	"Kaidan Translations <translations@kaidan.im>",
 	"Kaidan translations <translations@kaidan.im>",
 	"Hosted Weblate <hosted@weblate.org>",
-	"l10n daemon script <scripty@kde.org>"
+	"l10n daemon script <scripty@kde.org>",
+	"Anonymous <noreply@weblate.org>",
+	"Anonymous _ <noreply@weblate.org>",
+	"X anonymous <noreply@weblate.org>"
 ]
 
 GPL3_OPENSSL_LICENSE = """This program is free software; you can redistribute it and/or modify it under
@@ -327,6 +335,21 @@ def main():
 				"Melvin Keskin <melvo@olomono.de>": CopyrightAuthor(years = "2019"),
 			},
 		),
+		CopyrightTarget(
+			files = ["data/images/check-mark-pale.svg"],
+			licenseName = "CC-BY-SA-4.0",
+			authorList = {
+				"Melvin Keskin <melvo@olomono.de>": CopyrightAuthor(years = "2020"),
+				"Yury Gubich <blue@macaw.me>": CopyrightAuthor(years = "2020"),
+			},
+		),
+		CopyrightTarget(
+			files = ["data/images/cross.svg", "data/images/dots.svg"],
+			licenseName = "CC-BY-SA-4.0",
+			authorList = {
+				"Yury Gubich <blue@macaw.me>": CopyrightAuthor(years = "2020"),
+			},
+		),
 		CopyrightTarget(
 			files = [
 				"misc/kaidan-128x128.png",
@@ -407,7 +430,7 @@ def main():
 	];
 
 	print("Upstream-Name: kaidan")
-	print("Source: https://invent.kde.org/kde/kaidan/")
+	print("Source: https://invent.kde.org/network/kaidan/")
 	print("Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/")
 	print()
 
